@@ -32,24 +32,23 @@ import urllib
 import urlparse
 import uuid
 
-import adba
-from apscheduler.schedulers.background import BackgroundScheduler
+from apscheduler.schedulers.tornado import TornadoScheduler
 from apscheduler.triggers.interval import IntervalTrigger
 from dateutil import tz
 from fake_useragent import UserAgent
+from keycloak.realm import KeycloakRealm
 from tornado.ioloop import IOLoop
 
+import adba
 import sickrage
 from sickrage.core.api import API
 from sickrage.core.caches.name_cache import NameCache
 from sickrage.core.common import SD, SKIPPED, WANTED
 from sickrage.core.config import Config
 from sickrage.core.databases.cache import CacheDB
-from sickrage.core.databases.failed import FailedDB
 from sickrage.core.databases.main import MainDB
-from sickrage.core.google import GoogleAuth
-from sickrage.core.helpers import findCertainShow, \
-    generateCookieSecret, makeDir, get_lan_ip, restoreSR, getDiskSpaceUsage, getFreeSpace, launch_browser
+from sickrage.core.helpers import findCertainShow, generate_secret, makeDir, get_lan_ip, restoreSR, \
+    getDiskSpaceUsage, getFreeSpace, launch_browser, torrent_webui_url
 from sickrage.core.helpers.encoding import get_sys_encoding, ek, patch_modules
 from sickrage.core.logger import Logger
 from sickrage.core.nameparser.validator import check_force_season_folders
@@ -60,6 +59,7 @@ from sickrage.core.queues.search import SearchQueue
 from sickrage.core.queues.show import ShowQueue
 from sickrage.core.searchers.backlog_searcher import BacklogSearcher
 from sickrage.core.searchers.daily_searcher import DailySearcher
+from sickrage.core.searchers.failed_snatch_searcher import FailedSnatchSearcher
 from sickrage.core.searchers.proper_searcher import ProperSearcher
 from sickrage.core.searchers.subtitle_searcher import SubtitleSearcher
 from sickrage.core.searchers.trakt_searcher import TraktSearcher
@@ -67,9 +67,9 @@ from sickrage.core.tv.show import TVShow
 from sickrage.core.ui import Notifications
 from sickrage.core.updaters.show_updater import ShowUpdater
 from sickrage.core.updaters.tz_updater import update_network_dict
+from sickrage.core.upnp import UPNPClient
 from sickrage.core.version_updater import VersionUpdater
 from sickrage.core.webserver import WebServer
-from sickrage.core.websession import WebSession
 from sickrage.metadata import MetadataProviders
 from sickrage.notifiers import NotifierProviders
 from sickrage.providers import SearchProviders
@@ -79,10 +79,11 @@ class Core(object):
     def __init__(self):
         self.started = False
         self.daemon = None
-        self.io_loop = IOLoop().instance()
+        self.io_loop = IOLoop().current()
         self.pid = os.getpid()
+        self.showlist = []
 
-        self.tz = tz.tzlocal()
+        self.tz = tz.tzwinlocal() if tz.tzwinlocal else tz.tzlocal()
 
         self.config_file = None
         self.data_dir = None
@@ -95,25 +96,38 @@ class Core(object):
         self.newest_version = None
         self.newest_version_string = None
 
+        self.naming_ep_type = ("%(seasonnumber)dx%(episodenumber)02d",
+                               "s%(seasonnumber)02de%(episodenumber)02d",
+                               "S%(seasonnumber)02dE%(episodenumber)02d",
+                               "%(seasonnumber)02dx%(episodenumber)02d")
+        self.sports_ep_type = ("%(seasonnumber)dx%(episodenumber)02d",
+                               "s%(seasonnumber)02de%(episodenumber)02d",
+                               "S%(seasonnumber)02dE%(episodenumber)02d",
+                               "%(seasonnumber)02dx%(episodenumber)02d")
+        self.naming_ep_type_text = ("1x02", "s01e02", "S01E02", "01x02")
+        self.naming_multi_ep_type = {0: ["-%(episodenumber)02d"] * len(self.naming_ep_type),
+                                     1: [" - " + x for x in self.naming_ep_type],
+                                     2: [x + "%(episodenumber)02d" for x in ("x", "e", "E", "x")]}
+        self.naming_multi_ep_type_text = ("extend", "duplicate", "repeat")
+        self.naming_sep_type = (" - ", " ")
+        self.naming_sep_type_text = (" - ", "space")
+
         self.user_agent = 'SiCKRAGE.CE.1/({};{};{})'.format(platform.system(), platform.release(), str(uuid.uuid1()))
+        self.languages = [language for language in os.listdir(sickrage.LOCALE_DIR) if '_' in language]
         self.sys_encoding = get_sys_encoding()
-        self.languages = [language for language in os.listdir(sickrage.LOCALE_DIR) if '_' in language]
-        self.showlist = []
+        self.client_web_urls = {'torrent': '', 'newznab': ''}
 
-        self.api = None
         self.adba_connection = None
         self.notifier_providers = None
-        self.metadata_providers = None
+        self.metadata_providers = {}
         self.search_providers = None
         self.log = None
         self.config = None
         self.alerts = None
         self.main_db = None
         self.cache_db = None
-        self.failed_db = None
         self.scheduler = None
         self.wserver = None
-        self.wsession = None
         self.google_auth = None
         self.name_cache = None
         self.show_queue = None
@@ -127,9 +141,8 @@ class Core(object):
         self.trakt_searcher = None
         self.subtitle_searcher = None
         self.auto_postprocessor = None
-
-        # patch modules with encoding kludge
-        patch_modules()
+        self.upnp_client = None
+        self.oidc_client = None
 
     def start(self):
         self.started = True
@@ -137,21 +150,20 @@ class Core(object):
         # thread name
         threading.currentThread().setName('CORE')
 
+        # patch modules with encoding kludge
+        patch_modules()
+
         # init core classes
         self.notifier_providers = NotifierProviders()
         self.metadata_providers = MetadataProviders()
         self.search_providers = SearchProviders()
         self.log = Logger()
         self.config = Config()
-        self.api = API()
         self.alerts = Notifications()
         self.main_db = MainDB()
         self.cache_db = CacheDB()
-        self.failed_db = FailedDB()
-        self.scheduler = BackgroundScheduler()
+        self.scheduler = TornadoScheduler()
         self.wserver = WebServer()
-        self.wsession = WebSession()
-        self.google_auth = GoogleAuth()
         self.name_cache = NameCache()
         self.show_queue = ShowQueue()
         self.search_queue = SearchQueue()
@@ -159,12 +171,18 @@ class Core(object):
         self.version_updater = VersionUpdater()
         self.show_updater = ShowUpdater()
         self.daily_searcher = DailySearcher()
+        self.failed_snatch_searcher = FailedSnatchSearcher()
         self.backlog_searcher = BacklogSearcher()
         self.proper_searcher = ProperSearcher()
         self.trakt_searcher = TraktSearcher()
         self.subtitle_searcher = SubtitleSearcher()
         self.auto_postprocessor = AutoPostProcessor()
+        self.upnp_client = UPNPClient()
 
+        # setup oidc client
+        realm = KeycloakRealm(server_url='https://auth.sickrage.ca', realm_name='sickrage')
+        self.oidc_client = realm.open_id_connect(client_id='sickrage-app',
+                                                 client_secret='5d4710b2-ca70-4d39-b5a3-0705e2c5e703')
 
         # Check if we need to perform a restore first
         if os.path.exists(os.path.abspath(os.path.join(self.data_dir, 'restore'))):
@@ -211,6 +229,9 @@ class Core(object):
         urlparse.uses_netloc.append('scgi')
         urllib.FancyURLopener.version = self.user_agent
 
+        # set torrent client web url
+        torrent_webui_url(True)
+
         # Check available space
         try:
             total_space, available_space = getFreeSpace(self.data_dir)
@@ -219,10 +240,10 @@ class Core(object):
                                'otherwise. Only %sMB left', available_space)
                 return
         except Exception:
-            self.log.error('Failed getting diskspace: %s', traceback.format_exc())
+            self.log.error('Failed getting disk space: %s', traceback.format_exc())
 
         # perform database startup actions
-        for db in [self.main_db, self.cache_db, self.failed_db]:
+        for db in [self.main_db, self.cache_db]:
             # initialize database
             db.initialize()
 
@@ -235,8 +256,11 @@ class Core(object):
             # misc database cleanups
             db.cleanup()
 
+            # upgrade database
+            db.upgrade()
+
         # compact main database
-        if not sickrage.app.developer and self.config.last_db_compact < time.time() - 604800:  # 7 days
+        if self.config.last_db_compact < time.time() - 604800:  # 7 days
             self.main_db.compact()
             self.config.last_db_compact = int(time.time())
 
@@ -271,7 +295,7 @@ class Core(object):
             self.config.web_port = 8081
 
         if not self.config.web_cookie_secret:
-            self.config.web_cookie_secret = generateCookieSecret()
+            self.config.web_cookie_secret = generate_secret()
 
         # attempt to help prevent users from breaking links by using a bad url
         if not self.config.anon_redirect.endswith('?'):
@@ -300,6 +324,8 @@ class Core(object):
             self.config.version_updater_freq = self.config.min_version_updater_freq
         if self.config.subtitle_searcher_freq < self.config.min_subtitle_searcher_freq:
             self.config.subtitle_searcher_freq = self.config.min_subtitle_searcher_freq
+        if self.config.failed_snatch_age < self.config.min_failed_snatch_age:
+            self.config.failed_snatch_age = self.config.min_failed_snatch_age
         if self.config.proper_searcher_interval not in ('15m', '45m', '90m', '4h', 'daily'):
             self.config.proper_searcher_interval = 'daily'
         if self.config.showupdate_hour < 0 or self.config.showupdate_hour > 23:
@@ -313,8 +339,8 @@ class Core(object):
             IntervalTrigger(
                 hours=self.config.version_updater_freq
             ),
-            name="VERSIONUPDATER",
-            id="VERSIONUPDATER"
+            name=self.version_updater.name,
+            id=self.version_updater.name
         )
 
         # add network timezones updater job
@@ -334,8 +360,8 @@ class Core(object):
                 days=1,
                 start_date=datetime.datetime.now().replace(hour=self.config.showupdate_hour)
             ),
-            name="SHOWUPDATER",
-            id="SHOWUPDATER"
+            name=self.show_updater.name,
+            id=self.show_updater.name
         )
 
         # add daily search job
@@ -345,8 +371,19 @@ class Core(object):
                 minutes=self.config.daily_searcher_freq,
                 start_date=datetime.datetime.now() + datetime.timedelta(minutes=4)
             ),
-            name="DAILYSEARCHER",
-            id="DAILYSEARCHER"
+            name=self.daily_searcher.name,
+            id=self.daily_searcher.name
+        )
+
+        # add failed snatch search job
+        self.scheduler.add_job(
+            self.failed_snatch_searcher.run,
+            IntervalTrigger(
+                hours=1,
+                start_date=datetime.datetime.now() + datetime.timedelta(minutes=4)
+            ),
+            name=self.failed_snatch_searcher.name,
+            id=self.failed_snatch_searcher.name
         )
 
         # add backlog search job
@@ -356,8 +393,8 @@ class Core(object):
                 minutes=self.config.backlog_searcher_freq,
                 start_date=datetime.datetime.now() + datetime.timedelta(minutes=30)
             ),
-            name="BACKLOG",
-            id="BACKLOG"
+            name=self.backlog_searcher.name,
+            id=self.backlog_searcher.name
         )
 
         # add auto-postprocessing job
@@ -366,8 +403,8 @@ class Core(object):
             IntervalTrigger(
                 minutes=self.config.autopostprocessor_freq
             ),
-            name="POSTPROCESSOR",
-            id="POSTPROCESSOR"
+            name=self.auto_postprocessor.name,
+            id=self.auto_postprocessor.name
         )
 
         # add find proper job
@@ -377,8 +414,8 @@ class Core(object):
                 minutes={'15m': 15, '45m': 45, '90m': 90, '4h': 4 * 60, 'daily': 24 * 60}[
                     self.config.proper_searcher_interval]
             ),
-            name="PROPERSEARCHER",
-            id="PROPERSEARCHER"
+            name=self.proper_searcher.name,
+            id=self.proper_searcher.name
         )
 
         # add trakt.tv checker job
@@ -387,8 +424,8 @@ class Core(object):
             IntervalTrigger(
                 hours=1
             ),
-            name="TRAKTSEARCHER",
-            id="TRAKTSEARCHER"
+            name=self.trakt_searcher.name,
+            id=self.trakt_searcher.name
         )
 
         # add subtitles finder job
@@ -397,47 +434,39 @@ class Core(object):
             IntervalTrigger(
                 hours=self.config.subtitle_searcher_freq
             ),
-            name="SUBTITLESEARCHER",
-            id="SUBTITLESEARCHER"
+            name=self.subtitle_searcher.name,
+            id=self.subtitle_searcher.name
         )
 
         # start scheduler service
         self.scheduler.start()
 
-        # Pause/Resume PROPERSEARCHER job
-        (self.scheduler.get_job('PROPERSEARCHER').pause,
-         self.scheduler.get_job('PROPERSEARCHER').resume
-         )[self.config.download_propers]()
-
-        # Pause/Resume TRAKTSEARCHER job
-        (self.scheduler.get_job('TRAKTSEARCHER').pause,
-         self.scheduler.get_job('TRAKTSEARCHER').resume
-         )[self.config.use_trakt]()
-
-        # Pause/Resume SUBTITLESEARCHER job
-        (self.scheduler.get_job('SUBTITLESEARCHER').pause,
-         self.scheduler.get_job('SUBTITLESEARCHER').resume
-         )[self.config.use_subtitles]()
-
-        # Pause/Resume POSTPROCESS job
-        (self.scheduler.get_job('POSTPROCESSOR').pause,
-         self.scheduler.get_job('POSTPROCESSOR').resume
-         )[self.config.process_automatically]()
-
         # start queue's
         self.search_queue.start()
         self.show_queue.start()
         self.postprocessor_queue.start()
 
+        # start upnp client
+        if self.config.enable_upnp:
+            self.upnp_client.start()
+
         # start webserver
         self.wserver.start()
 
+        # start ioloop
+        self.io_loop.start()
+
     def shutdown(self, restart=False):
         if self.started:
             self.log.info('SiCKRAGE IS SHUTTING DOWN!!!')
 
             # shutdown webserver
-            self.wserver.shutdown()
+            if self.wserver:
+                self.wserver.shutdown()
+
+            # shutdown upnp client
+            if self.upnp_client:
+                self.upnp_client.shutdown()
 
             # shutdown show queue
             if self.show_queue:
@@ -466,13 +495,14 @@ class Core(object):
             self.save_all()
 
             # close databases
-            for db in [self.main_db, self.cache_db, self.failed_db]:
+            for db in [self.main_db, self.cache_db]:
                 if db.opened:
                     self.log.debug("Shutting down {} database connection".format(db.name))
                     db.close()
 
             # shutdown logging
-            self.log.close()
+            if self.log:
+                self.log.close()
 
         if restart:
             os.execl(sys.executable, sys.executable, *sys.argv)
@@ -482,6 +512,8 @@ class Core(object):
 
         self.started = False
 
+        self.io_loop.stop()
+
     def save_all(self):
         # write all shows
         self.log.info("Saving all shows to the database")
@@ -499,11 +531,9 @@ class Core(object):
         Populates the showlist with shows from the database
         """
 
-        for dbData in [x['doc'] for x in self.main_db.db.all('tv_shows', with_doc=True)]:
+        for dbData in self.main_db.all('tv_shows'):
             try:
                 self.log.debug("Loading data for show: [{}]".format(dbData['show_name']))
-                show = TVShow(int(dbData['indexer']), int(dbData['indexer_id']))
-                show.nextEpisode()
-                self.showlist += [show]
+                self.showlist += [TVShow(int(dbData['indexer']), int(dbData['indexer_id']))]
             except Exception as e:
-                self.log.error("Show error in [%s]: %s" % (dbData['location'], e.message))
\ No newline at end of file
+                self.log.debug("Show error in [%s]: %s" % (dbData['location'], str(e)))
