@@ -67,6 +67,7 @@ SNATCHED_PROPER = 9  # qualified with quality
 SUBTITLED = 10  # qualified with quality
 FAILED = 11  # episode downloaded or snatched we don't want
 SNATCHED_BEST = 12  # episode redownloaded using best quality
+MISSED = 13  # episode missed
 
 NAMING_REPEAT = 1
 NAMING_EXTEND = 2
@@ -184,9 +185,10 @@ class Quality(object):
     statusPrefixes = {DOWNLOADED: _("Downloaded"),
                       SNATCHED: _("Snatched"),
                       SNATCHED_PROPER: _("Snatched (Proper)"),
-                      FAILED: _("Failed"),
                       SNATCHED_BEST: _("Snatched (Best)"),
-                      ARCHIVED: _("Archived")}
+                      ARCHIVED: _("Archived"),
+                      FAILED: _("Failed"),
+                      MISSED: _("Missed"),}
 
     @staticmethod
     def _getStatusStrings(status):
@@ -216,13 +218,14 @@ class Quality(object):
     def splitQuality(quality):
         anyQualities = []
         bestQualities = []
+
         for curQual in Quality.qualityStrings.keys():
             if curQual & quality:
                 anyQualities.append(curQual)
             if curQual << 16 & quality:
                 bestQualities.append(curQual)
 
-        return (sorted(anyQualities), sorted(bestQualities))
+        return sorted(anyQualities), sorted(bestQualities)
 
     @staticmethod
     def nameQuality(name, anime=False):
@@ -295,20 +298,22 @@ class Quality(object):
         if (check_name(
                 [r"480p|\bweb\b|web.?dl|web(rip|mux|hd)|[sph]d.?tv|dsr|tv(rip|mux)|satrip", r"xvid|divx|[xh].?26[45]"],
                 all)
-            and not check_name([r"(720|1080)[pi]"], all)
-            and not check_name([r"hr.ws.pdtv.[xh].?26[45]"], any)):
+                and not check_name([r"(720|1080)[pi]"], all)
+                and not check_name([r"hr.ws.pdtv.[xh].?26[45]"], any)):
             ret = Quality.SDTV
         elif (check_name([r"dvd(rip|mux)|b[rd](rip|mux)|blue?-?ray", r"xvid|divx|[xh].?26[45]"], all)
               and not check_name([r"(720|1080)[pi]"], all)
               and not check_name([r"hr.ws.pdtv.[xh].?26[45]"], any)):
             ret = Quality.SDDVD
         elif (check_name([r"720p", r"hd.?tv", r"[xh].?26[45]"], all)
+              or check_name([r"720p", r"hevc", r"[xh].?26[45]"], all)
               or check_name([r"hr.ws.pdtv.[xh].?26[45]"], any) and not check_name([r"1080[pi]"], all)):
             ret = Quality.HDTV
         elif (check_name([r"720p|1080i", r"hd.?tv", r"mpeg-?2"], all)
               or check_name([r"1080[pi].hdtv", r"h.?26[45]"], all)):
             ret = Quality.RAWHDTV
-        elif check_name([r"1080p", r"hd.?tv", r"[xh].?26[45]"], all):
+        elif (check_name([r"1080p", r"hd.?tv", r"[xh].?26[45]"], all)
+              or check_name([r"1080p", r"hevc", r"[xh].?26[45]"], all)):
             ret = Quality.FULLHDTV
         elif (check_name([r"720p", r"\bweb\b|web.?dl|web(rip|mux|hd)"], all)
               or check_name([r"720p", r"itunes", r"[xh].?26[45]"], all)):
@@ -349,13 +354,23 @@ class Quality(object):
     def splitCompositeStatus(status):
         """Returns a tuple containing (status, quality)"""
         if status == UNKNOWN:
-            return (UNKNOWN, Quality.UNKNOWN)
+            return UNKNOWN, Quality.UNKNOWN
 
         for q in sorted(Quality.qualityStrings.keys(), reverse=True):
             if status > q * 100:
-                return (status - q * 100, q)
+                return status - q * 100, q
 
-        return (status, Quality.NONE)
+        return status, Quality.NONE
+
+    @staticmethod
+    def statusFromCompositeStatus(status):
+        status, quality = Quality.splitCompositeStatus(status)
+        return status
+
+    @staticmethod
+    def qualityFromCompositeStatus(status):
+        status, quality = Quality.splitCompositeStatus(status)
+        return quality
 
     @staticmethod
     def qualityFromFileMeta(filename):
@@ -476,20 +491,27 @@ class Quality(object):
     DOWNLOADED = None
     SNATCHED = None
     SNATCHED_PROPER = None
-    FAILED = None
     SNATCHED_BEST = None
     ARCHIVED = None
+    FAILED = None
     IGNORED = None
 
 
 Quality.DOWNLOADED = [Quality.compositeStatus(DOWNLOADED, x) for x in Quality.qualityStrings.keys()]
 Quality.SNATCHED = [Quality.compositeStatus(SNATCHED, x) for x in Quality.qualityStrings.keys()]
 Quality.SNATCHED_PROPER = [Quality.compositeStatus(SNATCHED_PROPER, x) for x in Quality.qualityStrings.keys()]
-Quality.FAILED = [Quality.compositeStatus(FAILED, x) for x in Quality.qualityStrings.keys()]
 Quality.SNATCHED_BEST = [Quality.compositeStatus(SNATCHED_BEST, x) for x in Quality.qualityStrings.keys()]
 Quality.ARCHIVED = [Quality.compositeStatus(ARCHIVED, x) for x in Quality.qualityStrings.keys()]
+Quality.FAILED = [Quality.compositeStatus(FAILED, x) for x in Quality.qualityStrings.keys()]
 Quality.IGNORED = [Quality.compositeStatus(IGNORED, x) for x in Quality.qualityStrings.keys()]
 
+Quality.DOWNLOADED.sort()
+Quality.SNATCHED.sort()
+Quality.SNATCHED_BEST.sort()
+Quality.SNATCHED_PROPER.sort()
+Quality.FAILED.sort()
+Quality.ARCHIVED.sort()
+
 HD720p = Quality.combineQualities([Quality.HDTV, Quality.HDWEBDL, Quality.HDBLURAY], [])
 HD1080p = Quality.combineQualities([Quality.FULLHDTV, Quality.FULLHDWEBDL, Quality.FULLHDBLURAY], [])
 UHD_4K = Quality.combineQualities([Quality.UHD_4K_TV, Quality.UHD_4K_WEBDL, Quality.UHD_4K_BLURAY], [])
@@ -553,7 +575,7 @@ class StatusStrings(UserDict):
         the old StatusStrings is fully deprecated, then we will raise a KeyError instead, where appropriate.
         """
         if isinstance(key, int):  # if the key is already an int...
-            if key in self.keys() + Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER + Quality.SNATCHED_BEST + Quality.ARCHIVED:
+            if key in self.keys() + Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER + Quality.SNATCHED_BEST + Quality.ARCHIVED + Quality.FAILED:
                 status, quality = Quality.splitCompositeStatus(key)
                 if quality == Quality.NONE:  # If a Quality is not listed... (shouldn't this be 'if not quality:'?)
                     return self[status]  # ...return the status...
@@ -585,8 +607,7 @@ class StatusStrings(UserDict):
         try:
             # This will raise a ValueError if we can't convert the key to int
             return ((int(key) in self.data) or
-                    (int(
-                        key) in Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER + Quality.SNATCHED_BEST + Quality.ARCHIVED))
+                    (int(key) in Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER + Quality.SNATCHED_BEST + Quality.ARCHIVED + Quality.FAILED))
         except ValueError:  # The key is not numeric and since we only want numeric keys...
             # ...and we don't want this function to fail...
             pass  # ...suppress the ValueError and do nothing, the key does not exist
@@ -595,27 +616,29 @@ class StatusStrings(UserDict):
 statusStrings = StatusStrings({UNKNOWN: _("Unknown"),
                                UNAIRED: _("Unaired"),
                                SNATCHED: _("Snatched"),
+                               SNATCHED_PROPER: _("Snatched (Proper)"),
+                               SNATCHED_BEST: _("Snatched (Best)"),
                                DOWNLOADED: _("Downloaded"),
                                SKIPPED: _("Skipped"),
-                               SNATCHED_PROPER: _("Snatched (Proper)"),
                                WANTED: _("Wanted"),
                                ARCHIVED: _("Archived"),
                                IGNORED: _("Ignored"),
                                SUBTITLED: _("Subtitled"),
                                FAILED: _("Failed"),
-                               SNATCHED_BEST: _("Snatched (Best)")})
+                               MISSED: _("Missed")})
 
 
 class Overview(object):
     UNAIRED = UNAIRED  # 1
-    QUAL = 2
+    SNATCHED = SNATCHED  # 2
     WANTED = WANTED  # 3
-    GOOD = 4
+    GOOD = DOWNLOADED  # 4
     SKIPPED = SKIPPED  # 5
-    MISSED = 6  # 6
+    SNATCHED_PROPER = SNATCHED_PROPER  # 9
+    SNATCHED_BEST = SNATCHED_BEST  # 12
+    MISSED = MISSED  # 13
 
-    # For both snatched statuses. Note: SNATCHED/QUAL have same value and break dict.
-    SNATCHED = SNATCHED_PROPER = SNATCHED_BEST  # 9
+    QUAL = 50
 
     overviewStrings = {SKIPPED: "skipped",
                        WANTED: "wanted",
@@ -623,6 +646,8 @@ class Overview(object):
                        GOOD: "good",
                        UNAIRED: "unaired",
                        SNATCHED: "snatched",
+                       SNATCHED_BEST: "snatched",
+                       SNATCHED_PROPER: "snatched",
                        MISSED: "missed"}
 
 
