@@ -21,9 +21,11 @@ from __future__ import unicode_literals
 import os
 
 import sickrage
+from sickrage.core.common import Quality
 from sickrage.core.databases import srDatabase
 from sickrage.core.databases.cache.index import CacheLastUpdateIndex, CacheLastSearchIndex, CacheSceneExceptionsIndex, \
     CacheSceneNamesIndex, CacheNetworkTimezonesIndex, CacheSceneExceptionsRefreshIndex, CacheProvidersIndex
+from sickrage.core.helpers import validate_url, is_ip_private
 
 
 class CacheDB(srDatabase):
@@ -50,9 +52,13 @@ class CacheDB(srDatabase):
         super(CacheDB, self).__init__(name)
         self.old_db_path = os.path.join(sickrage.app.data_dir, 'cache.db')
 
-    def check_versions(self, index_name, current_version, previous_version):
-        # Wipe table if versions are different
-        if previous_version < current_version:
-            for x in self.db.all(index_name, with_doc=True):
-                self.db.delete(x['doc'])
-        super(CacheDB, self).check_versions(index_name, current_version, previous_version)
+    def cleanup(self):
+        self.cleanup_provider_cache()
+
+    def cleanup_provider_cache(self):
+        for item in self.all('providers'):
+            if int(item["quality"]) == Quality.UNKNOWN:
+                self.delete(item)
+            elif not validate_url(item["url"]) and not item["url"].startswith("magnet") \
+                    or is_ip_private(item["url"].split(r'//')[-1].split(r'/')[0]):
+                self.delete(item)
