@@ -38,6 +38,7 @@ import urlparse
 import uuid
 import webbrowser
 import zipfile
+from collections import OrderedDict
 from contextlib import contextmanager
 
 import rarfile
@@ -168,77 +169,77 @@ def remove_non_release_groups(name):
     # Check your database for funky release_names and add them here, to improve failed handling, archiving, and history.
     # select release_name from tv_episodes WHERE LENGTH(release_name);
     # [eSc], [SSG], [GWC] are valid release groups for non-anime
-    removeWordsList = {
-        r'\[rartv\]$': 'searchre',
-        r'\[rarbg\]$': 'searchre',
-        r'\.\[eztv\]$': 'searchre',
-        r'\[eztv\]$': 'searchre',
-        r'\[ettv\]$': 'searchre',
-        r'\[cttv\]$': 'searchre',
-        r'\.\[vtv\]$': 'searchre',
-        r'\[vtv\]$': 'searchre',
-        r'\[EtHD\]$': 'searchre',
-        r'\[GloDLS\]$': 'searchre',
-        r'\[silv4\]$': 'searchre',
-        r'\[Seedbox\]$': 'searchre',
-        r'\[PublicHD\]$': 'searchre',
-        r'\.\[PublicHD\]$': 'searchre',
-        r'\.\[NO.RAR\]$': 'searchre',
-        r'\[NO.RAR\]$': 'searchre',
-        r'-\=\{SPARROW\}\=-$': 'searchre',
-        r'\=\{SPARR$': 'searchre',
-        r'\.\[720P\]\[HEVC\]$': 'searchre',
-        r'\[AndroidTwoU\]$': 'searchre',
-        r'\[brassetv\]$': 'searchre',
-        r'\[Talamasca32\]$': 'searchre',
-        r'\(musicbolt\.com\)$': 'searchre',
-        r'\.\(NLsub\)$': 'searchre',
-        r'\(NLsub\)$': 'searchre',
-        r'\.\[BT\]$': 'searchre',
-        r' \[1044\]$': 'searchre',
-        r'\.RiPSaLoT$': 'searchre',
-        r'\.GiuseppeTnT$': 'searchre',
-        r'\.Renc$': 'searchre',
-        r'\.gz$': 'searchre',
-        r'\.English$': 'searchre',
-        r'\.German$': 'searchre',
-        r'\.\.Italian$': 'searchre',
-        r'\.Italian$': 'searchre',
-        r'(?<![57])\.1$': 'searchre',
-        r'-NZBGEEK$': 'searchre',
-        r'-Siklopentan$': 'searchre',
-        r'-Chamele0n$': 'searchre',
-        r'-Obfuscated$': 'searchre',
-        r'-BUYMORE$': 'searchre',
-        r'-\[SpastikusTV\]$': 'searchre',
-        r'-RP$': 'searchre',
-        r'-20-40$': 'searchre',
-        r'\.\[www\.usabit\.com\]$': 'searchre',
-        r'^\[www\.Cpasbien\.pe\] ': 'searchre',
-        r'^\[www\.Cpasbien\.com\] ': 'searchre',
-        r'^\[ www\.Cpasbien\.pw \] ': 'searchre',
-        r'^\.www\.Cpasbien\.pw': 'searchre',
-        r'^\[www\.newpct1\.com\]': 'searchre',
-        r'^\[ www\.Cpasbien\.com \] ': 'searchre',
-        r'- \{ www\.SceneTime\.com \}$': 'searchre',
-        r'^\{ www\.SceneTime\.com \} - ': 'searchre',
-        r'^\]\.\[www\.tensiontorrent.com\] - ': 'searchre',
-        r'^\]\.\[ www\.tensiontorrent.com \] - ': 'searchre',
-        r'- \[ www\.torrentday\.com \]$': 'searchre',
-        r'^\[ www\.TorrentDay\.com \] - ': 'searchre',
-        r'\[NO-RAR\] - \[ www\.torrentday\.com \]$': 'searchre',
-        r'^www\.Torrenting\.com\.-\.': 'searchre',
-        r'-Scrambled$': 'searchre'
-    }
+    removeWordsList = OrderedDict([
+        (r'^\[www\.Cpasbien\.pe\] ', 'searchre'),
+        (r'^\[www\.Cpasbien\.com\] ', 'searchre'),
+        (r'^\[ www\.Cpasbien\.pw \] ', 'searchre'),
+        (r'^\.www\.Cpasbien\.pw', 'searchre'),
+        (r'^\[www\.newpct1\.com\]', 'searchre'),
+        (r'^\[ www\.Cpasbien\.com \] ', 'searchre'),
+        (r'^\{ www\.SceneTime\.com \} - ', 'searchre'),
+        (r'^\]\.\[www\.tensiontorrent.com\] - ', 'searchre'),
+        (r'^\]\.\[ www\.tensiontorrent.com \] - ', 'searchre'),
+        (r'^\[ www\.TorrentDay\.com \] - ', 'searchre'),
+        (r'^www\.Torrenting\.com\.-\.', 'searchre'),
+        (r'\[rartv\]$', 'searchre'),
+        (r'\[rarbg\]$', 'searchre'),
+        (r'\.\[eztv\]$', 'searchre'),
+        (r'\[eztv\]$', 'searchre'),
+        (r'\[ettv\]$', 'searchre'),
+        (r'\[cttv\]$', 'searchre'),
+        (r'\.\[vtv\]$', 'searchre'),
+        (r'\[vtv\]$', 'searchre'),
+        (r'\[EtHD\]$', 'searchre'),
+        (r'\[GloDLS\]$', 'searchre'),
+        (r'\[silv4\]$', 'searchre'),
+        (r'\[Seedbox\]$', 'searchre'),
+        (r'\[PublicHD\]$', 'searchre'),
+        (r'\.\[PublicHD\]$', 'searchre'),
+        (r'\.\[NO.RAR\]$', 'searchre'),
+        (r'\[NO.RAR\]$', 'searchre'),
+        (r'-\=\{SPARROW\}\=-$', 'searchre'),
+        (r'\=\{SPARR$', 'searchre'),
+        (r'\.\[720P\]\[HEVC\]$', 'searchre'),
+        (r'\[AndroidTwoU\]$', 'searchre'),
+        (r'\[brassetv\]$', 'searchre'),
+        (r'\[Talamasca32\]$', 'searchre'),
+        (r'\(musicbolt\.com\)$', 'searchre'),
+        (r'\.\(NLsub\)$', 'searchre'),
+        (r'\(NLsub\)$', 'searchre'),
+        (r'\.\[BT\]$', 'searchre'),
+        (r' \[1044\]$', 'searchre'),
+        (r'\.RiPSaLoT$', 'searchre'),
+        (r'\.GiuseppeTnT$', 'searchre'),
+        (r'\.Renc$', 'searchre'),
+        (r'\.gz$', 'searchre'),
+        (r'\.English$', 'searchre'),
+        (r'\.German$', 'searchre'),
+        (r'\.\.Italian$', 'searchre'),
+        (r'\.Italian$', 'searchre'),
+        (r'(?<![57])\.1$', 'searchre'),
+        (r'-NZBGEEK$', 'searchre'),
+        (r'-Siklopentan$', 'searchre'),
+        (r'-Chamele0n$', 'searchre'),
+        (r'-Obfuscated$', 'searchre'),
+        (r'-BUYMORE$', 'searchre'),
+        (r'-\[SpastikusTV\]$', 'searchre'),
+        (r'-RP$', 'searchre'),
+        (r'-20-40$', 'searchre'),
+        (r'\.\[www\.usabit\.com\]$', 'searchre'),
+        (r'\[NO-RAR\] - \[ www\.torrentday\.com \]$', 'searchre'),
+        (r'- \[ www\.torrentday\.com \]$', 'searchre'),
+        (r'- \{ www\.SceneTime\.com \}$', 'searchre'),
+        (r'-Scrambled$', 'searchre')
+    ])
 
     _name = name
-    for remove_string, remove_type in removeWordsList.items():
+    for remove_string, remove_type in six.iteritems(removeWordsList):
         if remove_type == 'search':
             _name = _name.replace(remove_string, '')
         elif remove_type == 'searchre':
             _name = re.sub(r'(?i)' + remove_string, '', _name)
 
-    return _name.strip('.- []{}')
+    return _name
 
 
 def replaceExtension(filename, newExt):
@@ -261,18 +262,20 @@ def replaceExtension(filename, newExt):
         return sepFile[0] + "." + newExt
 
 
-def notTorNZBFile(filename):
+def is_torrent_or_nzb_file(filename):
     """
-    Returns true if filename is not a NZB nor Torrent file
-
-    :param filename: Filename to check
-    :return: True if filename is not a NZB nor Torrent
+    Check if the provided ``filename`` is a NZB file or a torrent file, based on its extension.
+    :param filename: The filename to check
+    :return: ``True`` if the ``filename`` is a NZB file or a torrent file, ``False`` otherwise
     """
 
-    return not (filename.endswith(".torrent") or filename.endswith(".nzb"))
+    if not isinstance(filename, six.string_types):
+        return False
+
+    return filename.rpartition('.')[2].lower() in ['nzb', 'torrent']
 
 
-def isSyncFile(filename):
+def is_sync_file(filename):
     """
     Returns true if filename is a syncfile, indicating filesystem may be in flux
 
@@ -289,7 +292,7 @@ def isSyncFile(filename):
         return False
 
 
-def isMediaFile(filename):
+def is_media_file(filename):
     """
     Check if named file may contain media
 
@@ -314,13 +317,9 @@ def isMediaFile(filename):
     if re.search('extras?$', sepFile[0], re.I):
         return False
 
-    if sepFile[2].lower() in mediaExtensions:
-        return True
-    else:
-        return False
+    return sepFile[-1].lower() in mediaExtensions
 
-
-def isRarFile(filename):
+def is_rar_file(filename):
     """
     Check if file is a RAR file, or part of a RAR set
 
@@ -374,7 +373,7 @@ def remove_file_failed(failed_file):
         pass
 
 
-def findCertainShow(showList, indexerid):
+def findCertainShow(indexerid):
     """
     Find a show by indexer ID in the show list
 
@@ -383,11 +382,11 @@ def findCertainShow(showList, indexerid):
     :return: result list
     """
 
-    if not indexerid or not showList:
+    if not indexerid:
         return None
 
     indexer_ids = [indexerid] if not isinstance(indexerid, list) else indexerid
-    results = [show for show in showList if show.indexerid in indexer_ids]
+    results = [show for show in sickrage.app.showlist if show.indexerid in indexer_ids]
 
     if not results:
         return None
@@ -434,7 +433,7 @@ def list_media_files(path):
         if os.path.isdir(fullCurFile) and not curFile.startswith('.') and not curFile == 'Extras':
             files += list_media_files(fullCurFile)
 
-        elif isMediaFile(curFile):
+        elif is_media_file(curFile):
             files.append(fullCurFile)
 
     return files
@@ -451,7 +450,7 @@ def copyFile(srcFile, destFile):
     try:
         shutil.copyfile(srcFile, destFile)
     except Exception as e:
-        sickrage.app.log.warning(e.message)
+        sickrage.app.log.warning(str(e))
     else:
         try:
             shutil.copymode(srcFile, destFile)
@@ -470,7 +469,7 @@ def moveFile(srcFile, destFile):
     try:
         shutil.move(srcFile, destFile)
         fixSetGroupID(destFile)
-    except OSError as e:
+    except OSError:
         copyFile(srcFile, destFile)
         os.unlink(srcFile)
 
@@ -504,7 +503,7 @@ def hardlinkFile(srcFile, destFile):
         fixSetGroupID(destFile)
     except Exception as e:
         sickrage.app.log.warning("Failed to create hardlink of %s at %s. Error: %r. Copying instead"
-                                         % (srcFile, destFile, e))
+                                 % (srcFile, destFile, e))
         copyFile(srcFile, destFile)
 
 
@@ -539,7 +538,7 @@ def moveAndSymlinkFile(srcFile, destFile):
         symlink(destFile, srcFile)
     except Exception as e:
         sickrage.app.log.warning("Failed to create symlink of %s at %s. Error: %r. Copying instead"
-                                         % (srcFile, destFile, e))
+                                 % (srcFile, destFile, e))
         copyFile(srcFile, destFile)
 
 
@@ -655,8 +654,7 @@ def chmodAsParent(childPath):
     parentPath = os.path.dirname(childPath)
 
     if not parentPath:
-        sickrage.app.log.debug(
-            "No parent path provided in " + childPath + ", unable to get permissions from it")
+        sickrage.app.log.debug("No parent path provided in " + childPath + ", unable to get permissions from it")
         return
 
     childPath = os.path.join(parentPath, os.path.basename(childPath))
@@ -676,17 +674,15 @@ def chmodAsParent(childPath):
         return
 
     childPath_owner = childPathStat.st_uid
-    user_id = os.geteuid()  # @UndefinedVariable - only available on UNIX
+    user_id = os.geteuid()
 
     if user_id != 0 and user_id != childPath_owner:
-        sickrage.app.log.debug(
-            "Not running as root or owner of " + childPath + ", not trying to set permissions")
+        sickrage.app.log.debug("Not running as root or owner of " + childPath + ", not trying to set permissions")
         return
 
     try:
         os.chmod(childPath, childMode)
-        sickrage.app.log.debug(
-            "Setting permissions for %s to %o as parent directory has %o" % (childPath, childMode, parentMode))
+        sickrage.app.log.debug("Setting permissions for %s to %o as parent directory has %o" % (childPath, childMode, parentMode))
     except OSError:
         sickrage.app.log.debug("Failed to set permission for %s to %o" % (childPath, childMode))
 
@@ -717,20 +713,18 @@ def fixSetGroupID(childPath):
             return
 
         childPath_owner = childStat.st_uid
-        user_id = os.geteuid()  # @UndefinedVariable - only available on UNIX
+        user_id = os.geteuid()
 
         if user_id != 0 and user_id != childPath_owner:
-            sickrage.app.log.debug(
-                "Not running as root or owner of " + childPath + ", not trying to set the set-group-ID")
+            sickrage.app.log.debug("Not running as root or owner of {}, not trying to set the set-group-ID".format(childPath))
             return
 
         try:
             os.chown(childPath, -1, parentGID)  # @UndefinedVariable - only available on UNIX
-            sickrage.app.log.debug("Respecting the set-group-ID bit on the parent directory for %s" % childPath)
+            sickrage.app.log.debug("Respecting the set-group-ID bit on the parent directory for {}".format(childPath))
         except OSError:
-            sickrage.app.log.error(
-                "Failed to respect the set-group-ID bit on the parent directory for %s (setting group ID %i)" % (
-                    childPath, parentGID))
+            sickrage.app.log.error("Failed to respect the set-group-ID bit on the parent directory for {} (setting "
+                                   "group ID {})".format(childPath, parentGID))
 
 
 def sanitizeSceneName(name, anime=False):
@@ -770,8 +764,8 @@ def create_https_certificates(ssl_cert, ssl_key):
     try:
         import OpenSSL
     except ImportError:
-        sickrage.app.log.error(
-            "OpenSSL not available, please install for better requests validation: `https://pyopenssl.readthedocs.org/en/latest/install.html`")
+        sickrage.app.log.warning("OpenSSL not available, please install for better requests validation: "
+                                 "`https://pyopenssl.readthedocs.org/en/latest/install.html`")
         return False
 
     # Check happens if the certificate and key pair already exists for a domain
@@ -817,7 +811,7 @@ def create_https_certificates(ssl_cert, ssl_key):
             with io.open(ssl_cert, 'w') as certout:
                 certout.write(OpenSSL.crypto.dump_certificate(OpenSSL.crypto.FILETYPE_PEM, cert))
         except Exception:
-            sickrage.app.log.error("Error creating SSL key and certificate")
+            sickrage.app.log.warning("Error creating SSL key and certificate")
             return False
 
     return True
@@ -931,7 +925,7 @@ def create_zipfile(fileList, archive, arcname=None):
                 z.write(f, os.path.relpath(f, arcname))
         return True
     except Exception as e:
-        sickrage.app.log.error("Zip creation error: {} ".format(e.message))
+        sickrage.app.log.error("Zip creation error: {} ".format(e))
         return False
 
 
@@ -957,7 +951,7 @@ def restoreConfigZip(archive, targetDir, restore_database=True, restore_config=T
 
         with zipfile.ZipFile(archive, 'r', allowZip64=True) as zip_file:
             for member in zip_file.namelist():
-                if not restore_database and member.split('/')[0] in ['database', 'db_backup']:
+                if not restore_database and member.split('/')[0] == 'database':
                     continue
 
                 if not restore_config and member.split('/')[0] == 'config.ini':
@@ -970,7 +964,7 @@ def restoreConfigZip(archive, targetDir, restore_database=True, restore_config=T
 
         return True
     except Exception as e:
-        sickrage.app.log.error("Zip extraction error: {}".format(e.message))
+        sickrage.app.log.error("Zip extraction error: {}".format(e))
         shutil.rmtree(targetDir)
 
 
@@ -985,17 +979,7 @@ def backupSR(backupDir, keep_latest=False):
     def _keep_latest_backup():
         import glob
 
-        _files = glob.glob(os.path.join(backupDir, '*.zip'))
-
-        now = time.time()
-        newest = _files[0], now - os.path.getctime(_files[0])
-        for f in _files[1:]:
-            age = now - os.path.getctime(f)
-            if age < newest[1]:
-                newest = f, age
-        _files.remove(newest[0])
-
-        for f in _files:
+        for f in sorted(glob.glob(os.path.join(backupDir, '*.zip')), key=os.path.getctime, reverse=True)[1:]:
             os.remove(f)
 
     if keep_latest:
@@ -1012,11 +996,6 @@ def backupSR(backupDir, keep_latest=False):
         for filename in files:
             source += [os.path.join(path, filename)]
 
-    # db_backup folder
-    for (path, __, files) in os.walk(os.path.join(sickrage.app.data_dir, 'db_backup'), topdown=True):
-        for filename in files:
-            source += [os.path.join(path, filename)]
-
     # cache folder
     if sickrage.app.cache_dir:
         for (path, dirs, files) in os.walk(sickrage.app.cache_dir, topdown=True):
@@ -1061,15 +1040,6 @@ def restoreSR(srcDir, dstDir):
                                                                                     '%Y%m%d_%H%M%S'))))
             moveFile(os.path.join(srcDir, 'database'), dstDir)
 
-        # databse backups
-        if os.path.exists(os.path.join(srcDir, 'db_backup')):
-            if os.path.exists(os.path.join(dstDir, 'db_backup')):
-                moveFile(os.path.join(dstDir, 'db_backup'), os.path.join(dstDir, '{}.bak-{}'
-                                                                         .format('db_backup',
-                                                                                 datetime.datetime.now().strftime(
-                                                                                     '%Y%m%d_%H%M%S'))))
-            moveFile(os.path.join(srcDir, 'db_backup'), dstDir)
-
         # cache
         if os.path.exists(os.path.join(srcDir, 'cache')):
             if os.path.exists(os.path.join(dstDir, 'cache')):
@@ -1120,7 +1090,7 @@ def get_size(start_path='.'):
                 try:
                     total_size += os.path.getsize(fp)
                 except OSError as e:
-                    sickrage.app.log.error("Unable to get size for file %s Error: %r" % (fp, e))
+                    sickrage.app.log.warning("Unable to get size for file %s Error: %r" % (fp, e))
                     sickrage.app.log.debug(traceback.format_exc())
     except Exception as e:
         pass
@@ -1147,16 +1117,34 @@ def generateApiKey():
     m.update(r)
 
     # Return a hex digest of the md5, eg 49f68a5c8493ec2c0bf489821c21fc3b
-    sickrage.app.log.debug("New API key generated")
     return m.hexdigest()
 
 
-def pretty_filesize(file_bytes):
-    """Return humanly formatted sizes from bytes"""
-    for mod in ['B', 'KB', 'MB', 'GB', 'TB', 'PB']:
-        if file_bytes < 1024.00:
-            return "%3.2f %s" % (file_bytes, mod)
-        file_bytes /= 1024.00
+def pretty_filesize(size, use_decimal=False, **kwargs):
+    """
+    Return a human readable representation of the provided ``size``.
+
+    :param size: The size to convert
+    :param use_decimal: use decimal instead of binary prefixes (e.g. kilo = 1000 instead of 1024)
+
+    :keyword units: A list of unit names in ascending order.
+        Default units: ['B', 'KB', 'MB', 'GB', 'TB', 'PB']
+
+    :return: The converted size
+    """
+    try:
+        size = max(float(size), 0.)
+    except (ValueError, TypeError):
+        size = 0.
+
+    remaining_size = size
+    units = kwargs.pop('units', ['B', 'KB', 'MB', 'GB', 'TB', 'PB'])
+    block = 1024. if not use_decimal else 1000.
+    for unit in units:
+        if remaining_size < block:
+            return '{0:3.2f} {1}'.format(remaining_size, unit)
+        remaining_size /= block
+    return size
 
 
 def remove_article(text=''):
@@ -1165,7 +1153,7 @@ def remove_article(text=''):
     return re.sub(r'(?i)^(?:(?:A(?!\s+to)n?)|The)\s(\w)', r'\1', text)
 
 
-def generateCookieSecret():
+def generate_secret():
     """Generate a new cookie secret"""
 
     return base64.b64encode(uuid.uuid4().bytes + uuid.uuid4().bytes)
@@ -1201,7 +1189,7 @@ def verify_freespace(src, dest, oldfile=None):
                 fun = ctypes.windll.kernel32.GetDiskFreeSpaceExW
             else:
                 fun = ctypes.windll.kernel32.GetDiskFreeSpaceExA
-            ret = fun(path, ctypes.byref(_), ctypes.byref(total), ctypes.byref(free))
+            ret = fun(path, ctypes.byref(__), ctypes.byref(total), ctypes.byref(free))
             if ret == 0:
                 sickrage.app.log.warning("Unable to determine free space, something went wrong")
                 raise ctypes.WinError()
@@ -1231,8 +1219,8 @@ def verify_freespace(src, dest, oldfile=None):
         return True
     else:
         sickrage.app.log.warning("Not enough free space: Needed: %s bytes ( %s ), found: %s bytes ( %s )"
-                                         % (neededspace, pretty_filesize(neededspace), diskfree,
-                                            pretty_filesize(diskfree)))
+                                 % (neededspace, pretty_filesize(neededspace), diskfree,
+                                    pretty_filesize(diskfree)))
         return False
 
 
@@ -1366,12 +1354,12 @@ def restoreVersionedFile(backup_file, version):
 
     try:
         sickrage.app.log.debug("Trying to backup %s to %s.r%s before restoring backup"
-                                       % (new_file, new_file, version))
+                               % (new_file, new_file, version))
 
         moveFile(new_file, new_file + '.' + 'r' + str(version))
     except Exception as e:
         sickrage.app.log.warning("Error while trying to backup file %s before proceeding with restore: %r"
-                                         % (restore_file, e))
+                                 % (restore_file, e))
         return False
 
     while not os.path.isfile(new_file):
@@ -1500,7 +1488,7 @@ def convert_size(size, default=0, units=None):
 
 
 def randomString(size=8, chars=string.ascii_uppercase + string.digits):
-    return ''.join(random.choice(chars) for x in range(size))
+    return ''.join(random.choice(chars) for x in xrange(size))
 
 
 def clean_url(url):
@@ -1509,6 +1497,8 @@ def clean_url(url):
     or an empty string
     """
 
+    urlparse.uses_netloc.append('scgi')
+
     if url and url.strip():
 
         url = url.strip()
@@ -1530,7 +1520,6 @@ def clean_url(url):
 
 
 def overall_stats():
-    shows = sickrage.app.showlist
     today = str(datetime.date.today().toordinal())
 
     downloaded_status = Quality.DOWNLOADED + Quality.ARCHIVED
@@ -1544,13 +1533,14 @@ def overall_stats():
             'total': 0,
         },
         'shows': {
-            'active': len([show for show in shows if show.paused == 0 and show.status.lower() == 'continuing']),
-            'total': len(shows),
+            'active': len([show for show in sickrage.app.showlist
+                           if show.paused == 0 and show.status.lower() == 'continuing']),
+            'total': len(sickrage.app.showlist),
         },
         'total_size': 0
     }
 
-    for result in [x['doc'] for x in sickrage.app.main_db.db.all('tv_episodes', with_doc=True)]:
+    for result in sickrage.app.main_db.all('tv_episodes'):
         if not (result['season'] > 0 and result['episode'] > 0 and result['airdate'] > 1):
             continue
 
@@ -1604,12 +1594,16 @@ def validate_url(value):
     return (True, False)[not re.compile(regex.format(tld=r'\.[a-z]{2,10}')).match(value)]
 
 
-def torrent_webui_url():
+def torrent_webui_url(reset=False):
+    if not reset:
+        return sickrage.app.client_web_urls.get('torrent', '')
+
     if not sickrage.app.config.use_torrents or \
             not sickrage.app.config.torrent_host.lower().startswith('http') or \
-                    sickrage.app.config.torrent_method == 'blackhole' or sickrage.app.config.enable_https and \
+            sickrage.app.config.torrent_method == 'blackhole' or sickrage.app.config.enable_https and \
             not sickrage.app.config.torrent_host.lower().startswith('https'):
-        return ''
+        sickrage.app.client_web_urls['torrent'] = ''
+        return sickrage.app.client_web_urls['torrent']
 
     torrent_ui_url = re.sub('localhost|127.0.0.1', sickrage.app.config.web_host or get_lan_ip(),
                             sickrage.app.config.torrent_host or '', re.I)
@@ -1627,7 +1621,9 @@ def torrent_webui_url():
         if test_exists(urlparse.urljoin(torrent_ui_url, 'download/')):
             torrent_ui_url = urlparse.urljoin(torrent_ui_url, 'download/')
 
-    return ('', torrent_ui_url)[test_exists(torrent_ui_url)]
+    sickrage.app.client_web_urls['torrent'] = ('', torrent_ui_url)[test_exists(torrent_ui_url)]
+
+    return sickrage.app.client_web_urls['torrent']
 
 
 def checkbox_to_value(option, value_on=True, value_off=False):
@@ -1702,3 +1698,38 @@ def clean_hosts(hosts, default_port=None):
         cleaned_hosts = ''
 
     return cleaned_hosts
+
+
+def glob_escape(pathname):
+    """
+    Escape all special characters.
+    """
+
+    MAGIC_CHECK = re.compile(r'([*?[])')
+    MAGIC_CHECK_BYTES = re.compile(r'([*?[])')
+
+    drive, pathname = os.path.splitdrive(pathname)
+    if isinstance(pathname, bytes):
+        pathname = MAGIC_CHECK_BYTES.sub(r'[\1]', pathname)
+    else:
+        pathname = MAGIC_CHECK.sub(r'[\1]', pathname)
+
+    return drive + pathname
+
+
+def memory_usage():
+    try:
+        try:
+            import psutil
+            p = psutil.Process(sickrage.app.pid)
+            return pretty_filesize(int(p.memory_info().rss))
+        except ImportError:
+            try:
+                import resource
+                return pretty_filesize(int(resource.getrusage(resource.RUSAGE_SELF).ru_maxrss) * 1024)
+            except ImportError:
+                pass
+    except Exception:
+        pass
+
+    return 'unknown'
