@@ -25,6 +25,7 @@ import re
 
 import sickrage
 from sickrage.core.helpers import bs4_parser
+from sickrage.core.websession import WebSession
 
 
 class imdbPopular(object):
@@ -47,7 +48,7 @@ class imdbPopular(object):
         popular_shows = []
 
         try:
-            data = sickrage.app.wsession.get(self.url,
+            data = WebSession().get(self.url,
                                                     headers={'Referer': 'http://akas.imdb.com/'},
                                                     params=self.params).text
         except Exception:
@@ -124,4 +125,4 @@ class imdbPopular(object):
         full_path = os.path.join(path, os.path.basename(image_url))
 
         if not os.path.isfile(full_path):
-            sickrage.app.wsession.download(image_url, full_path)
+            WebSession().download(image_url, full_path)
