@@ -43,10 +43,9 @@ class NameParser(object):
     NORMAL_REGEX = 1
     ANIME_REGEX = 2
 
-    def __init__(self, file_name=True, showObj=None, tryIndexers=False, naming_pattern=False, validate_show=True):
+    def __init__(self, file_name=True, showObj=None, naming_pattern=False, validate_show=True):
         self.file_name = file_name
         self.showObj = showObj
-        self.tryIndexers = tryIndexers
         self.naming_pattern = naming_pattern
         self.validate_show = validate_show
 
@@ -59,43 +58,50 @@ class NameParser(object):
 
     def get_show(self, name):
         show = None
-        show_id = 0
-        fromCache = False
+        show_id = None
 
-        if not all([name, sickrage.app.showlist]): return show, show_id
+        if not all([name, sickrage.app.showlist]):
+            return show, show_id
 
-        try:
-            # check cache for show
-            cache = sickrage.app.name_cache.get(name)
-            if cache:
-                fromCache = True
-                show_id = cache
+        def cache_lookup(name):
+            return sickrage.app.name_cache.get(name)
 
-            # try indexers
-            if not show_id and self.tryIndexers:
-                try:
-                    show_id1 = int(IndexerApi().searchForShowID(full_sanitizeSceneName(name))[2])
-                    show_id2 = int(srTraktAPI()['search'].query(full_sanitizeSceneName(name), 'show')[0].ids['tvdb'])
-                    show_id = (show_id, show_id1)[show_id1 == show_id2]
-                except Exception:
-                    pass
+        def scene_exception_lookup(name):
+            return get_scene_exception_by_name(name)[0]
 
-            # try scene exceptions
-            if not show_id:
-                try:
-                    show_id = get_scene_exception_by_name(name)[0]
-                except Exception:
-                    pass
+        def indexer_lookup(name):
+            show_id1 = int(IndexerApi().searchForShowID(full_sanitizeSceneName(name))[2])
+            show_id2 = int(srTraktAPI()['search'].query(full_sanitizeSceneName(name), 'show')[0].ids['tvdb'])
+            return (None, show_id1)[show_id1 == show_id2]
 
-            # create show object
-            show = findCertainShow(sickrage.app.showlist, int(show_id)) if show_id else None
+        lookup_list = [
+            lambda: cache_lookup(name),
+            lambda: scene_exception_lookup(name),
+            lambda: indexer_lookup(name),
+        ]
 
-            # add show to cache
-            if show and not fromCache:
-                sickrage.app.name_cache.put(name, show.indexerid)
-        except Exception as e:
-            sickrage.app.log.debug(
-                "Error when attempting to find show: %s in SiCKRAGE. Error: %r " % (name, repr(e)))
+        # lookup show id
+        for lookup in lookup_list:
+            if show or show_id is not None:
+                continue
+
+            try:
+                show_id = int(lookup())
+                if show_id == 0:
+                    continue
+
+                sickrage.app.name_cache.put(name, show_id)
+                if self.validate_show:
+                    show = findCertainShow(show_id)
+                else:
+                    from sickrage.core.tv.show import TVShow
+                    show = TVShow(1, show_id)
+            except Exception:
+                pass
+
+        if show_id is None:
+            # ignore show name by caching it with a indexerid of 0
+            sickrage.app.name_cache.put(name, 0)
 
         return show, show_id or 0
 
@@ -154,7 +160,7 @@ class NameParser(object):
                 continue
 
             result = ParseResult(name)
-            result.which_regex = [cur_regex_name]
+            result.which_regex = {cur_regex_name}
             result.score = 0 - cur_regex_num
 
             named_groups = match.groupdict().keys()
@@ -248,9 +254,12 @@ class NameParser(object):
                 bestResult.show, bestResult.indexerid = self.get_show(bestResult.series_name)
 
                 # confirm passed in show object indexer id matches result show object indexer id
-                if (bestResult.show and self.showObj) and bestResult.show.indexerid != self.showObj.indexerid:
-                    bestResult.show = None
-                    bestResult.indexerid = 0
+                if self.showObj and bestResult.show:
+                    if self.showObj.indexerid == bestResult.show.indexerid:
+                        bestResult.show = self.showObj
+                    else:
+                        bestResult.show = None
+                        bestResult.indexerid = 0
 
             # if this is a naming pattern test or result doesn't have a show object then return best result
             if not bestResult.show or self.naming_pattern:
@@ -267,9 +276,8 @@ class NameParser(object):
             if bestResult.is_air_by_date:
                 airdate = bestResult.air_date.toordinal()
 
-                dbData = [x['doc'] for x in
-                          sickrage.app.main_db.db.get_many('tv_episodes', bestResult.show.indexerid, with_doc=True)
-                          if x['doc']['indexer'] == bestResult.show.indexer and x['doc']['airdate'] == airdate]
+                dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', bestResult.show.indexerid)
+                          if x['indexer'] == bestResult.show.indexer and x['airdate'] == airdate]
 
                 season_number = None
                 episode_numbers = []
@@ -278,7 +286,7 @@ class NameParser(object):
                     season_number = int(dbData[0]['season'])
                     episode_numbers = [int(dbData[0]['episode'])]
 
-                if not season_number or not len(episode_numbers):
+                if not season_number or not episode_numbers:
                     try:
                         lINDEXER_API_PARMS = IndexerApi(bestResult.show.indexer).api_params.copy()
 
@@ -292,8 +300,9 @@ class NameParser(object):
                         season_number = int(epObj["airedseason"])
                         episode_numbers = [int(epObj["airedepisodenumber"])]
                     except indexer_episodenotfound:
-                        sickrage.app.log.warning(
-                            "Unable to find episode with date " + bestResult.air_date + " for show " + bestResult.show.name + ", skipping")
+                        sickrage.app.log.warning("Unable to find episode with date {air_date} for show {show_name}, "
+                                                 "skipping".format(air_date=bestResult.air_date,
+                                                                   show_name=bestResult.show.name))
                         episode_numbers = []
                     except indexer_error as e:
                         sickrage.app.log.warning(
@@ -470,8 +479,7 @@ class NameParser(object):
         final_result.air_date = self._combine_results(file_name_result, dir_name_result, 'air_date')
 
         # anime absolute numbers
-        final_result.ab_episode_numbers = self._combine_results(file_name_result, dir_name_result,
-                                                                'ab_episode_numbers')
+        final_result.ab_episode_numbers = self._combine_results(file_name_result, dir_name_result, 'ab_episode_numbers')
 
         # season and episode numbers
         final_result.season_number = self._combine_results(file_name_result, dir_name_result, 'season_number')
@@ -479,34 +487,35 @@ class NameParser(object):
 
         # if the dirname has a release group/show name I believe it over the filename
         final_result.series_name = self._combine_results(dir_name_result, file_name_result, 'series_name')
+
         final_result.extra_info = self._combine_results(dir_name_result, file_name_result, 'extra_info')
         final_result.release_group = self._combine_results(dir_name_result, file_name_result, 'release_group')
         final_result.version = self._combine_results(dir_name_result, file_name_result, 'version')
 
-        final_result.which_regex = []
         if final_result == file_name_result:
             final_result.which_regex = file_name_result.which_regex
         elif final_result == dir_name_result:
             final_result.which_regex = dir_name_result.which_regex
         else:
             if file_name_result:
-                final_result.which_regex += file_name_result.which_regex
+                final_result.which_regex |= file_name_result.which_regex
             if dir_name_result:
-                final_result.which_regex += dir_name_result.which_regex
+                final_result.which_regex |= dir_name_result.which_regex
 
         final_result.show = self._combine_results(file_name_result, dir_name_result, 'show')
         final_result.indexerid = self._combine_results(file_name_result, dir_name_result, 'indexerid')
         final_result.quality = self._combine_results(file_name_result, dir_name_result, 'quality')
 
-        if not final_result.show and self.validate_show:
-            raise InvalidShowException("Unable to match {result.original_name} to a show in your database. "
-                                       "Parser result: {result}".format(result=final_result))
+        if self.validate_show and not self.naming_pattern and not final_result.show:
+            raise InvalidShowException("Unable to match {} to a show in your database. Parser result: {}".format(
+                name, final_result))
 
         # if there's no useful info in it then raise an exception
         if final_result.season_number is None and not final_result.episode_numbers and final_result.air_date is None and not final_result.ab_episode_numbers and not final_result.series_name:
-            raise InvalidNameException("Unable to parse {}".format(name))
+            raise InvalidNameException("Unable to parse {} to a valid episode of {}. Parser result: {}".format(
+                name, final_result.show.name, final_result))
 
-        if cache_result:
+        if cache_result and final_result.show:
             name_parser_cache.add(name, final_result)
 
         sickrage.app.log.debug("Parsed {} into {}".format(name, final_result))
@@ -531,66 +540,34 @@ class ParseResult(object):
                  ):
 
         self.original_name = original_name
-
         self.series_name = series_name
         self.season_number = season_number
-        if not episode_numbers:
-            self.episode_numbers = []
-        else:
-            self.episode_numbers = episode_numbers
-
-        if not ab_episode_numbers:
-            self.ab_episode_numbers = []
-        else:
-            self.ab_episode_numbers = ab_episode_numbers
-
-        if not quality:
-            self.quality = Quality.UNKNOWN
-        else:
-            self.quality = quality
-
+        self.episode_numbers = episode_numbers or []
+        self.ab_episode_numbers = ab_episode_numbers or []
+        self.quality = quality or Quality.UNKNOWN
         self.extra_info = extra_info
         self.release_group = release_group
-
         self.air_date = air_date
-
-        self.which_regex = []
         self.show = show
-        self.indexerid = indexerid
+        self.indexerid = indexerid or 0
         self.score = score
-
         self.version = version
+        self.which_regex = set()
 
     def __eq__(self, other):
-        if not other:
-            return False
-
-        if self.series_name != other.series_name:
-            return False
-        if self.season_number != other.season_number:
-            return False
-        if self.episode_numbers != other.episode_numbers:
-            return False
-        if self.extra_info != other.extra_info:
-            return False
-        if self.release_group != other.release_group:
-            return False
-        if self.air_date != other.air_date:
-            return False
-        if self.ab_episode_numbers != other.ab_episode_numbers:
-            return False
-        if self.show != other.show:
-            return False
-        if self.indexerid != other.indexerid:
-            return False
-        if self.score != other.score:
-            return False
-        if self.quality != other.quality:
-            return False
-        if self.version != other.version:
-            return False
-
-        return True
+        return other and all([
+            self.series_name == other.series_name,
+            self.season_number == other.season_number,
+            self.episode_numbers == other.episode_numbers,
+            self.extra_info == other.extra_info,
+            self.release_group == other.release_group,
+            self.air_date == other.air_date,
+            self.ab_episode_numbers == other.ab_episode_numbers,
+            self.show == other.show,
+            self.score == other.score,
+            self.quality == other.quality,
+            self.version == other.version
+        ])
 
     def __unicode__(self):
         to_return = ""
