@@ -25,14 +25,14 @@ import re
 import stat
 import subprocess
 
-from adba import aniDBAbstracter
-
 import sickrage
+from adba import aniDBAbstracter
 from sickrage.core.common import Quality, ARCHIVED, DOWNLOADED
-from sickrage.core.exceptions import EpisodeNotFoundException, EpisodePostProcessingFailedException
-from sickrage.core.helpers import findCertainShow, show_names, fixGlob, replaceExtension, makeDir, \
+from sickrage.core.exceptions import EpisodeNotFoundException, EpisodePostProcessingFailedException, \
+    NoFreeSpaceException
+from sickrage.core.helpers import findCertainShow, show_names, replaceExtension, makeDir, \
     chmodAsParent, moveFile, copyFile, hardlinkFile, moveAndSymlinkFile, remove_non_release_groups, remove_extension, \
-    isFileLocked, verify_freespace, delete_empty_folders, make_dirs, symlink
+    isFileLocked, verify_freespace, delete_empty_folders, make_dirs, symlink, is_rar_file, glob_escape
 from sickrage.core.nameparser import InvalidNameException, InvalidShowException, \
     NameParser
 from sickrage.core.tv.show.history import FailedHistory, History  # memory intensive
@@ -156,83 +156,107 @@ class PostProcessor(object):
                       sickrage.app.log.DEBUG)
             return PostProcessor.DOESNT_EXIST
 
-    def list_associated_files(self, file_path, base_name_only=False, subtitles_only=False, subfolders=False):
+    def list_associated_files(self, file_path, subtitles_only=False, subfolders=False, rename=False):
         """
         For a given file path searches for files with the same name but different extension and returns their absolute paths
 
-        :param subfolders:
-        :param subtitles_only:
         :param file_path: The file to check for associated files
-
-        :param base_name_only: False add extra '.' (conservative search) to file_path minus extension
-
         :return: A list containing all files which are associated to the given file
         """
 
         def recursive_glob(treeroot, pattern):
             results = []
-            for base, __, files in os.walk(treeroot):
+            for base, __, files in os.walk(treeroot, followlinks=sickrage.app.config.processor_follow_symlinks):
                 goodfiles = fnmatch.filter(files, pattern)
-                results.extend(os.path.join(base, f) for f in goodfiles)
+                for f in goodfiles:
+                    found = os.path.join(base, f)
+                    if found != file_path:
+                        results.append(found)
             return results
 
         if not file_path:
             return []
 
-        # don't confuse glob with chars we didn't mean to use
-        globbable_file_path = fixGlob(file_path)
-
-        file_path_list = []
+        file_path_list_to_allow = []
+        file_path_list_to_delete = []
 
         if subfolders:
-            base_name = os.path.basename(globbable_file_path).rpartition('.')[0]
+            base_name = os.path.basename(file_path).rpartition('.')[0]
         else:
-            base_name = globbable_file_path.rpartition('.')[0]
-
-        if not base_name_only:
-            base_name += '.'
+            base_name = file_path.rpartition('.')[0]
 
         # don't strip it all and use cwd by accident
         if not base_name:
             return []
 
-        if subfolders:  # subfolders are only checked in show folder, so names will always be exactly alike
-            filelist = recursive_glob(os.path.dirname(globbable_file_path),
-                                      base_name + '*')  # just create the list of all files starting with the basename
-        else:  # this is called when PP, so we need to do the filename check case-insensitive
+        dirname = os.path.dirname(file_path) or '.'
+
+        # subfolders are only checked in show folder, so names will always be exactly alike
+        if subfolders:
+            # just create the list of all files starting with the basename
+            filelist = recursive_glob(dirname, glob_escape(base_name) + '*')
+        # this is called when PP, so we need to do the filename check case-insensitive
+        else:
             filelist = []
 
-            checklist = glob.glob(os.path.join(os.path.dirname(globbable_file_path),
-                                               '*'))  # get a list of all the files in the folder
-            for filefound in checklist:  # loop through all the files in the folder, and check if they are the same name even when the cases don't match
-                file_name = filefound.rpartition('.')[0]
-                if not base_name_only:
-                    file_name += '.'
-                if file_name.lower() == base_name.lower().replace('[[]', '[').replace('[]]',
-                                                                                      ']'):  # if there's no difference in the filename add it to the filelist
-                    filelist.append(filefound)
+            # loop through all the files in the folder, and check if they are the same name even when the cases don't match
+            for found_file in glob.glob(os.path.join(glob_escape(dirname), '*')):
+                file_name, separator, file_extension = found_file.rpartition('.')
+
+                # Handles subtitles with language code
+                if file_extension in subtitle_extensions and file_name.rpartition('.')[0].lower() == base_name.lower():
+                    filelist.append(found_file)
+                # Handles all files with same basename, including subtitles without language code
+                elif file_name.lower() == base_name.lower():
+                    filelist.append(found_file)
 
         for associated_file_path in filelist:
-            # only add associated to list
-            if associated_file_path == file_path:
+            # Exclude the video file we are post-processing
+            if os.path.abspath(associated_file_path) == os.path.abspath(file_path):
                 continue
-            # only list it if the only non-shared part is the extension or if it is a subtitle
-            if subtitles_only and not associated_file_path[len(associated_file_path) - 3:] in subtitle_extensions:
+
+            # If this is a rename in the show folder, we don't need to check anything, just add it to the list
+            if rename:
+                file_path_list_to_allow.append(associated_file_path)
+                continue
+
+            # Exclude non-subtitle files with the 'subtitles_only' option
+            if subtitles_only and not associated_file_path.endswith(tuple(subtitle_extensions)):
                 continue
 
             # Exclude .rar files from associated list
-            if re.search(r'(^.+\.(rar|r\d+)$)', associated_file_path):
+            if is_rar_file(associated_file_path):
                 continue
 
+            # Define associated files (all, allowed and non allowed)
             if os.path.isfile(associated_file_path):
-                file_path_list.append(associated_file_path)
+                # check if allowed or not during post processing
+                if sickrage.app.config.move_associated_files and associated_file_path.endswith(
+                        tuple(sickrage.app.config.allowed_extensions.split(","))):
+                    file_path_list_to_allow.append(associated_file_path)
+                elif sickrage.app.config.delete_non_associated_files:
+                    file_path_list_to_delete.append(associated_file_path)
 
-        if file_path_list:
-            self._log("Found the following associated files: " + str(file_path_list), sickrage.app.log.DEBUG)
+        if file_path_list_to_allow or file_path_list_to_delete:
+            self._log("Found the following associated files for {}: {}".format(file_path,
+                                                                               file_path_list_to_allow + file_path_list_to_delete),
+                      sickrage.app.log.DEBUG)
+
+            if file_path_list_to_delete:
+                self._log(
+                    "Deleting non allowed associated files for {}: {}".format(file_path, file_path_list_to_delete),
+                    sickrage.app.log.DEBUG)
+
+                # Delete all extensions the user doesn't allow
+                self._delete(file_path_list_to_delete)
+            if file_path_list_to_allow:
+                self._log("Allowing associated files for {0}: {1}".format(file_path, file_path_list_to_allow),
+                          sickrage.app.log.DEBUG)
         else:
-            self._log("No associated files were during this pass", sickrage.app.log.DEBUG)
+            self._log("No associated files for {0} were found during this pass".format(file_path),
+                      sickrage.app.log.DEBUG)
 
-        return file_path_list
+        return file_path_list_to_allow
 
     def _delete(self, file_path, associated_files=False):
         """
@@ -246,9 +270,12 @@ class PostProcessor(object):
             return
 
         # figure out which files we want to delete
-        file_list = [file_path]
+        file_list = file_path
+        if not isinstance(file_path, list):
+            file_list = [file_path]
+
         if associated_files:
-            file_list = file_list + self.list_associated_files(file_path, base_name_only=True, subfolders=True)
+            file_list = file_list + self.list_associated_files(file_path, subfolders=True)
 
         if not file_list:
             self._log("There were no files associated with " + file_path + ", not deleting anything",
@@ -294,10 +321,13 @@ class PostProcessor(object):
             return
 
         file_list = [file_path]
+        subfolders = os.path.normpath(os.path.dirname(file_path)) != os.path.normpath(
+            sickrage.app.config.tv_download_dir)
+
         if associated_files:
-            file_list = file_list + self.list_associated_files(file_path)
+            file_list = file_list + self.list_associated_files(file_path, subfolders=subfolders)
         elif subs:
-            file_list = file_list + self.list_associated_files(file_path, subtitles_only=True)
+            file_list = file_list + self.list_associated_files(file_path, subtitles_only=True, subfolders=subfolders)
 
         if not file_list:
             self._log("There were no files associated with " + file_path + ", not moving anything",
@@ -310,7 +340,6 @@ class PostProcessor(object):
 
         # deal with all files
         for cur_file_path in file_list:
-
             cur_file_name = os.path.basename(cur_file_path)
 
             # get the extension without .
@@ -357,13 +386,13 @@ class PostProcessor(object):
         """
 
         def _int_move(cur_file_path, new_file_path):
-
             self._log("Moving file from " + cur_file_path + " to " + new_file_path, sickrage.app.log.DEBUG)
+
             try:
                 moveFile(cur_file_path, new_file_path)
                 chmodAsParent(new_file_path)
             except (IOError, OSError) as e:
-                self._log("Unable to move file " + cur_file_path + " to " + new_file_path + ": {}".format(e.message),
+                self._log("Unable to move file {} to {}: {}".format(cur_file_path, new_file_path, e),
                           sickrage.app.log.ERROR)
                 raise
 
@@ -387,8 +416,8 @@ class PostProcessor(object):
                 copyFile(cur_file_path, new_file_path)
                 chmodAsParent(new_file_path)
             except (IOError, OSError) as e:
-                sickrage.app.log.error(
-                    "Unable to copy file " + cur_file_path + " to " + new_file_path + ": {}".format(e.message))
+                self._log("Unable to copy file {} to {}: {}".format(cur_file_path, new_file_path, e),
+                          sickrage.app.log.ERROR)
                 raise
 
         self._combined_file_operation(file_path, new_path, new_base_name, associated_files, action=_int_copy,
@@ -409,11 +438,13 @@ class PostProcessor(object):
             self._log("Hard linking file from " + cur_file_path + " to " + new_file_path,
                       sickrage.app.log.DEBUG)
             try:
+                if os.path.exists(new_file_path):
+                    os.remove(new_file_path)
+
                 hardlinkFile(cur_file_path, new_file_path)
                 chmodAsParent(new_file_path)
             except (IOError, OSError) as e:
-                self._log("Unable to link file {} to {}: {}".format(cur_file_path, new_file_path,
-                                                                    e)), sickrage.app.log.ERROR
+                self._log("Unable to hardlink file {} to {}: {}".format(cur_file_path, new_file_path, e), sickrage.app.log.ERROR)
                 raise
 
         self._combined_file_operation(file_path, new_path, new_base_name, associated_files, action=_int_hard_link,
@@ -437,7 +468,7 @@ class PostProcessor(object):
                 moveAndSymlinkFile(cur_file_path, new_file_path)
                 chmodAsParent(new_file_path)
             except (IOError, OSError) as e:
-                self._log("Unable to link file " + cur_file_path + " to " + new_file_path + ": {}".format(e.message),
+                self._log("Unable to move and symlink file {} to {}: {}".format(cur_file_path, new_file_path, e),
                           sickrage.app.log.ERROR)
                 raise
 
@@ -448,8 +479,8 @@ class PostProcessor(object):
         """
         symlink destination to source location, and set proper permissions
 
-        :param file_path: The full path of the media file to move
-        :param new_path: Destination path where we want to move the file to create a symbolic link to
+        :param file_path: The full path of the media file to link
+        :param new_path: Destination path where we want to create a symbolic link to
         :param new_base_name: The base filename (no extension) to use during the link. Use None to keep the same name.
         :param associated_files: Boolean, whether we should move similarly-named files too
         """
@@ -459,10 +490,13 @@ class PostProcessor(object):
             self._log("Creating then symbolic linking file from " + new_file_path + " to " + cur_file_path,
                       sickrage.app.log.DEBUG)
             try:
+                if os.path.exists(new_file_path):
+                    os.remove(new_file_path)
+
                 symlink(cur_file_path, new_file_path)
                 chmodAsParent(cur_file_path)
             except (IOError, OSError) as e:
-                self._log("Unable to link file " + cur_file_path + " to " + new_file_path + ": " + e,
+                self._log("Unable to symlink file {} to {}: {}".format(cur_file_path, new_file_path, e),
                           sickrage.app.log.ERROR)
                 raise
 
@@ -494,9 +528,7 @@ class PostProcessor(object):
 
         # search the database for a possible match and return immediately if we find one
         for curName in names:
-            dbData = [x['doc'] for x in sickrage.app.main_db.db.all('history', with_doc=True)
-                      if curName in x['doc']['resource']]
-
+            dbData = [x for x in sickrage.app.main_db.all('history') if curName in x['resource']]
             if len(dbData) == 0:
                 continue
 
@@ -508,7 +540,7 @@ class PostProcessor(object):
             if quality == Quality.UNKNOWN:
                 quality = None
 
-            show = findCertainShow(sickrage.app.showlist, indexer_id)
+            show = findCertainShow(indexer_id)
 
             self.in_history = True
             self.version = version
@@ -533,21 +565,21 @@ class PostProcessor(object):
 
         # remember whether it's a proper
         if parse_result.extra_info:
-            self.is_proper = re.search(r'(^|[\. _-])(proper|repack)([\. _-]|$)', parse_result.extra_info,
-                                       re.I) is not None
+            self.is_proper = re.search(r'\b(proper|repack|real)\b', parse_result.extra_info, re.I) is not None
 
         # if the result is complete then remember that for later
         # if the result is complete then set release name
-        if parse_result.series_name and (not (not (
-                        parse_result.season_number is not None and parse_result.episode_numbers) and not parse_result.air_date)) and parse_result.release_group:
+        if parse_result.series_name and (
+                (parse_result.season_number is not None and parse_result.episode_numbers) or parse_result.air_date) \
+                and parse_result.release_group:
 
             if not self.release_name:
                 self.release_name = remove_non_release_groups(
                     remove_extension(os.path.basename(parse_result.original_name)))
 
         else:
-            sickrage.app.log.debug(
-                "Parse result not sufficient (all following have to be set). will not save release name")
+            sickrage.app.log.debug("Parse result not sufficient (all following have to be set). will not save release "
+                                   "name")
             sickrage.app.log.debug("Parse result(series_name): " + str(parse_result.series_name))
             sickrage.app.log.debug("Parse result(season_number): " + str(parse_result.season_number))
             sickrage.app.log.debug("Parse result(episode_numbers): " + str(parse_result.episode_numbers))
@@ -574,7 +606,7 @@ class PostProcessor(object):
         name = remove_non_release_groups(remove_extension(name))
 
         # parse the name to break it into show name, season, and episode
-        np = NameParser(True, tryIndexers=True)
+        np = NameParser(True)
         parse_result = np.parse(name)
 
         # show object
@@ -659,7 +691,7 @@ class PostProcessor(object):
             try:
                 (cur_show, cur_season, cur_episodes, cur_quality, cur_version) = cur_attempt()
             except (InvalidNameException, InvalidShowException) as e:
-                sickrage.app.log.debug("Unable to parse, skipping: {}".format(e.message))
+                sickrage.app.log.debug("Unable to parse, skipping: {}".format(e))
                 continue
 
             if not cur_show:
@@ -687,20 +719,16 @@ class PostProcessor(object):
                 airdate = episodes[0].toordinal()
 
                 # Ignore season 0 when searching for episode(Conflict between special and regular episode, same air date)
-                dbData = [x['doc'] for x in
-                          sickrage.app.main_db.db.get_many('tv_episodes', show.indexerid, with_doc=True)
-                          if x['doc']['indexer'] == show.indexer
-                          and x['doc']['airdate'] == airdate
-                          and x['doc']['season'] != 0]
+                dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', show.indexerid)
+                          if x['indexer'] == show.indexer and x['airdate'] == airdate and x['season'] != 0]
 
                 if dbData:
                     season = int(dbData[0]['season'])
                     episodes = [int(dbData[0]['episode'])]
                 else:
                     # Found no result, try with season 0
-                    dbData = [x['doc'] for x in
-                              sickrage.app.main_db.db.get_many('tv_episodes', show.indexerid, with_doc=True)
-                              if x['doc']['indexer'] == show.indexer and x['doc']['airdate'] == airdate]
+                    dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', show.indexerid)
+                              if x['indexer'] == show.indexer and x['airdate'] == airdate]
 
                     if dbData:
                         season = int(dbData[0]['season'])
@@ -718,13 +746,11 @@ class PostProcessor(object):
 
             # if there's no season then we can hopefully just use 1 automatically
             elif season is None and show:
-                if len({x['doc']['season'] for x in
-                        sickrage.app.main_db.db.get_many('tv_episodes', show.indexerid, with_doc=True)
-                        if x['doc']['season'] != 0 and x['doc']['indexer'] == show.indexer}) == 1 and season is None:
+                if len({x['season'] for x in sickrage.app.main_db.get_many('tv_episodes', show.indexerid)
+                        if x['season'] != 0 and x['indexer'] == show.indexer}) == 1:
+                    self._log("Don't have a season number, but this show appears to only have 1 season, setting "
+                              "season number to 1...", sickrage.app.log.DEBUG)
                     season = 1
-                    self._log(
-                        "Don't have a season number, but this show appears to only have 1 season, setting season number to 1...",
-                        sickrage.app.log.DEBUG)
 
             if show and season and episodes:
                 return show, season, episodes, quality, version
@@ -752,7 +778,7 @@ class PostProcessor(object):
             try:
                 curEp = show.getEpisode(season, cur_episode)
             except EpisodeNotFoundException as e:
-                self._log("Unable to create episode: {}".format(e.message)), sickrage.app.log.DEBUG
+                self._log("Unable to create episode: {}".format(e)), sickrage.app.log.DEBUG
                 raise EpisodePostProcessingFailedException()
 
             # associate all the episodes together under a single root episode
@@ -849,10 +875,10 @@ class PostProcessor(object):
                 self._log("Script result: " + str(out), sickrage.app.log.DEBUG)
 
             except OSError as e:
-                self._log("Unable to run extra_script: {}".format(e.message))
+                self._log("Unable to run extra_script: {}".format(e))
 
             except Exception as e:
-                self._log("Unable to run extra_script: {}".format(e.message))
+                self._log("Unable to run extra_script: {}".format(e))
 
     def _is_priority(self, ep_obj, new_ep_quality):
         """
@@ -962,19 +988,17 @@ class PostProcessor(object):
         self._log("Is ep a priority download: " + str(priority_download), sickrage.app.log.DEBUG)
 
         # get the version of the episode we're processing
+        new_ep_version = -1
         if version:
             self._log("Snatch history had a version in it, using that: v" + str(version),
                       sickrage.app.log.DEBUG)
             new_ep_version = version
-        else:
-            new_ep_version = -1
 
         # check for an existing file
         existing_file_status = self._checkForExistingFile(ep_obj.location)
 
         # if it's not priority then we don't want to replace smaller files in case it was a mistake
         if not priority_download:
-
             # Not a priority and the quality is lower than what we already have
             if (new_ep_quality < old_ep_quality != Quality.UNKNOWN) \
                     and not existing_file_status == PostProcessor.DOESNT_EXIST:
@@ -984,28 +1008,26 @@ class PostProcessor(object):
             # if there's an existing file that we don't want to replace stop here
             if existing_file_status == PostProcessor.EXISTS_LARGER:
                 if self.is_proper:
-                    self._log(
-                        "File exists and new file is smaller, new file is a proper/repack, marking it safe to replace")
+                    self._log("File exists and new file is smaller, new file is a proper/repack, marking it safe to "
+                              "replace")
                     return True
-
                 else:
                     self._log("File exists and new file is smaller, marking it unsafe to replace")
                     return False
-
             elif existing_file_status == PostProcessor.EXISTS_SAME:
                 self._log("File exists and new file is same size, marking it unsafe to replace")
                 return False
-
         # if the file is priority then we're going to replace it even if it exists
         else:
-            self._log(
-                "This download is marked a priority download so I'm going to replace an existing file if I find one")
+            self._log("This download is marked a priority download so I'm going to replace an existing file if I find "
+                      "one")
 
         # try to find out if we have enough space to perform the copy or move action.
         if not isFileLocked(self.file_path, False):
             if not verify_freespace(self.file_path, ep_obj.show.location, [ep_obj] + ep_obj.relatedEps):
-                self._log("Not enough space to continue PP, exiting", sickrage.app.log.WARNING)
-                return False
+                self._log("Not enough space to continue PostProcessing, exiting", sickrage.app.log.WARNING)
+                #return False
+                raise NoFreeSpaceException
         else:
             self._log("Unable to determine needed filespace as the source file is locked for access")
 
@@ -1038,13 +1060,12 @@ class PostProcessor(object):
                 raise EpisodePostProcessingFailedException(
                     "Unable to create the show directory: " + ep_obj.show.location)
 
-            # get metadata for the show (but not episode because it hasn't been fully processed)
+            # write metadata for the show (but not episode because it hasn't been fully processed)
             ep_obj.show.writeMetadata(True)
 
         # update the ep info before we rename so the quality & release name go into the name properly
         for cur_ep in [ep_obj] + ep_obj.relatedEps:
             with cur_ep.lock:
-
                 if self.release_name:
                     self._log("Found release name " + self.release_name, sickrage.app.log.DEBUG)
                     cur_ep.release_name = self.release_name
@@ -1099,7 +1120,6 @@ class PostProcessor(object):
             orig_extension = self.file_name.rpartition('.')[-1]
             new_base_name = os.path.basename(proper_path)
             new_file_name = new_base_name + '.' + orig_extension
-
         else:
             # if we're not renaming then there's no new base name, we'll just use the existing name
             new_base_name = None
@@ -1168,7 +1188,7 @@ class PostProcessor(object):
         # If any notification fails, don't stop postProcessor
         try:
             # send notifications
-            Notifiers.notify_download(ep_obj._format_pattern('%SN - %Sx%0E - %EN - %QN'))
+            Notifiers.mass_notify_download(ep_obj._format_pattern('%SN - %Sx%0E - %EN - %QN'))
 
             # do the library update for KODI
             sickrage.app.notifier_providers['kodi'].update_library(ep_obj.show.name)
@@ -1190,7 +1210,7 @@ class PostProcessor(object):
 
             # do the library update for Trakt
             sickrage.app.notifier_providers['trakt'].update_library(ep_obj)
-        except:
+        except Exception:
             sickrage.app.log.info("Some notifications could not be sent. Continuing with post-processing...")
 
         self._run_extra_scripts(ep_obj)
