@@ -51,7 +51,8 @@ class ShowQueue(srQueue):
         if not show:
             return False
 
-        return show.indexerid in [x.show.indexerid if x.show else 0 for __, __, x in self.queue if x.action_id in actions]
+        return show.indexerid in [x.show.indexerid if x.show else 0 for __, __, x in self.queue if
+                                  x.action_id in actions]
 
     def _isBeing(self, show, actions):
         return self.currentItem is not None and show == self.currentItem.show and self.currentItem.action_id in actions
@@ -68,6 +69,9 @@ class ShowQueue(srQueue):
     def isInSubtitleQueue(self, show):
         return self._isInQueue(show, (ShowQueueActions.SUBTITLE,))
 
+    def isBeingRemoved(self, show):
+        return self._isBeing(show, (ShowQueueActions.REMOVE,))
+
     def isBeingAdded(self, show):
         return self._isBeing(show, (ShowQueueActions.ADD,))
 
@@ -87,28 +91,28 @@ class ShowQueue(srQueue):
         return [x for __, __, x in self.queue + [(None, None, self.currentItem)] if x and x.isLoading]
 
     def updateShow(self, show, force=False):
-
         if self.isBeingAdded(show):
-            raise CantUpdateShowException(
-                str(show.name) + " is still being added, please wait until it is finished before trying to update.")
+            raise CantUpdateShowException("{} is still being added, please wait until it is finished before trying to "
+                                          "update.".format(show.name))
 
         if self.isBeingUpdated(show):
-            raise CantUpdateShowException(
-                str(show.name) + " is already being updated, can't update again until it's done.")
+            raise CantUpdateShowException("{} is already being updated, can't update again until "
+                                          "it's done.".format(show.name))
 
         if self.isInUpdateQueue(show):
-            raise CantUpdateShowException(
-                str(show.name) + " is in the process of being updated, can't update again until it's done.")
+            raise CantUpdateShowException("{} is in the process of being updated, can't update again until "
+                                          "it's done.".format(show.name))
 
         return self.put(QueueItemForceUpdate(show)) if force else self.put(QueueItemUpdate(show))
 
     def refreshShow(self, show, force=False):
         if (self.isBeingRefreshed(show) or self.isInRefreshQueue(show)) and not force:
-            raise CantRefreshShowException(
-                "This show is already being refreshed or queued to be refreshed, skipping this request.")
+            raise CantRefreshShowException("This show is already being refreshed or queued to be refreshed, skipping "
+                                           "this request.")
         elif (self.isBeingUpdated(show) or self.isInUpdateQueue(show)) and not force:
-            raise CantRefreshShowException(
-                "A refresh was attempted but there is already an update queued or in progress. Since updates do a refresh at the end anyway I'm skipping this request.")
+            raise CantRefreshShowException("A refresh was attempted but there is already an update queued or in "
+                                           "progress. Since updates do a refresh at the end anyway I'm skipping this "
+                                           "request.")
 
         sickrage.app.log.debug("Queueing show refresh for {}".format(show.name))
 
@@ -122,7 +126,7 @@ class ShowQueue(srQueue):
 
     def addShow(self, indexer, indexer_id, showDir, default_status=None, quality=None, flatten_folders=None,
                 lang=None, subtitles=None, subtitles_sr_metadata=None, anime=None, scene=None, paused=None,
-                blacklist=None, whitelist=None, default_status_after=None, archive=None):
+                blacklist=None, whitelist=None, default_status_after=None, skip_downloaded=None):
 
         if lang is None:
             lang = sickrage.app.config.indexer_default_language
@@ -142,7 +146,7 @@ class ShowQueue(srQueue):
                                      blacklist=blacklist,
                                      whitelist=whitelist,
                                      default_status_after=default_status_after,
-                                     archive=archive))
+                                     skip_downloaded=skip_downloaded))
 
     def removeShow(self, show, full=False):
         if not show:
@@ -217,7 +221,7 @@ class ShowQueueItem(srQueueItem):
 
 class QueueItemAdd(ShowQueueItem):
     def __init__(self, indexer, indexer_id, showDir, default_status, quality, flatten_folders, lang, subtitles,
-                 subtitles_sr_metadata, anime, scene, paused, blacklist, whitelist, default_status_after, archive):
+                 subtitles_sr_metadata, anime, scene, paused, blacklist, whitelist, default_status_after, skip_downloaded):
         super(QueueItemAdd, self).__init__(None, ShowQueueActions.ADD)
 
         self.indexer = indexer
@@ -235,7 +239,7 @@ class QueueItemAdd(ShowQueueItem):
         self.blacklist = blacklist
         self.whitelist = whitelist
         self.default_status_after = default_status_after
-        self.archive = archive
+        self.skip_downloaded = skip_downloaded
         self.priority = srQueuePriorities.HIGH
 
     @property
@@ -272,34 +276,39 @@ class QueueItemAdd(ShowQueueItem):
             sickrage.app.log.info("{}: {}".format(index_name, repr(lINDEXER_API_PARMS)))
 
             t = IndexerApi(self.indexer).indexer(**lINDEXER_API_PARMS)
-            s = t[self.indexer_id]
-            if not s: return self._finishEarly()
+
+            try:
+                s = t[self.indexer_id]
+            except indexer_error:
+                s = None
+
+            if not s:
+                return self._finishEarly()
 
             # this usually only happens if they have an NFO in their show dir which gave us a Indexer ID that has no proper english version of the show
             if not getattr(s, 'seriesname'):
-                sickrage.app.log.error(
+                sickrage.app.log.warning(
                     "Show in {} has no name on {}, probably the wrong language used to search with".format(self.showDir,
                                                                                                            index_name))
                 sickrage.app.alerts.error(_("Unable to add show"),
-                                                      _(
-                                                          "Show in {} has no name on {}, probably the wrong language. Delete .nfo and add manually in the correct language").format(
-                                                          self.showDir, index_name))
+                                          _("Show in {} has no name on {}, probably the wrong language. Delete .nfo "
+                                            "and add manually in the correct language").format(self.showDir,
+                                                                                               index_name))
                 return self._finishEarly()
 
             # if the show has no episodes/seasons
             if not len(s):
-                sickrage.app.log.error("Show " + str(s['seriesname']) + " is on " + str(
+                sickrage.app.log.warning("Show " + str(s['seriesname']) + " is on " + str(
                     IndexerApi(self.indexer).name) + " but contains no season/episode data.")
                 sickrage.app.alerts.error(_("Unable to add show"),
-                                                      _("Show ") + str(s['seriesname']) + _(" is on ") + str(
-                                                          IndexerApi(
-                                                              self.indexer).name) + _(
-                                                          " but contains no season/episode data."))
+                                          _("Show ") + str(s['seriesname']) + _(" is on ") + str(
+                                              IndexerApi(
+                                                  self.indexer).name) + _(
+                                              " but contains no season/episode data."))
                 return self._finishEarly()
         except Exception as e:
             sickrage.app.log.error(
-                "{}: Error while loading information from indexer {}. Error: {}".format(self.indexer_id, index_name,
-                                                                                        e.message))
+                "{}: Error while loading information from indexer {}. Error: {}".format(self.indexer_id, index_name, e))
 
             sickrage.app.alerts.error(
                 _("Unable to add show"),
@@ -336,7 +345,7 @@ class QueueItemAdd(ShowQueueItem):
             self.show.flatten_folders = self.flatten_folders or sickrage.app.config.flatten_folders_default
             self.show.anime = self.anime or sickrage.app.config.anime_default
             self.show.scene = self.scene or sickrage.app.config.scene_default
-            self.show.archive_firstmatch = self.archive or sickrage.app.config.archive_default
+            self.show.skip_downloaded = self.skip_downloaded or sickrage.app.config.skip_downloaded_default
             self.show.paused = self.paused or False
 
             # set up default new/missing episode status
@@ -361,9 +370,9 @@ class QueueItemAdd(ShowQueueItem):
                     #     self.show.sports = 1
 
         except indexer_exception as e:
-            sickrage.app.log.error(
+            sickrage.app.log.warning(
                 "Unable to add show due to an error with " + IndexerApi(
-                    self.indexer).name + ": {}".format(e.message))
+                    self.indexer).name + ": {}".format(e))
             if self.show:
                 sickrage.app.alerts.error(
                     _("Unable to add ") + str(self.show.name) + _(" due to an error with ") + IndexerApi(
@@ -376,51 +385,51 @@ class QueueItemAdd(ShowQueueItem):
         except MultipleShowObjectsException:
             sickrage.app.log.warning("The show in " + self.showDir + " is already in your show list, skipping")
             sickrage.app.alerts.error(_('Show skipped'),
-                                                  _("The show in ") + self.showDir + _(" is already in your show list"))
+                                      _("The show in ") + self.showDir + _(" is already in your show list"))
             return self._finishEarly()
 
         except Exception as e:
-            sickrage.app.log.error("Error trying to add show: {}".format(e.message))
+            sickrage.app.log.error("Error trying to add show: {}".format(e))
             sickrage.app.log.debug(traceback.format_exc())
             raise self._finishEarly()
 
         try:
             sickrage.app.log.debug("Attempting to retrieve show info from IMDb")
-            self.show.loadIMDbInfo()
+            self.show.load_imdb_info()
         except Exception as e:
-            sickrage.app.log.error("Error loading IMDb info: {}".format(e.message))
+            sickrage.app.log.error("Error loading IMDb info: {}".format(e))
 
         try:
             self.show.saveToDB()
         except Exception as e:
-            sickrage.app.log.error("Error saving the show to the database: {}".format(e.message))
+            sickrage.app.log.error("Error saving the show to the database: {}".format(e))
             sickrage.app.log.debug(traceback.format_exc())
             raise self._finishEarly()
 
         # add it to the show list
-        if not findCertainShow(sickrage.app.showlist, self.indexer_id): sickrage.app.showlist.append(self.show)
+        if not findCertainShow(self.indexer_id):
+            sickrage.app.showlist.append(self.show)
 
         try:
             self.show.loadEpisodesFromIndexer()
         except Exception as e:
             sickrage.app.log.error(
                 "Error with " + IndexerApi(
-                    self.show.indexer).name + ", not creating episode list: {}".format(e.message))
+                    self.show.indexer).name + ", not creating episode list: {}".format(e))
             sickrage.app.log.debug(traceback.format_exc())
 
         try:
             self.show.loadEpisodesFromDir()
         except Exception as e:
-            sickrage.app.log.debug("Error searching dir for episodes: {}".format(e.message))
+            sickrage.app.log.debug("Error searching dir for episodes: {}".format(e))
             sickrage.app.log.debug(traceback.format_exc())
 
         # if they set default ep status to WANTED then run the backlog to search for episodes
         if self.show.default_ep_status == WANTED:
             sickrage.app.log.info("Launching backlog for this show since its episodes are WANTED")
-            sickrage.app.backlog_searcher.searchBacklog([self.show])
+            sickrage.app.backlog_searcher.search_backlog([self.show])
 
-        self.show.writeMetadata()
-        self.show.updateMetadata()
+        self.show.writeMetadata(force=True)
         self.show.populateCache()
 
         if sickrage.app.config.use_trakt:
@@ -471,12 +480,8 @@ class QueueItemRefresh(ShowQueueItem):
 
         self.show.refreshDir()
 
-        self.show.writeMetadata()
-
-        if self.force:
-            self.show.updateMetadata()
-
-        self.show.populateCache(self.force)
+        self.show.writeMetadata(force=self.force)
+        self.show.populateCache(force=self.force)
 
         # Load XEM data to DB for show
         xem_refresh(self.show.indexerid, self.show.indexer)
@@ -555,20 +560,18 @@ class QueueItemUpdate(ShowQueueItem):
             self.show.loadFromIndexer(cache=False)
         except indexer_error as e:
             sickrage.app.log.warning(
-                "Unable to contact " + IndexerApi(self.show.indexer).name + ", aborting: {}".format(e.message))
+                "Unable to contact " + IndexerApi(self.show.indexer).name + ", aborting: {}".format(e))
             return
         except indexer_attributenotfound as e:
-            sickrage.app.log.error(
-                "Data retrieved from " + IndexerApi(self.show.indexer).name + " was incomplete, aborting: {}".format(
-                    e.message))
+            sickrage.app.log.warning(
+                "Data retrieved from " + IndexerApi(self.show.indexer).name + " was incomplete, aborting: {}".format(e))
             return
 
         try:
             sickrage.app.log.debug("Attempting to retrieve show info from IMDb")
-            self.show.loadIMDbInfo()
+            self.show.load_imdb_info()
         except Exception as e:
-            sickrage.app.log.error("Error loading IMDb info: {}".format(e.message))
-            sickrage.app.log.debug(traceback.format_exc())
+            sickrage.app.log.warning("Error loading IMDb info for {}: {}".format(IndexerApi(self.show.indexer).name, e))
 
         # get episode list from DB
         DBEpList = self.show.loadEpisodesFromDB()
@@ -579,9 +582,9 @@ class QueueItemUpdate(ShowQueueItem):
             IndexerEpList = self.show.loadEpisodesFromIndexer()
         except indexer_exception as e:
             sickrage.app.log.error("Unable to get info from " + IndexerApi(
-                self.show.indexer).name + ", the show info will not be refreshed: {}".format(e.message))
+                self.show.indexer).name + ", the show info will not be refreshed: {}".format(e))
 
-        if IndexerEpList is None:
+        if not IndexerEpList:
             sickrage.app.log.error("No data returned from " + IndexerApi(
                 self.show.indexer).name + ", unable to update this show")
         else:
@@ -596,10 +599,8 @@ class QueueItemUpdate(ShowQueueItem):
                 for curEpisode in DBEpList[curSeason]:
                     sickrage.app.log.info(
                         "Permanently deleting episode " + str(curSeason) + "x" + str(curEpisode) + " from the database")
-
-                    curEp = self.show.getEpisode(curSeason, curEpisode)
                     try:
-                        curEp.deleteEpisode()
+                        self.show.getEpisode(curSeason, curEpisode).deleteEpisode()
                     except EpisodeDeletedException:
                         pass
 
@@ -625,9 +626,16 @@ class QueueItemRemove(ShowQueueItem):
         super(QueueItemRemove, self).__init__(show, ShowQueueActions.REMOVE)
 
         # lets make sure this happens before any other high priority actions
-        self.priority = srQueuePriorities.HIGH + srQueuePriorities.HIGH
+        self.priority = srQueuePriorities.EXTREME
         self.full = full
 
+    @property
+    def isLoading(self):
+        """
+        Returns false cause we are removing the show.
+        """
+        return False
+
     def run(self):
         sickrage.app.log.info("Removing show: {}".format(self.show.name))
 
