@@ -27,6 +27,7 @@ from CodernityDB.database import RecordNotFound
 
 import sickrage
 from sickrage.core.helpers import findCertainShow, try_int
+from sickrage.core.websession import WebSession
 from sickrage.indexers import IndexerApi
 
 
@@ -46,7 +47,7 @@ def get_scene_numbering(indexer_id, indexer, season, episode, fallback_to_xem=Tr
     if indexer_id is None or season is None or episode is None:
         return season, episode
 
-    showObj = findCertainShow(sickrage.app.showlist, int(indexer_id))
+    showObj = findCertainShow(int(indexer_id))
     if showObj and not showObj.is_scene:
         return season, episode
 
@@ -71,12 +72,12 @@ def find_scene_numbering(indexer_id, indexer, season, episode):
     indexer_id = int(indexer_id)
     indexer = int(indexer)
 
-    dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('scene_numbering', indexer_id, with_doc=True)
-              if x['doc']['indexer'] == indexer
-              and x['doc']['season'] == season
-              and x['doc']['episode'] == episode
-              and x['doc']['scene_season'] != 0
-              and x['doc']['scene_episode'] != 0]
+    dbData = [x for x in sickrage.app.main_db.get_many('scene_numbering', indexer_id)
+              if x['indexer'] == indexer
+              and x['season'] == season
+              and x['episode'] == episode
+              and x['scene_season'] != 0
+              and x['scene_episode'] != 0]
 
     if dbData:
         return try_int(dbData[0].get("scene_season")), try_int(dbData[0].get("scene_episode"))
@@ -100,7 +101,7 @@ def get_scene_absolute_numbering(indexer_id, indexer, absolute_number, fallback_
     indexer_id = int(indexer_id)
     indexer = int(indexer)
 
-    showObj = findCertainShow(sickrage.app.showlist, indexer_id)
+    showObj = findCertainShow(indexer_id)
     if showObj and not showObj.is_scene:
         return absolute_number
 
@@ -125,10 +126,10 @@ def find_scene_absolute_numbering(indexer_id, indexer, absolute_number):
     indexer_id = int(indexer_id)
     indexer = int(indexer)
 
-    dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('scene_numbering', indexer_id, with_doc=True)
-              if x['doc']['indexer'] == indexer
-              and x['doc']['absolute_number'] == absolute_number
-              and x['doc']['scene_absolute_number'] != 0]
+    dbData = [x for x in sickrage.app.main_db.get_many('scene_numbering', indexer_id)
+              if x['indexer'] == indexer
+              and x['absolute_number'] == absolute_number
+              and x['scene_absolute_number'] != 0]
 
     if dbData:
         return try_int(dbData[0].get('scene_absolute_number'))
@@ -145,10 +146,10 @@ def get_indexer_numbering(indexer_id, indexer, sceneSeason, sceneEpisode, fallba
     indexer_id = int(indexer_id)
     indexer = int(indexer)
 
-    dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('scene_numbering', indexer_id, with_doc=True)
-              if x['doc']['indexer'] == indexer
-              and x['doc']['scene_season'] == sceneSeason
-              and x['doc']['scene_episode'] == sceneEpisode]
+    dbData = [x for x in sickrage.app.main_db.get_many('scene_numbering', indexer_id)
+              if x['indexer'] == indexer
+              and x['scene_season'] == sceneSeason
+              and x['scene_episode'] == sceneEpisode]
 
     if dbData:
         return try_int(dbData[0].get("season")), try_int(dbData[0].get("episode"))
@@ -170,14 +171,14 @@ def get_indexer_absolute_numbering(indexer_id, indexer, sceneAbsoluteNumber, fal
     indexer = int(indexer)
 
     if scene_season is None:
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('scene_numbering', indexer_id, with_doc=True)
-                  if x['doc']['indexer'] == indexer
-                  and x['doc']['scene_absolute_number'] == sceneAbsoluteNumber]
+        dbData = [x for x in sickrage.app.main_db.get_many('scene_numbering', indexer_id)
+                  if x['indexer'] == indexer
+                  and x['scene_absolute_number'] == sceneAbsoluteNumber]
     else:
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('scene_numbering', indexer_id, with_doc=True)
-                  if x['doc']['indexer'] == indexer
-                  and x['doc']['scene_absolute_number'] == sceneAbsoluteNumber
-                  and x['doc']['scene_season'] == scene_season]
+        dbData = [x for x in sickrage.app.main_db.get_many('scene_numbering', indexer_id)
+                  if x['indexer'] == indexer
+                  and x['scene_absolute_number'] == sceneAbsoluteNumber
+                  and x['scene_season'] == scene_season]
 
     if dbData:
         return try_int(dbData[0].get("absolute_number"))
@@ -200,17 +201,17 @@ def set_scene_numbering(indexer_id, indexer, season=0, episode=0, absolute_numbe
     indexer = int(indexer)
 
     if season and episode:
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('scene_numbering', indexer_id, with_doc=True)
-                  if x['doc']['index'] == indexer
-                  and x['doc']['season'] == season
-                  and x['doc']['episode'] == episode]
+        dbData = [x for x in sickrage.app.main_db.get_many('scene_numbering', indexer_id)
+                  if x['index'] == indexer
+                  and x['season'] == season
+                  and x['episode'] == episode]
 
         if len(dbData):
             dbData[0]['scene_season'] = sceneSeason
             dbData[0]['scene_episode'] = sceneEpisode
-            sickrage.app.main_db.db.update(dbData[0])
+            sickrage.app.main_db.update(dbData[0])
         else:
-            sickrage.app.main_db.db.insert({
+            sickrage.app.main_db.insert({
                 '_t': 'scene_numbering',
                 'indexer': indexer,
                 'indexer_id': indexer_id,
@@ -223,15 +224,15 @@ def set_scene_numbering(indexer_id, indexer, season=0, episode=0, absolute_numbe
             })
 
     elif absolute_number:
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('scene_numbering', indexer_id, with_doc=True)
-                  if x['doc']['index'] == indexer
-                  and x['doc']['absolute_number'] == absolute_number]
+        dbData = [x for x in sickrage.app.main_db.get_many('scene_numbering', indexer_id)
+                  if x['index'] == indexer
+                  and x['absolute_number'] == absolute_number]
 
         if len(dbData):
             dbData[0]['scene_absolute_number'] = sceneAbsolute
-            sickrage.app.main_db.db.update(dbData[0])
+            sickrage.app.main_db.update(dbData[0])
         else:
-            sickrage.app.main_db.db.insert({
+            sickrage.app.main_db.insert({
                 '_t': 'scene_numbering',
                 'indexer': indexer,
                 'indexer_id': indexer_id,
@@ -244,7 +245,7 @@ def set_scene_numbering(indexer_id, indexer, season=0, episode=0, absolute_numbe
             })
 
     # Reload data from DB so that cache and db are in sync
-    show = findCertainShow(sickrage.app.showlist, indexer_id)
+    show = findCertainShow(indexer_id)
     show.flushEpisodes()
 
 
@@ -266,12 +267,12 @@ def find_xem_numbering(indexer_id, indexer, season, episode):
 
     xem_refresh(indexer_id, indexer)
 
-    dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', indexer_id, with_doc=True)
-              if x['doc']['indexer'] == indexer
-              and x['doc']['season'] == season
-              and x['doc']['episode'] == episode
-              and x['doc']['scene_season'] != 0
-              and x['doc']['scene_episode'] != 0]
+    dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', indexer_id)
+              if x['indexer'] == indexer
+              and x['season'] == season
+              and x['episode'] == episode
+              and x['scene_season'] != 0
+              and x['scene_episode'] != 0]
 
     if dbData:
         return try_int(dbData[0].get("scene_season")), try_int(dbData[0].get("scene_episode"))
@@ -294,10 +295,10 @@ def find_xem_absolute_numbering(indexer_id, indexer, absolute_number):
 
     xem_refresh(indexer_id, indexer)
 
-    dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', indexer_id, with_doc=True)
-              if x['doc']['indexer'] == indexer
-              and x['doc']['absolute_number'] == absolute_number
-              and x['doc']['scene_absolute_number'] != 0]
+    dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', indexer_id)
+              if x['indexer'] == indexer
+              and x['absolute_number'] == absolute_number
+              and x['scene_absolute_number'] != 0]
 
     if dbData:
         return try_int(dbData[0].get('scene_absolute_number'))
@@ -320,10 +321,10 @@ def get_indexer_numbering_for_xem(indexer_id, indexer, sceneSeason, sceneEpisode
 
     xem_refresh(indexer_id, indexer)
 
-    dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', indexer_id, with_doc=True)
-              if x['doc']['indexer'] == indexer
-              and x['doc']['scene_season'] == sceneSeason
-              and x['doc']['scene_episode'] == sceneEpisode]
+    dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', indexer_id)
+              if x['indexer'] == indexer
+              and x['scene_season'] == sceneSeason
+              and x['scene_episode'] == sceneEpisode]
 
     if dbData:
         return try_int(dbData[0].get("season")), try_int(dbData[0].get("episode"))
@@ -348,14 +349,14 @@ def get_indexer_absolute_numbering_for_xem(indexer_id, indexer, sceneAbsoluteNum
     xem_refresh(indexer_id, indexer)
 
     if scene_season is None:
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', indexer_id, with_doc=True)
-                  if x['doc']['indexer'] == indexer
-                  and x['doc']['scene_absolute_number'] == sceneAbsoluteNumber]
+        dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', indexer_id)
+                  if x['indexer'] == indexer
+                  and x['scene_absolute_number'] == sceneAbsoluteNumber]
     else:
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', indexer_id, with_doc=True)
-                  if x['doc']['indexer'] == indexer
-                  and x['doc']['scene_absolute_number'] == sceneAbsoluteNumber
-                  and x['doc']['scene_season'] == scene_season]
+        dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', indexer_id)
+                  if x['indexer'] == indexer
+                  and x['scene_absolute_number'] == sceneAbsoluteNumber
+                  and x['scene_season'] == scene_season]
 
     if dbData:
         return try_int(dbData[0].get('absolute_number'))
@@ -376,7 +377,7 @@ def get_scene_numbering_for_show(indexer_id, indexer):
     indexer = int(indexer)
 
     result = {}
-    for dbData in [x['doc'] for x in sickrage.app.main_db.db.get_many('scene_numbering', indexer_id, with_doc=True)]:
+    for dbData in sickrage.app.main_db.get_many('scene_numbering', indexer_id):
         season = try_int(dbData['season'])
         episode = try_int(dbData['episode'])
         scene_season = try_int(dbData['scene_season'])
@@ -403,7 +404,7 @@ def get_xem_numbering_for_show(indexer_id, indexer):
     xem_refresh(indexer_id, indexer)
 
     result = {}
-    for dbData in [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', indexer_id, with_doc=True)]:
+    for dbData in sickrage.app.main_db.get_many('tv_episodes', indexer_id):
         season = try_int(dbData.get('season'))
         episode = try_int(dbData.get('episode'))
         scene_season = try_int(dbData.get('scene_season'))
@@ -428,7 +429,7 @@ def get_scene_absolute_numbering_for_show(indexer_id, indexer):
     indexer = int(indexer)
 
     result = {}
-    for dbData in [x['doc'] for x in sickrage.app.main_db.db.get_many('scene_numbering', indexer_id, with_doc=True)]:
+    for dbData in sickrage.app.main_db.get_many('scene_numbering', indexer_id):
         absolute_number = try_int(dbData.get('absolute_number'))
         scene_absolute_number = try_int(dbData.get('scene_absolute_number'))
         if try_int(dbData.get('indexer')) != indexer or scene_absolute_number == 0: continue
@@ -453,7 +454,7 @@ def get_xem_absolute_numbering_for_show(indexer_id, indexer):
     xem_refresh(indexer_id, indexer)
 
     result = {}
-    for dbData in [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', indexer_id, with_doc=True)]:
+    for dbData in sickrage.app.main_db.get_many('tv_episodes', indexer_id):
         absolute_number = try_int(dbData.get('absolute_number'))
         scene_absolute_number = try_int(dbData.get('scene_absolute_number'))
         if try_int(dbData['indexer']) != indexer or scene_absolute_number == 0: continue
@@ -478,7 +479,7 @@ def xem_refresh(indexer_id, indexer, force=False):
     MAX_REFRESH_AGE_SECS = 86400  # 1 day
 
     try:
-        dbData = sickrage.app.main_db.db.get('xem_refresh', indexer_id, with_doc=True)['doc']
+        dbData = sickrage.app.main_db.get('xem_refresh', indexer_id)
         lastRefresh = try_int(dbData['last_refreshed'])
         refresh = int(time.mktime(datetime.datetime.today().timetuple())) > lastRefresh + MAX_REFRESH_AGE_SECS
     except RecordNotFound:
@@ -490,11 +491,11 @@ def xem_refresh(indexer_id, indexer, force=False):
 
         # mark refreshed
         try:
-            dbData = sickrage.app.main_db.db.get('xem_refresh', indexer_id, with_doc=True)['doc']
+            dbData = sickrage.app.main_db.get('xem_refresh', indexer_id)
             dbData['last_refreshed'] = int(time.mktime(datetime.datetime.today().timetuple()))
-            sickrage.app.main_db.db.update(dbData)
+            sickrage.app.main_db.update(dbData)
         except RecordNotFound:
-            sickrage.app.main_db.db.insert({
+            sickrage.app.main_db.insert({
                 '_t': 'xem_refresh',
                 'indexer': indexer,
                 'last_refreshed': int(time.mktime(datetime.datetime.today().timetuple())),
@@ -506,13 +507,13 @@ def xem_refresh(indexer_id, indexer, force=False):
             url = "http://thexem.de/map/havemap?origin=%s" % IndexerApi(indexer).config['xem_origin']
 
             try:
-                parsedJSON = sickrage.app.wsession.get(url).json()
+                parsedJSON = WebSession().get(url).json()
                 if indexer_id not in map(int, parsedJSON['data']):
-                    raise
-            except:
-                for x in sickrage.app.main_db.db.get_many('tv_episodes', indexer_id, with_doc=True):
-                    x['doc']['scene_season'], x['doc']['scene_episode'], x['doc']['scene_absolute_number'] = 0, 0, 0
-                    sickrage.app.main_db.db.update(x['doc'])
+                    raise Exception
+            except Exception:
+                for x in sickrage.app.main_db.get_many('tv_episodes', indexer_id):
+                    x['scene_season'], x['scene_episode'], x['scene_absolute_number'] = 0, 0, 0
+                    sickrage.app.main_db.update(x)
                 return
 
             # XEM API URL
@@ -520,21 +521,19 @@ def xem_refresh(indexer_id, indexer, force=False):
                 indexer_id, IndexerApi(indexer).config['xem_origin'])
 
             try:
-                parsedJSON = sickrage.app.wsession.get(url).json()
+                parsedJSON = WebSession().get(url).json()
                 if 'success' not in parsedJSON['result']:
-                    raise
-            except:
+                    raise Exception
+            except Exception:
                 sickrage.app.log.info(
                     'No XEM data for show "%s on %s"' % (indexer_id, IndexerApi(indexer).name,))
                 return
 
             for entry in parsedJSON['data']:
                 try:
-                    dbData = \
-                        [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', indexer_id, with_doc=True)
-                         if x['doc']['season'] == entry[IndexerApi(indexer).config['xem_origin']]['season']
-                         and x['doc']['episode'] == entry[IndexerApi(indexer).config['xem_origin']]['episode']][
-                            0]
+                    dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', indexer_id)
+                              if x['season'] == entry[IndexerApi(indexer).config['xem_origin']]['season']
+                              and x['episode'] == entry[IndexerApi(indexer).config['xem_origin']]['episode']][0]
                 except:
                     continue
 
@@ -547,13 +546,13 @@ def xem_refresh(indexer_id, indexer, force=False):
                     dbData['scene_episode'] = entry['scene_2']['episode']
                     dbData['scene_absolute_number'] = entry['scene_2']['absolute']
 
-                sickrage.app.main_db.db.update(dbData)
+                sickrage.app.main_db.update(dbData)
 
         except Exception as e:
             sickrage.app.log.warning(
                 "Exception while refreshing XEM data for show {} on {}: {}".format(indexer_id,
                                                                                    IndexerApi(indexer).name,
-                                                                                   e.message))
+                                                                                   e))
             sickrage.app.log.debug(traceback.format_exc())
 
 
@@ -570,9 +569,8 @@ def get_absolute_number_from_season_and_episode(show, season, episode):
     absolute_number = None
 
     if season and episode:
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', show.indexerid, with_doc=True)
-                  if x['doc']['season'] == season
-                  and x['doc']['episode'] == episode]
+        dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', show.indexerid)
+                  if x['season'] == season and x['episode'] == episode]
 
         if len(dbData) == 1:
             absolute_number = try_int(dbData[0].get("absolute_number"))
