@@ -19,138 +19,24 @@
 
 from __future__ import unicode_literals
 
-import io
-import os
 import re
 import threading
 from datetime import date, timedelta
 
-import bencode
-from bencode import BTFailure
-
 import sickrage
 from sickrage.clients import getClientIstance
 from sickrage.clients.nzbget import NZBGet
 from sickrage.clients.sabnzbd import SabNZBd
 from sickrage.core.common import Quality, SEASON_RESULT, SNATCHED_BEST, \
-    SNATCHED_PROPER, SNATCHED, DOWNLOADED, WANTED, MULTI_EP_RESULT, video_exts
+    SNATCHED_PROPER, SNATCHED, MULTI_EP_RESULT
 from sickrage.core.exceptions import AuthException
-from sickrage.core.helpers import show_names, chmodAsParent
+from sickrage.core.helpers import show_names
 from sickrage.core.nzbSplitter import splitNZBResult
 from sickrage.core.tv.show.history import FailedHistory, History
 from sickrage.notifiers import Notifiers
 from sickrage.providers import NZBProvider, NewznabProvider, TorrentProvider, TorrentRssProvider
 
 
-def _verify_result(result):
-    """
-    Save the result to disk.
-    """
-
-    resProvider = result.provider
-
-    # check for auth
-    if resProvider.login():
-        for url in resProvider.make_url(result.url):
-            if 'NO_DOWNLOAD_NAME' in url:
-                continue
-
-            headers = {}
-            if url.startswith('http'):
-                headers.update({
-                    'Referer': '/'.join(url.split('/')[:3]) + '/'
-                })
-
-            sickrage.app.log.debug("Verifiying a result from " + resProvider.name + " at " + url)
-
-            try:
-                result.content = sickrage.app.wsession.get(url, verify=False, headers=headers).content
-                if result.resultType == "torrent":
-                    try:
-                        meta_info = bencode.bdecode(result.content)
-                        if meta_info.get('info'):
-                            if result.resultType == "torrent" and not resProvider.private:
-                                # add public trackers to torrent result
-                                result = resProvider.add_trackers(result)
-                            return result
-                    except BTFailure:
-                        pass
-                else:
-                    return result
-            except Exception:
-                pass
-
-            sickrage.app.log.debug("Failed to verify result: %s" % url)
-
-    result.content = None
-
-    return result
-
-
-def _download_result(result):
-    """
-    Downloads a result to the appropriate black hole folder.
-
-    :param result: SearchResult instance to download.
-    :return: boolean, True on success
-    """
-    downloaded = False
-
-    resProvider = result.provider
-    if resProvider is None:
-        sickrage.app.log.error("Invalid provider name - this is a coding error, report it please")
-        return False
-
-    filename = resProvider.make_filename(result.name)
-
-    # Support for Jackett/TorzNab
-    if result.url.endswith('torrent') and filename.endswith('nzb'):
-        filename = filename.rsplit('.', 1)[0] + '.' + 'torrent'
-
-    # nzbs with an URL can just be downloaded from the provider
-    if result.resultType == "nzb":
-        result = _verify_result(result)
-        if result.content:
-            sickrage.app.log.info("Saving NZB to " + filename)
-
-            # write content to torrent file
-            with io.open(filename, 'wb') as f:
-                f.write(result.content)
-
-            downloaded = True
-    # if it's an nzb data result
-    elif result.resultType == "nzbdata":
-        # get the final file path to the nzb
-        filename = os.path.join(sickrage.app.config.nzb_dir, result.name + ".nzb")
-
-        sickrage.app.log.info("Saving NZB to " + filename)
-
-        # save the data to disk
-        try:
-            with io.open(filename, 'w') as fileOut:
-                fileOut.write(result.extraInfo[0])
-
-            chmodAsParent(filename)
-
-            downloaded = True
-        except EnvironmentError as e:
-            sickrage.app.log.error("Error trying to save NZB to black hole: {}".format(e.message))
-    elif result.resultType == "torrent":
-        result = _verify_result(result)
-        if result.content:
-            sickrage.app.log.info("Saving TORRENT to " + filename)
-
-            # write content to torrent file
-            with io.open(filename, 'wb') as f:
-                f.write(result.content)
-
-            downloaded = True
-    else:
-        sickrage.app.log.error("Invalid provider type - this is a coding error, report it please")
-
-    return downloaded
-
-
 def snatchEpisode(result, endStatus=SNATCHED):
     """
     Contains the internal logic necessary to actually "snatch" a result that
@@ -171,16 +57,19 @@ def snatchEpisode(result, endStatus=SNATCHED):
             if date.today() - curEp.airdate <= timedelta(days=7):
                 result.priority = 1
 
-    if re.search(r'(^|[\. _-])(proper|repack)([\. _-]|$)', result.name, re.I) is not None:
+    if re.search(r'(^|[. _-])(proper|repack)([. _-]|$)', result.name, re.I) is not None:
         endStatus = SNATCHED_PROPER
 
     if result.url.startswith('magnet') or result.url.endswith('torrent'):
         result.resultType = 'torrent'
 
+    # get result content
+    result.content = result.provider.get_content(result.url)
+
     dlResult = False
     if result.resultType in ("nzb", "nzbdata"):
         if sickrage.app.config.nzb_method == "blackhole":
-            dlResult = _download_result(result)
+            dlResult = result.provider.download_result(result)
         elif sickrage.app.config.nzb_method == "sabnzbd":
             dlResult = SabNZBd.sendNZB(result)
         elif sickrage.app.config.nzb_method == "nzbget":
@@ -190,12 +79,16 @@ def snatchEpisode(result, endStatus=SNATCHED):
             sickrage.app.log.error(
                 "Unknown NZB action specified in config: " + sickrage.app.config.nzb_method)
     elif result.resultType == "torrent":
+        # add public trackers to torrent result
+        if not result.provider.private:
+            result = result.provider.add_trackers(result)
+
         if sickrage.app.config.torrent_method == "blackhole":
-            dlResult = _download_result(result)
+            dlResult = result.provider.download_result(result)
         else:
             if any([result.content, result.url.startswith('magnet:')]):
                 client = getClientIstance(sickrage.app.config.torrent_method)()
-                dlResult = client.sendTORRENT(result)
+                dlResult = client.send_torrent(result)
             else:
                 sickrage.app.log.warning("Torrent file content is empty")
     else:
@@ -205,8 +98,7 @@ def snatchEpisode(result, endStatus=SNATCHED):
     if not dlResult:
         return False
 
-    if sickrage.app.config.use_failed_downloads:
-        FailedHistory.logSnatch(result)
+    FailedHistory.logSnatch(result)
 
     sickrage.app.alerts.message(_('Episode snatched'), result.name)
 
@@ -226,7 +118,7 @@ def snatchEpisode(result, endStatus=SNATCHED):
 
         if curEpObj.status not in Quality.DOWNLOADED:
             try:
-                Notifiers.notify_snatch(
+                Notifiers.mass_notify_snatch(
                     curEpObj._format_pattern('%SN - %Sx%0E - %EN - %QN') + " from " + result.provider.name)
             except:
                 sickrage.app.log.debug("Failed to send snatch notification")
@@ -278,17 +170,19 @@ def pickBestResult(results, show):
             sickrage.app.log.debug(cur_result.name + " is a quality we know we don't want, rejecting it")
             continue
 
-        # check if seeders and leechers meet out minimum requirements, disgard result if it does not
-        if hasattr(cur_result.provider, 'minseed') and hasattr(cur_result.provider, 'minleech'):
-            if cur_result.seeders not in (-1, None) and cur_result.leechers not in (-1, None):
-                if int(cur_result.seeders) < int(cur_result.provider.minseed) or int(cur_result.leechers) < int(cur_result.provider.minleech):
-                    sickrage.app.log.info('Discarding torrent because it does not meet the minimum provider '
-                                                  'setting S:{} L:{}. Result has S:{} L:{}',
-                                                  cur_result.provider.minseed,
-                                                  cur_result.provider.minleech,
-                                                  cur_result.seeders,
-                                                  cur_result.leechers)
-                    continue
+        # check if seeders meet out minimum requirements, disgard result if it does not
+        if hasattr(cur_result.provider, 'minseed') and cur_result.seeders not in (-1, None):
+            if int(cur_result.seeders) < int(cur_result.provider.minseed):
+                sickrage.app.log.info("Discarding torrent because it doesn't meet the minimum seeders: {}. Seeders:  "
+                                      "{}".format(cur_result.name, cur_result.seeders))
+                continue
+
+        # check if leechers meet out minimum requirements, disgard result if it does not
+        if hasattr(cur_result.provider, 'minleech') and cur_result.leechers not in (-1, None):
+            if int(cur_result.leechers) < int(cur_result.provider.minleech):
+                sickrage.app.log.info("Discarding torrent because it doesn't meet the minimum leechers: {}. Leechers:  "
+                                      "{}".format(cur_result.name, cur_result.leechers))
+                continue
 
         if show.rls_ignore_words and show_names.containsAtLeastOneWord(cur_result.name,
                                                                        cur_result.show.rls_ignore_words):
@@ -308,40 +202,38 @@ def pickBestResult(results, show):
             continue
 
         if hasattr(cur_result, 'size'):
-            if sickrage.app.config.use_failed_downloads and FailedHistory.hasFailed(cur_result.name,
-                                                                                         cur_result.size,
-                                                                                         cur_result.provider.name):
+            if FailedHistory.hasFailed(cur_result.name, cur_result.size, cur_result.provider.name):
                 sickrage.app.log.info(cur_result.name + " has previously failed, rejecting it")
                 continue
 
-        # quality definition video file size constraints check
-        try:
-            quality_size = sickrage.app.config.quality_sizes[cur_result.quality]
-            for file, file_size in cur_result.files.items():
-                if not file.decode('utf-8').endswith(tuple(video_exts)):
-                    continue
-
-                file_size = float(file_size / 1000000)
+            # quality definition video file size constraints check
+            try:
+                quality_size = sickrage.app.config.quality_sizes[cur_result.quality]
+                file_size = float(cur_result.size / 1000000)
                 if file_size > quality_size:
                     raise Exception(
                         "Ignoring " + cur_result.name + " with size: {} based on quality size filter: {}".format(
                             file_size, quality_size)
                     )
-        except Exception as e:
-            sickrage.app.log.info(e.message)
-            continue
+            except Exception as e:
+                sickrage.app.log.info(str(e))
+                continue
 
         # verify result content
-        cur_result = _verify_result(cur_result)
-        if not cur_result.content:
-            sickrage.app.log.info(
-                "Ignoring " + cur_result.name + " because it does not have valid download url")
-            continue
+        if not cur_result.provider.private:
+            if cur_result.resultType in ["nzb", "torrent"] and not cur_result.provider.get_content(cur_result.url):
+                if sickrage.app.config.download_unverified_magnet_link and cur_result.url.startswith('magnet'):
+                    # Attempt downloading unverified torrent magnet link
+                    pass
+                else:
+                    sickrage.app.log.info(
+                        "Ignoring {} because we are unable to verify the download url".format(cur_result.name))
+                    continue
 
         if not bestResult:
             bestResult = cur_result
         elif cur_result.quality in bestQualities and (
-                        bestResult.quality < cur_result.quality or bestResult.quality not in bestQualities):
+                bestResult.quality < cur_result.quality or bestResult.quality not in bestQualities):
             bestResult = cur_result
         elif cur_result.quality in anyQualities and bestResult.quality not in bestQualities and bestResult.quality < cur_result.quality:
             bestResult = cur_result
@@ -408,76 +300,15 @@ def isFirstBestMatch(result):
 
     any_qualities, best_qualities = Quality.splitQuality(show_obj.quality)
 
-    # if there is a redownload that's a match to one of our best qualities and we want to archive the episode then we are done
-    if best_qualities and show_obj.archive_firstmatch and result.quality in best_qualities:
+    # if there is a re-download that's a match to one of our best qualities and we want to skip downloaded then we
+    # are done
+    if best_qualities and show_obj.skip_downloaded and result.quality in best_qualities:
         return True
 
     return False
 
 
-def wantedEpisodes(show, fromDate):
-    """
-    Get a list of episodes that we want to download
-    :param show: Show these episodes are from
-    :param fromDate: Search from a certain date
-    :return: list of wanted episodes
-    """
-
-    wanted = []
-    if show.paused:
-        sickrage.app.log.debug("Not checking for episodes of {} because the show is paused".format(show.name))
-        return wanted
-
-    anyQualities, bestQualities = Quality.splitQuality(show.quality)
-    allQualities = list(set(anyQualities + bestQualities))
-
-    sickrage.app.log.debug("Seeing if we need anything from {}".format(show.name))
-
-    # check through the list of statuses to see if we want any
-    for dbData in [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', show.indexerid, with_doc=True)
-                   if x['doc']['season'] > 0 and x['doc']['airdate'] > fromDate.toordinal()]:
-
-        curCompositeStatus = int(dbData["status"] or -1)
-        curStatus, curQuality = Quality.splitCompositeStatus(curCompositeStatus)
-
-        if bestQualities:
-            highestBestQuality = max(allQualities)
-        else:
-            highestBestQuality = 0
-
-        # if we need a better one then say yes
-        if (curStatus in (DOWNLOADED, SNATCHED,
-                          SNATCHED_PROPER) and curQuality < highestBestQuality) or curStatus == WANTED:
-            epObj = show.getEpisode(int(dbData["season"]), int(dbData["episode"]))
-            epObj.wantedQuality = [i for i in allQualities if (i > curQuality and i != Quality.UNKNOWN)]
-            wanted.append(epObj)
-
-    return wanted
-
-
-def searchForNeededEpisodes():
-    """
-    Check providers for details on wanted episodes
-
-    :return: episodes we have a search hit for
-    """
-
-    results = []
-
-    for curShow in sickrage.app.showlist:
-        if curShow.paused:
-            continue
-
-        curShow.nextEpisode()
-
-        episodes = wantedEpisodes(curShow, date.fromordinal(1))
-        result = searchProviders(curShow, episodes, cacheOnly=sickrage.app.config.enable_rss_cache)
-        if result: results += result
-
-    return results
-
-
-def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, cacheOnly=False):
+def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, updateCache=True, cacheOnly=False):
     """
     Walk providers for information on shows
 
@@ -498,28 +329,31 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
     origThreadName = threading.currentThread().getName()
 
     def perform_searches():
-        foundResults = {}
-        finalResults = []
+        search_results = {}
+        found_results = {}
+        final_results = []
 
         for providerID, providerObj in sickrage.app.search_providers.sort(
                 randomize=sickrage.app.config.randomize_providers).items():
 
-            # check provider type and provider is enabled
+            # check if provider is enabled
+            if not providerObj.isEnabled:
+                continue
+
+            # check provider type
             if not sickrage.app.config.use_nzbs and providerObj.type in [NZBProvider.type, NewznabProvider.type]:
                 continue
             elif not sickrage.app.config.use_torrents and providerObj.type in [TorrentProvider.type,
-                                                                                    TorrentRssProvider.type]:
-                continue
-            elif not providerObj.isEnabled:
+                                                                               TorrentRssProvider.type]:
                 continue
 
             if providerObj.anime_only and not show.is_anime:
                 sickrage.app.log.debug("" + str(show.name) + " is not an anime, skiping")
                 continue
 
-            foundResults[providerObj.name] = {}
+            found_results[providerObj.name] = {}
 
-            searchCount = 0
+            search_count = 0
             search_mode = providerObj.search_mode
 
             # Always search for episode when manually searching when in sponly
@@ -527,13 +361,14 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
                 search_mode = 'eponly'
 
             while True:
-                searchCount += 1
+                search_count += 1
 
                 try:
                     threading.currentThread().setName(origThreadName + "::[" + providerObj.name + "]")
 
                     # update provider RSS cache
-                    if sickrage.app.config.enable_rss_cache: providerObj.cache.update()
+                    if sickrage.app.config.enable_rss_cache and updateCache:
+                        providerObj.cache.update()
 
                     if len(episodes):
                         if search_mode == 'eponly':
@@ -542,36 +377,36 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
                             sickrage.app.log.info("Performing season pack search for " + show.name)
 
                     # search provider for episodes
-                    searchResults = providerObj.findSearchResults(show,
-                                                                  episodes,
-                                                                  search_mode,
-                                                                  manualSearch,
-                                                                  downCurQuality,
-                                                                  cacheOnly)
+                    search_results = providerObj.findSearchResults(show,
+                                                                   episodes,
+                                                                   search_mode,
+                                                                   manualSearch,
+                                                                   downCurQuality,
+                                                                   cacheOnly)
                 except AuthException as e:
-                    sickrage.app.log.warning("Authentication error: {}".format(e.message))
+                    sickrage.app.log.warning("Authentication error: {}".format(e))
                     break
                 except Exception as e:
                     sickrage.app.log.error(
-                        "Error while searching " + providerObj.name + ", skipping: {}".format(e.message))
+                        "Error while searching " + providerObj.name + ", skipping: {}".format(e))
                     break
                 finally:
                     threading.currentThread().setName(origThreadName)
 
-                if len(searchResults):
+                if len(search_results):
                     # make a list of all the results for this provider
-                    for curEp in searchResults:
-                        if curEp in foundResults:
-                            foundResults[providerObj.name][curEp] += searchResults[curEp]
+                    for curEp in search_results:
+                        if curEp in found_results:
+                            found_results[providerObj.name][curEp] += search_results[curEp]
                         else:
-                            foundResults[providerObj.name][curEp] = searchResults[curEp]
+                            found_results[providerObj.name][curEp] = search_results[curEp]
 
                         # Sort results by seeders if available
                         if providerObj.type == 'torrent' or getattr(providerObj, 'torznab', False):
-                            foundResults[providerObj.name][curEp].sort(key=lambda k: int(k.seeders), reverse=True)
+                            found_results[providerObj.name][curEp].sort(key=lambda k: int(k.seeders), reverse=True)
 
                     break
-                elif not providerObj.search_fallback or searchCount == 2:
+                elif not providerObj.search_fallback or search_count == 2:
                     break
 
                 if search_mode == 'sponly':
@@ -582,17 +417,17 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
                     search_mode = 'sponly'
 
             # skip to next provider if we have no results to process
-            if not len(foundResults[providerObj.name]):
+            if not len(found_results[providerObj.name]):
                 continue
 
             # pick the best season NZB
             bestSeasonResult = None
-            if SEASON_RESULT in foundResults[providerObj.name]:
-                bestSeasonResult = pickBestResult(foundResults[providerObj.name][SEASON_RESULT], show)
+            if SEASON_RESULT in found_results[providerObj.name]:
+                bestSeasonResult = pickBestResult(found_results[providerObj.name][SEASON_RESULT], show)
 
             highest_quality_overall = 0
-            for cur_episode in foundResults[providerObj.name]:
-                for cur_result in foundResults[providerObj.name][cur_episode]:
+            for cur_episode in found_results[providerObj.name]:
+                for cur_result in found_results[providerObj.name][cur_episode]:
                     if cur_result.quality != Quality.UNKNOWN and cur_result.quality > highest_quality_overall:
                         highest_quality_overall = cur_result.quality
 
@@ -610,9 +445,8 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
                     Quality.qualityStrings[
                         seasonQual])
 
-                allEps = [int(x['doc']["episode"]) for x in
-                          sickrage.app.main_db.db.get_many('tv_episodes', show.indexerid, with_doc=True)
-                          if x['doc']['season'] in searchedSeasons]
+                allEps = [int(x["episode"]) for x in sickrage.app.main_db.get_many('tv_episodes', show.indexerid)
+                          if x['season'] in searchedSeasons]
 
                 sickrage.app.log.debug("Episode list: " + str(allEps))
 
@@ -625,7 +459,8 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
                         else:
                             anyWanted = True
 
-                # if we need every ep in the season and there's nothing better then just download this and be done with it (unless single episodes are preferred)
+                # if we need every ep in the season and there's nothing better then just download this and be done
+                # with it (unless single episodes are preferred)
                 if allWanted and bestSeasonResult.quality == highest_quality_overall:
                     sickrage.app.log.info(
                         "Every ep in this season is needed, downloading the whole " + bestSeasonResult.provider.type + " " + bestSeasonResult.name)
@@ -650,15 +485,16 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
                         # if not, break it apart and add them as the lowest priority results
                         individualResults = splitNZBResult(bestSeasonResult)
                         for curResult in individualResults:
+                            epNum = -1
                             if len(curResult.episodes) == 1:
                                 epNum = curResult.episodes[0].episode
                             elif len(curResult.episodes) > 1:
                                 epNum = MULTI_EP_RESULT
 
-                            if epNum in foundResults[providerObj.name]:
-                                foundResults[providerObj.name][epNum].append(curResult)
+                            if epNum in found_results[providerObj.name]:
+                                found_results[providerObj.name][epNum].append(curResult)
                             else:
-                                foundResults[providerObj.name][epNum] = [curResult]
+                                found_results[providerObj.name][epNum] = [curResult]
 
                     # If this is a torrent all we can do is leech the entire torrent, user will have to select which eps not do download in his torrent client
                     else:
@@ -672,15 +508,15 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
                                 epObjs.append(show.getEpisode(season, curEpNum))
                         bestSeasonResult.episodes = epObjs
 
-                        if MULTI_EP_RESULT in foundResults[providerObj.name]:
-                            foundResults[providerObj.name][MULTI_EP_RESULT].append(bestSeasonResult)
+                        if MULTI_EP_RESULT in found_results[providerObj.name]:
+                            found_results[providerObj.name][MULTI_EP_RESULT].append(bestSeasonResult)
                         else:
-                            foundResults[providerObj.name][MULTI_EP_RESULT] = [bestSeasonResult]
+                            found_results[providerObj.name][MULTI_EP_RESULT] = [bestSeasonResult]
 
             # go through multi-ep results and see if we really want them or not, get rid of the rest
             multiResults = {}
-            if MULTI_EP_RESULT in foundResults[providerObj.name]:
-                for _multiResult in foundResults[providerObj.name][MULTI_EP_RESULT]:
+            if MULTI_EP_RESULT in found_results[providerObj.name]:
+                for _multiResult in found_results[providerObj.name][MULTI_EP_RESULT]:
 
                     sickrage.app.log.debug(
                         "Seeing if we want to bother with multi-episode result " + _multiResult.name)
@@ -695,8 +531,8 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
                     notNeededEps = []
                     for epObj in multiResult.episodes:
                         # if we have results for the episode
-                        if epObj.episode in foundResults[providerObj.name] and len(
-                                foundResults[providerObj.name][epObj.episode]) > 0:
+                        if epObj.episode in found_results[providerObj.name] and len(
+                                found_results[providerObj.name][epObj.episode]) > 0:
                             notNeededEps.append(epObj.episode)
                         else:
                             neededEps.append(epObj.episode)
@@ -732,42 +568,42 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
                     # don't bother with the single result if we're going to get it with a multi result
                     for epObj in multiResult.episodes:
                         multiResults[epObj.episode] = multiResult
-                        if epObj.episode in foundResults[providerObj.name]:
+                        if epObj.episode in found_results[providerObj.name]:
                             sickrage.app.log.debug(
                                 "A needed multi-episode result overlaps with a single-episode result for ep #" + str(
                                     epObj.episode) + ", removing the single-episode results from the list")
-                            del foundResults[providerObj.name][epObj.episode]
+                            del found_results[providerObj.name][epObj.episode]
 
             # of all the single ep results narrow it down to the best one for each episode
-            finalResults += set(multiResults.values())
-            for curEp in foundResults[providerObj.name]:
+            final_results += set(multiResults.values())
+            for curEp in found_results[providerObj.name]:
                 if curEp in (MULTI_EP_RESULT, SEASON_RESULT):
                     continue
 
-                if not len(foundResults[providerObj.name][curEp]) > 0:
+                if not len(found_results[providerObj.name][curEp]) > 0:
                     continue
 
                 # if all results were rejected move on to the next episode
-                bestResult = pickBestResult(foundResults[providerObj.name][curEp], show)
+                bestResult = pickBestResult(found_results[providerObj.name][curEp], show)
                 if not bestResult:
                     continue
 
                 # add result if its not a duplicate and
                 found = False
-                for i, result in enumerate(finalResults):
+                for i, result in enumerate(final_results):
                     for bestResultEp in bestResult.episodes:
                         if bestResultEp in result.episodes:
                             if result.quality < bestResult.quality:
-                                finalResults.pop(i)
+                                final_results.pop(i)
                             else:
                                 found = True
                 if not found:
-                    finalResults += [bestResult]
+                    final_results += [bestResult]
 
             # check that we got all the episodes we wanted first before doing a match and snatch
             wantedEpCount = 0
             for wantedEp in episodes:
-                for result in finalResults:
+                for result in final_results:
                     if wantedEp in result.episodes and isFinalResult(result):
                         wantedEpCount += 1
 
@@ -775,6 +611,6 @@ def searchProviders(show, episodes, manualSearch=False, downCurQuality=False, ca
             if wantedEpCount == len(episodes):
                 break
 
-        return finalResults
+        return final_results
 
     return perform_searches()
