@@ -46,7 +46,7 @@ class ProperSearcher(object):
         Start looking for new propers
         :param force: Start even if already running (currently not used, defaults to False)
         """
-        if self.amActive or sickrage.app.developer and not force:
+        if self.amActive or (not sickrage.app.config.download_propers or sickrage.app.developer) and not force:
             return
 
         self.amActive = True
@@ -60,8 +60,6 @@ class ProperSearcher(object):
         if propers:
             self._downloadPropers(propers)
 
-        self._set_lastProperSearch(datetime.datetime.today().toordinal())
-
         sickrage.app.log.info("Completed the search for new propers")
 
         self.amActive = False
@@ -77,13 +75,16 @@ class ProperSearcher(object):
         origThreadName = threading.currentThread().getName()
 
         recently_aired = []
-        for show in [s['doc'] for s in sickrage.app.main_db.db.all('tv_shows', with_doc=True)]:
-            for episode in [e['doc'] for e in
-                            sickrage.app.main_db.db.get_many('tv_episodes', show['indexer_id'], with_doc=True)]:
+        for show in sickrage.app.showlist:
+            self._lastProperSearch = self._get_lastProperSearch(show.indexerid)
+
+            for episode in sickrage.app.main_db.get_many('tv_episodes', show.indexerid):
                 if episode['airdate'] >= str(search_date.toordinal()):
                     if episode['status'] in Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_BEST:
                         recently_aired += [episode]
 
+            self._set_lastProperSearch(show.indexerid, datetime.datetime.today().toordinal())
+
         if not recently_aired:
             sickrage.app.log.info('No recently aired episodes, nothing to search for')
             return []
@@ -93,10 +94,10 @@ class ProperSearcher(object):
                 randomize=sickrage.app.config.randomize_providers).items():
             # check provider type and provider is enabled
             if not sickrage.app.config.use_nzbs and providerObj.type in [NZBProvider.type,
-                                                                              NewznabProvider.type]:
+                                                                         NewznabProvider.type]:
                 continue
             elif not sickrage.app.config.use_torrents and providerObj.type in [TorrentProvider.type,
-                                                                                    TorrentRssProvider.type]:
+                                                                               TorrentRssProvider.type]:
                 continue
             elif not providerObj.isEnabled:
                 continue
@@ -108,17 +109,17 @@ class ProperSearcher(object):
             try:
                 curPropers = providerObj.find_propers(recently_aired)
             except AuthException as e:
-                sickrage.app.log.warning("Authentication error: {}".format(e.message))
+                sickrage.app.log.warning("Authentication error: {}".format(e))
                 continue
             except Exception as e:
                 sickrage.app.log.debug(
-                    "Error while searching " + providerObj.name + ", skipping: {}".format(e.message))
+                    "Error while searching " + providerObj.name + ", skipping: {}".format(e))
                 sickrage.app.log.debug(traceback.format_exc())
                 continue
 
             # if they haven't been added by a different provider than add the proper to the list
             for x in curPropers:
-                if not re.search(r'(^|[\. _-])(proper|repack)([\. _-]|$)', x.name, re.I):
+                if not re.search(r'(^|[. _-])(proper|repack)([. _-]|$)', x.name, re.I):
                     sickrage.app.log.debug('findPropers returned a non-proper, we have caught and skipped it.')
                     continue
 
@@ -135,7 +136,6 @@ class ProperSearcher(object):
         finalPropers = []
 
         for curProper in sortedPropers:
-
             try:
                 myParser = NameParser(False)
                 parse_result = myParser.parse(curProper.name)
@@ -187,10 +187,11 @@ class ProperSearcher(object):
                     continue
 
             # check if we actually want this proper (if it's the right quality)            
-            dbData = [x['doc'] for x in
-                      sickrage.app.main_db().db.get_many('tv_episodes', bestResult.indexerid, with_doc=True)
-                      if x['doc']['season'] == bestResult.season and x['doc']['episode'] == bestResult.episode]
-            if not dbData: continue
+            dbData = [x for x in sickrage.app.main_db().get_many('tv_episodes', bestResult.indexerid)
+                      if x['season'] == bestResult.season and x['episode'] == bestResult.episode]
+
+            if not dbData:
+                continue
 
             # only keep the proper if we have already retrieved the same quality ep (don't get better/worse ones)
             oldStatus, oldQuality = Quality.splitCompositeStatus(int(dbData[0]["status"]))
@@ -199,9 +200,8 @@ class ProperSearcher(object):
 
             # check if we actually want this proper (if it's the right release group and a higher version)
             if bestResult.show.is_anime:
-                dbData = [x['doc'] for x in
-                          sickrage.app.main_db.db.get_many('tv_episodes', bestResult.indexerid, with_doc=True)
-                          if x['doc']['season'] == bestResult.season and x['doc']['episode'] == bestResult.episode]
+                dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', bestResult.indexerid)
+                          if x['season'] == bestResult.season and x['episode'] == bestResult.episode]
 
                 oldVersion = int(dbData[0]["version"])
                 oldRelease_group = (dbData[0]["release_group"])
@@ -236,12 +236,12 @@ class ProperSearcher(object):
             historyLimit = datetime.datetime.today() - datetime.timedelta(days=30)
 
             # make sure the episode has been downloaded before
-            historyResults = [x for x in
-                              sickrage.app.main_db.db.get_many('history', curProper.indexerid, with_doc=True)
-                              if x['doc']['season'] == curProper.season and x['doc']['episode'] == curProper.episode
-                              and x['doc']['quality'] == curProper.quality
-                              and x['doc']['date'] >= historyLimit.strftime(History.date_format)
-                              and x['doc']['action'] in Quality.SNATCHED + Quality.DOWNLOADED]
+            historyResults = [x for x in sickrage.app.main_db.get_many('history', curProper.indexerid)
+                              if x['season'] == curProper.season
+                              and x['episode'] == curProper.episode
+                              and x['quality'] == curProper.quality
+                              and x['date'] >= historyLimit.strftime(History.date_format)
+                              and x['action'] in Quality.SNATCHED + Quality.DOWNLOADED]
 
             # if we didn't download this episode in the first place we don't know what quality to use for the proper so we can't do it
             if len(historyResults) == 0:
@@ -285,7 +285,7 @@ class ProperSearcher(object):
     def _genericName(self, name):
         return name.replace(".", " ").replace("-", " ").replace("_", " ").lower()
 
-    def _set_lastProperSearch(self, when):
+    def _set_lastProperSearch(self, showid, when):
         """
         Record last propersearch in DB
 
@@ -294,28 +294,20 @@ class ProperSearcher(object):
 
         sickrage.app.log.debug("Setting the last proper search in database to " + str(when))
 
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.all('info', with_doc=True)]
-        if len(dbData) == 0:
-            sickrage.app.main_db.db.insert({
-                '_t': 'info',
-                'last_backlog': 0,
-                'last_indexer': 0,
-                'last_proper_search': str(when)
-            })
-        else:
-            dbData[0]['last_proper_search'] = str(when)
-            sickrage.app.main_db.db.update(dbData[0])
+        dbData = sickrage.app.main_db.get('tv_shows', showid)
+        dbData['last_proper_search'] = when
+        sickrage.app.main_db.update(dbData)
 
     @staticmethod
-    def _get_lastProperSearch():
+    def _get_lastProperSearch(showid):
         """
         Find last propersearch from DB
         """
 
-        try:
-            dbData = [x['doc'] for x in sickrage.app.main_db.db.all('info', with_doc=True)]
-            last_proper_search = datetime.date.fromordinal(int(dbData[0]["last_proper_search"]))
-        except:
-            last_proper_search = datetime.date.fromordinal(1)
+        sickrage.app.log.debug("Retrieving the last check time from the DB")
 
-        return last_proper_search
+        try:
+            dbData = sickrage.app.main_db.get('tv_shows', showid)
+            return int(dbData["last_proper_search"])
+        except:
+            return 1
