@@ -30,7 +30,7 @@ from sickrage.core.common import Quality, UNKNOWN, UNAIRED, statusStrings, dateT
     NAMING_LIMITED_EXTEND, NAMING_LIMITED_EXTEND_E_PREFIXED, NAMING_DUPLICATE, NAMING_SEPARATED_REPEAT
 from sickrage.core.exceptions import NoNFOException, \
     EpisodeNotFoundException, EpisodeDeletedException
-from sickrage.core.helpers import isMediaFile, try_int, replaceExtension, \
+from sickrage.core.helpers import is_media_file, try_int, replaceExtension, \
     touchFile, sanitizeSceneName, remove_non_release_groups, remove_extension, sanitizeFileName, \
     safe_getattr, make_dirs, moveFile, delete_empty_folders
 from sickrage.core.nameparser import NameParser, InvalidNameException, InvalidShowException
@@ -292,7 +292,7 @@ class TVEpisode(object):
     def downloadSubtitles(self):
         if not os.path.isfile(self.location):
             sickrage.app.log.debug("%s: Episode file doesn't exist, can't download subtitles for S%02dE%02d" %
-                                           (self.show.indexerid, self.season or 0, self.episode or 0))
+                                   (self.show.indexerid, self.season or 0, self.episode or 0))
             return
 
         sickrage.app.log.debug(
@@ -308,12 +308,12 @@ class TVEpisode(object):
         if newSubtitles:
             subtitleList = ", ".join([name_from_code(newSub) for newSub in newSubtitles])
             sickrage.app.log.debug("%s: Downloaded %s subtitles for S%02dE%02d" %
-                                           (self.show.indexerid, subtitleList, self.season or 0, self.episode or 0))
+                                   (self.show.indexerid, subtitleList, self.season or 0, self.episode or 0))
 
-            Notifiers.notify_subtitle_download(self.pretty_name(), subtitleList)
+            Notifiers.mass_notify_subtitle_download(self.pretty_name(), subtitleList)
         else:
             sickrage.app.log.debug("%s: No subtitles downloaded for S%02dE%02d" %
-                                           (self.show.indexerid, self.season or 0, self.episode or 0))
+                                   (self.show.indexerid, self.season or 0, self.episode or 0))
 
         return newSubtitles
 
@@ -377,13 +377,12 @@ class TVEpisode(object):
         sickrage.app.log.debug("%s: Loading episode details from DB for episode %s S%02dE%02d" % (
             self.show.indexerid, self.show.name, season or 0, episode or 0))
 
-        dbData = [x['doc'] for x in
-                  sickrage.app.main_db.db.get_many('tv_episodes', self.show.indexerid, with_doc=True)
-                  if x['doc']['season'] == season and x['doc']['episode'] == episode]
+        dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', self.show.indexerid)
+                  if x['season'] == season and x['episode'] == episode]
 
         if len(dbData) > 1:
             for ep in dbData:
-                sickrage.app.main_db.db.delete(ep)
+                sickrage.app.main_db.delete(ep)
             return False
         elif len(dbData) == 0:
             sickrage.app.log.debug("%s: Episode S%02dE%02d not found in the database" % (
@@ -461,7 +460,7 @@ class TVEpisode(object):
                 myEp = cachedSeason[episode]
 
         except (indexer_error, IOError) as e:
-            sickrage.app.log.debug("{} threw up an error: {}".format(indexer_name, e.message))
+            sickrage.app.log.debug("{} threw up an error: {}".format(indexer_name, e))
 
             # if the episode is already valid just log it, if not throw it up
             if self.name:
@@ -544,8 +543,8 @@ class TVEpisode(object):
 
         if self.location:
             sickrage.app.log.debug("%s: Setting status for S%02dE%02d based on status %s and location %s" %
-                                           (self.show.indexerid, season or 0, episode or 0, statusStrings[self.status],
-                                            self.location))
+                                   (self.show.indexerid, season or 0, episode or 0, statusStrings[self.status],
+                                    self.location))
 
         if not os.path.isfile(self.location):
             if self.airdate >= datetime.date.today() or self.airdate == datetime.date.fromordinal(1):
@@ -564,7 +563,7 @@ class TVEpisode(object):
                         self.status])
 
         # if we have a media file then it's downloaded
-        elif isMediaFile(self.location):
+        elif is_media_file(self.location):
             # leave propers alone, you have to either post-process them or manually change them back
             if self.status not in Quality.SNATCHED_PROPER + Quality.DOWNLOADED + Quality.SNATCHED + Quality.ARCHIVED:
                 sickrage.app.log.debug(
@@ -591,7 +590,7 @@ class TVEpisode(object):
         if os.path.isfile(location):
             self.location = location
             if self.status == UNKNOWN:
-                if isMediaFile(self.location):
+                if is_media_file(self.location):
                     sickrage.app.log.debug("7 Status changes from " + str(self.status) + " to " + str(
                         Quality.statusFromName(self.location, anime=self.show.is_anime)))
                     self.status = Quality.statusFromName(self.location, anime=self.show.is_anime)
@@ -605,13 +604,12 @@ class TVEpisode(object):
                     showXML = ElementTree(file=nfoFile)
                 except (SyntaxError, ValueError) as e:
                     sickrage.app.log.error(
-                        "Error loading the NFO, backing up the NFO and skipping for now: {}".format(e.message))
+                        "Error loading the NFO, backing up the NFO and skipping for now: {}".format(e))
                     try:
                         os.rename(nfoFile, nfoFile + ".old")
                     except Exception as e:
                         sickrage.app.log.error(
-                            "Failed to rename your episode's NFO file - you need to delete it or fix it: {}".format(
-                                e.message))
+                            "Failed to rename your episode's NFO file - you need to delete it or fix it: {}".format(e))
                     raise NoNFOException("Error in NFO format")
 
                 for epDetails in showXML.iter('episodedetails'):
@@ -676,34 +674,34 @@ class TVEpisode(object):
         toReturn += "status: %r\n" % self.status
         return toReturn
 
-    def createMetaFiles(self):
+    def createMetaFiles(self, force=False):
 
         if not os.path.isdir(self.show.location):
             sickrage.app.log.info(
                 str(self.show.indexerid) + ": The show dir is missing, not bothering to try to create metadata")
             return
 
-        self.createNFO()
-        self.createThumbnail()
+        self.createNFO(force)
+        self.createThumbnail(force)
 
         if self.checkForMetaFiles():
             self.saveToDB()
 
-    def createNFO(self):
+    def createNFO(self, force=False):
 
         result = False
 
         for cur_provider in sickrage.app.metadata_providers.values():
-            result = cur_provider.create_episode_metadata(self) or result
+            result = cur_provider.create_episode_metadata(self, force) or result
 
         return result
 
-    def createThumbnail(self):
+    def createThumbnail(self, force=False):
 
         result = False
 
         for cur_provider in sickrage.app.metadata_providers.values():
-            result = cur_provider.create_episode_thumb(self) or result
+            result = cur_provider.create_episode_thumb(self, force) or result
 
         return result
 
@@ -720,9 +718,9 @@ class TVEpisode(object):
         # delete myself from the DB
         sickrage.app.log.debug("Deleting myself from the database")
 
-        [sickrage.app.main_db.db.delete(x['doc']) for x in
-         sickrage.app.main_db.db.get_many('tv_episodes', self.show.indexerid, with_doc=True)
-         if x['doc']['season'] == self.season and x['doc']['episode'] == self.episode]
+        [sickrage.app.main_db.delete(x) for x in
+         sickrage.app.main_db.get_many('tv_episodes', self.show.indexerid)
+         if x['season'] == self.season and x['episode'] == self.episode]
 
         data = sickrage.app.notifier_providers['trakt'].trakt_episode_data_generate([(self.season, self.episode)])
         if sickrage.app.config.use_trakt and sickrage.app.config.trakt_sync_watchlist and data:
@@ -780,14 +778,13 @@ class TVEpisode(object):
         }
 
         try:
-            dbData = \
-                [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', self.show.indexerid, with_doc=True)
-                 if x['doc']['indexerid'] == self.indexerid][0]
+            dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', self.show.indexerid)
+                      if x['indexerid'] == self.indexerid][0]
 
             dbData.update(tv_episode)
-            sickrage.app.main_db.db.update(dbData)
+            sickrage.app.main_db.update(dbData)
         except:
-            sickrage.app.main_db.db.insert(tv_episode)
+            sickrage.app.main_db.insert(tv_episode)
 
     def fullPath(self):
         if self.location is None or self.location == "":
@@ -882,16 +879,13 @@ class TVEpisode(object):
                 str(self.indexerid) + ": File " + self.location + " is already named correctly, skipping")
             return
 
-        related_files = PostProcessor(self.location).list_associated_files(
-            self.location, base_name_only=True, subfolders=True)
+        related_files = PostProcessor(self.location).list_associated_files(self.location, subfolders=True)
 
         # This is wrong. Cause of pp not moving subs.
-        if self.show.subtitles and sickrage.app.config.subtitles_dir != '':
-            related_subs = PostProcessor(self.location).list_associated_files(
-                sickrage.app.config.subtitles_dir,
-                subtitles_only=True,
-                subfolders=True)
-            absolute_proper_subs_path = os.path.join(sickrage.app.config.subtitles_dir, self.formatted_filename())
+        if self.show.subtitles and sickrage.app.config.subtitles_dir:
+            subs_path = os.path.join(sickrage.app.config.subtitles_dir, os.path.basename(self.location))
+            related_subs = PostProcessor(self.location).list_associated_files(subs_path, subtitles_only=True,
+                                                                              subfolders=True, rename=True)
 
         sickrage.app.log.debug("Files associated to " + self.location + ": " + str(related_files))
 
@@ -1050,7 +1044,7 @@ class TVEpisode(object):
             try:
                 parse_result = NameParser(name, showObj=show, naming_pattern=True).parse(name)
             except (InvalidNameException, InvalidShowException) as e:
-                sickrage.app.log.debug("Unable to get parse release_group: {}".format(e.message))
+                sickrage.app.log.debug("Unable to get parse release_group: {}".format(e))
                 return ''
 
             if not parse_result.release_group:
