@@ -27,24 +27,24 @@ import stat
 import threading
 import traceback
 
-import imdbpie
 import send2trash
-from CodernityDB.database import RecordNotFound
+from CodernityDB.database import RecordNotFound, RevConflict
 from unidecode import unidecode
 
 import sickrage
+from sickrage.core.api.imdb import IMDbAPI
 from sickrage.core.blackandwhitelist import BlackAndWhiteList
 from sickrage.core.caches import image_cache
 from sickrage.core.classes import ShowListUI
 from sickrage.core.common import Quality, SKIPPED, WANTED, UNKNOWN, DOWNLOADED, IGNORED, SNATCHED, SNATCHED_PROPER, \
-    UNAIRED, ARCHIVED, statusStrings, Overview, FAILED, SNATCHED_BEST
-from sickrage.core.exceptions import MultipleShowObjectsException, ShowNotFoundException, \
-    EpisodeNotFoundException, EpisodeDeletedException, MultipleShowsInDatabaseException
-from sickrage.core.helpers import list_media_files, isMediaFile, findCertainShow, try_int, safe_getattr
+    UNAIRED, ARCHIVED, statusStrings, Overview
+from sickrage.core.exceptions import ShowNotFoundException, \
+    EpisodeNotFoundException, EpisodeDeletedException, MultipleShowsInDatabaseException, MultipleShowObjectsException
+from sickrage.core.helpers import list_media_files, is_media_file, try_int, safe_getattr, findCertainShow
 from sickrage.core.nameparser import NameParser, InvalidNameException, InvalidShowException
 from sickrage.indexers import IndexerApi
 from sickrage.indexers.config import INDEXER_TVRAGE
-from sickrage.indexers.exceptions import indexer_seasonnotfound, indexer_attributenotfound
+from sickrage.indexers.exceptions import indexer_attributenotfound
 
 
 class TVShow(object):
@@ -71,7 +71,7 @@ class TVShow(object):
         self._subtitles = int(sickrage.app.config.subtitles_default)
         self._subtitles_sr_metadata = 0
         self._dvdorder = 0
-        self._archive_firstmatch = 0
+        self._skip_downloaded = 0
         self._lang = lang
         self._last_update = datetime.datetime.now().toordinal()
         self._last_refresh = datetime.datetime.now().toordinal()
@@ -81,15 +81,16 @@ class TVShow(object):
         self._rls_ignore_words = ""
         self._rls_require_words = ""
         self._default_ep_status = SKIPPED
+        self._notify_list = ""
+        self._search_delay = 0
         self.dirty = True
 
         self._location = ""
+        self._next_aired = ""
         self.episodes = {}
-        self.next_aired = ""
         self.release_groups = None
 
-        otherShow = findCertainShow(sickrage.app.showlist, self.indexerid)
-        if otherShow is not None:
+        if findCertainShow(self.indexerid) is not None:
             raise MultipleShowObjectsException("Can't create a show if it already exists")
 
         self.loadFromDB()
@@ -285,14 +286,14 @@ class TVShow(object):
         self._dvdorder = value
 
     @property
-    def archive_firstmatch(self):
-        return self._archive_firstmatch
+    def skip_downloaded(self):
+        return self._skip_downloaded
 
-    @archive_firstmatch.setter
-    def archive_firstmatch(self, value):
-        if self._archive_firstmatch != value:
+    @skip_downloaded.setter
+    def skip_downloaded(self, value):
+        if self._skip_downloaded != value:
             self.dirty = True
-        self._archive_firstmatch = value
+        self._skip_downloaded = value
 
     @property
     def lang(self):
@@ -384,6 +385,26 @@ class TVShow(object):
             self.dirty = True
         self._default_ep_status = value
 
+    @property
+    def notify_list(self):
+        return self._notify_list
+
+    @notify_list.setter
+    def notify_list(self, value):
+        if self._notify_list != value:
+            self.dirty = True
+        self._notify_list = value
+
+    @property
+    def search_delay(self):
+        return self._search_delay
+
+    @search_delay.setter
+    def search_delay(self, value):
+        if self._search_delay != value:
+            self.dirty = True
+        self._search_delay = value
+
     @property
     def subtitles_sr_metadata(self):
         return self._subtitles_sr_metadata
@@ -410,6 +431,19 @@ class TVShow(object):
     def network_logo_name(self):
         return unidecode(self.network).lower()
 
+    @property
+    def next_aired(self):
+        if not self.paused:
+            curDate = datetime.date.today()
+
+            if not self._next_aired or self._next_aired and curDate.toordinal() > self._next_aired:
+                dbData = sorted([x for x in sickrage.app.main_db.get_many('tv_episodes', self.indexerid)
+                                 if x['airdate'] >= curDate.toordinal()
+                                 and x['status'] in (UNAIRED, WANTED)], key=lambda d: d['airdate'])
+
+                self._next_aired = dbData[0]['airdate'] if dbData else ''
+        return self._next_aired
+
     @property
     def location(self):
         return self._location
@@ -431,17 +465,14 @@ class TVShow(object):
 
     def getAllEpisodes(self, season=None, has_location=False):
         results = []
-        for x in [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)]:
-            if season and x['season'] != season:
-                continue
-            if has_location and x['location'] == '':
+        for x in sickrage.app.main_db.get_many('tv_episodes', self.indexerid):
+            if (season and x['season'] != season) or (has_location and x['location'] == ''):
                 continue
 
             results += [x]
 
         ep_list = []
-        for cur_result in [x['doc'] for x in
-                           sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)]:
+        for cur_result in sickrage.app.main_db.get_many('tv_episodes', self.indexerid):
             cur_ep = self.getEpisode(int(cur_result["season"]), int(cur_result["episode"]))
             if not cur_ep:
                 continue
@@ -451,16 +482,14 @@ class TVShow(object):
                 # if there is a location, check if it's a multi-episode (share_location > 0) and put them in relatedEps
                 if len([r for r in results
                         if r['showid'] == cur_result['showid']
-                        and r['season'] == cur_result['season']
-                        and r['location'] != '' and r['location'] == cur_result['location']
-                        and r['episode'] != cur_result['episode']]) > 0:
+                           and r['season'] == cur_result['season']
+                           and r['location'] != '' and r['location'] == cur_result['location']
+                           and r['episode'] != cur_result['episode']]) > 0:
 
-                    related_eps_result = sorted([x['doc'] for x in
-                                                 sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid,
-                                                                                    with_doc=True)
-                                                 if x['doc']['season'] == cur_ep.season
-                                                 and x['doc']['location'] == cur_ep.location
-                                                 and x['doc']['episode'] == cur_ep.episode], key=lambda d: d['episode'])
+                    related_eps_result = sorted([x for x in sickrage.app.main_db.get_many('tv_episodes', self.indexerid)
+                                                 if x['season'] == cur_ep.season
+                                                 and x['location'] == cur_ep.location
+                                                 and x['episode'] == cur_ep.episode], key=lambda d: d['episode'])
 
                     for cur_related_ep in related_eps_result:
                         related_ep = self.getEpisode(int(cur_related_ep["season"]), int(cur_related_ep["episode"]))
@@ -475,8 +504,8 @@ class TVShow(object):
 
         # if we get an anime get the real season and episode
         if self.is_anime and absolute_number and not season and not episode:
-            dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)
-                      if x['doc']['absolute_number'] == absolute_number and x['doc']['season'] != 0]
+            dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', self.indexerid)
+                      if x['absolute_number'] == absolute_number and x['season'] != 0]
 
             if len(dbData) == 1:
                 episode = int(dbData[0]["episode"])
@@ -522,10 +551,9 @@ class TVShow(object):
         last_airdate = datetime.date.fromordinal(1)
 
         # get latest aired episode to compare against today - graceperiod and today + graceperiod
-        dbData = sorted(
-            [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)
-             if x['doc']['season'] > 0 and x['doc']['airdate'] > 1 and x['doc']['status'] == 1],
-            key=lambda d: d['airdate'], reverse=True)
+        dbData = sorted((x for x in sickrage.app.main_db.get_many('tv_episodes', self.indexerid)
+                         if x['season'] > 0 and x['airdate'] > 1 and x['status'] == 1),
+                        key=lambda d: d['airdate'], reverse=True)
 
         if dbData:
             last_airdate = datetime.date.fromordinal(dbData[0]['airdate'])
@@ -533,10 +561,8 @@ class TVShow(object):
                 return True
 
         # get next upcoming UNAIRED episode to compare against today + graceperiod
-        dbData = sorted(
-            [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)
-             if x['doc']['season'] > 0 and x['doc']['airdate'] > 1 and x['doc']['status'] == 1],
-            key=lambda d: d['airdate'])
+        dbData = sorted((x for x in sickrage.app.main_db.get_many('tv_episodes', self.indexerid)
+                         if x['season'] > 0 and x['airdate'] > 1 and x['status'] == 1), key=lambda d: d['airdate'])
 
         if dbData:
             next_airdate = datetime.date.fromordinal(dbData[0]['airdate'])
@@ -545,12 +571,12 @@ class TVShow(object):
 
         # in the first year after ended (last airdate), update every 30 days
         if (update_date - last_airdate) < datetime.timedelta(days=450) and (
-                    update_date - datetime.date.fromordinal(self.last_update)) > datetime.timedelta(days=30):
+                update_date - datetime.date.fromordinal(self.last_update)) > datetime.timedelta(days=30):
             return True
 
         return False
 
-    def writeShowNFO(self):
+    def writeShowNFO(self, force=False):
 
         result = False
 
@@ -560,11 +586,11 @@ class TVShow(object):
 
         sickrage.app.log.debug(str(self.indexerid) + ": Writing NFOs for show")
         for cur_provider in sickrage.app.metadata_providers.values():
-            result = cur_provider.create_show_metadata(self) or result
+            result = cur_provider.create_show_metadata(self, force) or result
 
         return result
 
-    def writeMetadata(self, show_only=False):
+    def writeMetadata(self, show_only=False, force=False):
 
         if not os.path.isdir(self.location):
             sickrage.app.log.info(str(self.indexerid) + ": Show dir doesn't exist, skipping NFO generation")
@@ -572,12 +598,12 @@ class TVShow(object):
 
         self.getImages()
 
-        self.writeShowNFO()
+        self.writeShowNFO(force)
 
         if not show_only:
-            self.writeEpisodeNFOs()
+            self.writeEpisodeNFOs(force)
 
-    def writeEpisodeNFOs(self):
+    def writeEpisodeNFOs(self, force=False):
 
         if not os.path.isdir(self.location):
             sickrage.app.log.info(str(self.indexerid) + ": Show dir doesn't exist, skipping NFO generation")
@@ -585,36 +611,14 @@ class TVShow(object):
 
         sickrage.app.log.debug(str(self.indexerid) + ": Writing NFOs for all episodes")
 
-        for dbData in [x['doc'] for x in
-                       sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)
-                       if x['doc']['location'] != '']:
+        for dbData in sickrage.app.main_db.get_many('tv_episodes', self.indexerid):
+            if dbData['location'] == '':
+                continue
+
             sickrage.app.log.debug(str(self.indexerid) + ": Retrieving/creating episode S%02dE%02d" % (
                 dbData["season"] or 0, dbData["episode"] or 0))
 
-            curEp = self.getEpisode(dbData["season"], dbData["episode"])
-            curEp.createMetaFiles()
-
-    def updateMetadata(self):
-
-        if not os.path.isdir(self.location):
-            sickrage.app.log.info(str(self.indexerid) + ": Show dir doesn't exist, skipping NFO generation")
-            return
-
-        self.updateShowNFO()
-
-    def updateShowNFO(self):
-
-        result = False
-
-        if not os.path.isdir(self.location):
-            sickrage.app.log.info(str(self.indexerid) + ": Show dir doesn't exist, skipping NFO generation")
-            return False
-
-        sickrage.app.log.info(str(self.indexerid) + ": Updating NFOs for show with new indexer info")
-        for cur_provider in sickrage.app.metadata_providers.values():
-            result = cur_provider.update_show_indexer_metadata(self) or result
-
-        return result
+            self.getEpisode(dbData["season"], dbData["episode"]).createMetaFiles(force)
 
     # find all media files in the show folder and create episodes for as many as possible
     def loadEpisodesFromDir(self):
@@ -637,7 +641,7 @@ class TVShow(object):
             try:
                 curEpisode = self.makeEpFromFile(os.path.join(self.location, mediaFile))
             except (ShowNotFoundException, EpisodeNotFoundException) as e:
-                sickrage.app.log.error("Episode " + mediaFile + " returned an exception: {}".format(e.message))
+                sickrage.app.log.warning("Episode " + mediaFile + " returned an exception: {}".format(e))
             except EpisodeDeletedException:
                 sickrage.app.log.debug("The episode deleted itself when I tried making an object for it")
 
@@ -650,7 +654,7 @@ class TVShow(object):
             ep_file_name = os.path.splitext(ep_file_name)[0]
 
             try:
-                parse_result = NameParser(False, showObj=self, tryIndexers=True).parse(ep_file_name)
+                parse_result = NameParser(False, showObj=self).parse(ep_file_name)
             except (InvalidNameException, InvalidShowException):
                 parse_result = None
 
@@ -674,33 +678,12 @@ class TVShow(object):
 
         sickrage.app.log.debug("{}: Loading all episodes for show from DB".format(self.indexerid))
 
-        lINDEXER_API_PARMS = IndexerApi(self.indexer).api_params.copy()
-
-        lINDEXER_API_PARMS['language'] = self.lang or sickrage.app.config.indexer_default_language
-
-        if self.dvdorder != 0:
-            lINDEXER_API_PARMS['dvdorder'] = True
-
-        t = IndexerApi(self.indexer).indexer(**lINDEXER_API_PARMS)
-
-        cachedShow = t[self.indexerid]
-        cachedSeasons = {}
-
-        for dbData in [x['doc'] for x in
-                       sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)]:
-
+        for dbData in sickrage.app.main_db.get_many('tv_episodes', self.indexerid):
             deleteEp = False
 
             curSeason = int(dbData["season"])
             curEpisode = int(dbData["episode"])
 
-            if curSeason not in cachedSeasons:
-                try:
-                    cachedSeasons[curSeason] = cachedShow[curSeason]
-                except indexer_seasonnotfound, e:
-                    sickrage.app.log.warning("Error when trying to load the episode from TVDB: " + e.message)
-                    deleteEp = True
-
             if curSeason not in scannedEps:
                 scannedEps[curSeason] = {}
 
@@ -708,11 +691,9 @@ class TVShow(object):
                 sickrage.app.log.debug(
                     "{}: Loading episode S{:02d}E{:02d} info".format(self.indexerid, curSeason or 0, curEpisode or 0))
 
-                curEp = self.getEpisode(curSeason, curEpisode)
-                if deleteEp: curEp.deleteEpisode()
+                if deleteEp:
+                    self.getEpisode(curSeason, curEpisode).deleteEpisode()
 
-                # curEp.loadFromDB(curSeason, curEpisode)
-                # curEp.loadFromIndexer(tvapi=t, cachedSeason=cachedSeasons[curSeason])
                 scannedEps[curSeason][curEpisode] = True
             except EpisodeDeletedException:
                 continue
@@ -779,7 +760,7 @@ class TVShow(object):
         for cur_provider in sickrage.app.metadata_providers.values():
             fanart_result = cur_provider.create_fanart(self) or fanart_result
             poster_result = cur_provider.create_poster(self) or poster_result
-            banner_result = cur_provider.create_banner(self) or banner_result
+            banner_result = cur_provider.create_banner(self, ) or banner_result
 
             season_posters_result = cur_provider.create_season_posters(self) or season_posters_result
             season_banners_result = cur_provider.create_season_banners(self) or season_banners_result
@@ -797,7 +778,7 @@ class TVShow(object):
         sickrage.app.log.debug(str(self.indexerid) + ": Creating episode object from " + file)
 
         try:
-            parse_result = NameParser(showObj=self, tryIndexers=True).parse(file, skip_scene_detection=True)
+            parse_result = NameParser(showObj=self).parse(file, skip_scene_detection=True)
         except InvalidNameException:
             sickrage.app.log.debug("Unable to parse the filename " + file + " into a valid episode")
             return None
@@ -812,11 +793,9 @@ class TVShow(object):
 
         # for now lets assume that any episode in the show dir belongs to that show
         season = parse_result.season_number if parse_result.season_number is not None else 1
-        episodes = parse_result.episode_numbers
         rootEp = None
 
-        for curEpNum in episodes:
-
+        for curEpNum in parse_result.episode_numbers:
             episode = int(curEpNum)
 
             sickrage.app.log.debug(
@@ -869,7 +848,7 @@ class TVShow(object):
                     curEp.status = Quality.compositeStatus(DOWNLOADED, newQuality)
 
             # check for status/quality changes as long as it's a new file
-            elif not same_file and isMediaFile(
+            elif not same_file and is_media_file(
                     file) and curEp.status not in Quality.DOWNLOADED + Quality.ARCHIVED + [IGNORED]:
                 oldStatus, oldQuality = Quality.splitCompositeStatus(curEp.status)
                 newQuality = Quality.nameQuality(file, self.is_anime)
@@ -916,16 +895,14 @@ class TVShow(object):
         return rootEp
 
     def loadFromDB(self, skipNFO=False):
-
         sickrage.app.log.debug(str(self.indexerid) + ": Loading show info from database")
 
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_shows', self.indexerid, with_doc=True)]
+        dbData = [x for x in sickrage.app.main_db.get_many('tv_shows', self.indexerid)]
 
         if len(dbData) > 1:
             raise MultipleShowsInDatabaseException()
         elif len(dbData) == 0:
-            sickrage.app.log.info(str(self.indexerid) + ": Unable to find the show in the database")
-            return False
+            return ShowNotFoundException()
 
         self._indexer = try_int(dbData[0]["indexer"], self.indexer)
         self._name = dbData[0].get("show_name", self.name)
@@ -944,7 +921,7 @@ class TVShow(object):
         self._subtitles = try_int(dbData[0]["subtitles"], self.subtitles)
         self._subtitles_sr_metadata = dbData[0].get("subtitles_sr_metadata", self.subtitles_sr_metadata)
         self._dvdorder = try_int(dbData[0]["dvdorder"], self.dvdorder)
-        self._archive_firstmatch = try_int(dbData[0]["archive_firstmatch"], self.archive_firstmatch)
+        self._skip_downloaded = try_int(dbData[0]["skip_downloaded"], self.skip_downloaded)
         self._quality = try_int(dbData[0]["quality"], self.quality)
         self._flatten_folders = try_int(dbData[0]["flatten_folders"], self.flatten_folders)
         self._paused = try_int(dbData[0]["paused"], self.paused)
@@ -954,6 +931,8 @@ class TVShow(object):
         self._rls_ignore_words = dbData[0].get("rls_ignore_words", self.rls_ignore_words)
         self._rls_require_words = dbData[0].get("rls_require_words", self.rls_require_words)
         self._default_ep_status = try_int(dbData[0]["default_ep_status"], self.default_ep_status)
+        self._notify_list = dbData[0].get("notify_list", self.notify_list)
+        self._search_delay = dbData[0].get("search_delay", self.search_delay)
         self._imdbid = dbData[0].get("imdb_id", self.imdbid)
         self._location = dbData[0].get("location", self.location)
 
@@ -963,23 +942,7 @@ class TVShow(object):
         if not skipNFO:
             try:
                 # Get IMDb_info from database
-                imdb_info_keys = [
-                    'imdb_id',
-                    'title',
-                    'year',
-                    'akas',
-                    'runtime',
-                    'genres',
-                    'countries',
-                    'country_codes',
-                    'certificates',
-                    'rating',
-                    'votes',
-                    'last_update'
-                ]
-
-                dbData = sickrage.app.main_db.db.get('imdb_info', self.indexerid, with_doc=True)['doc']
-                self._imdb_info = {k: dbData[k] for k in imdb_info_keys if k in dbData}
+                self._imdb_info = sickrage.app.main_db.get('imdb_info', self.indexerid)
             except RecordNotFound:
                 pass
 
@@ -1038,26 +1001,12 @@ class TVShow(object):
         # save to database
         self.saveToDB()
 
-    def loadIMDbInfo(self, imdbapi=None):
-        imdb_info = {'imdb_id': self.imdbid,
-                     'title': '',
-                     'year': '',
-                     'akas': [],
-                     'runtime': '',
-                     'genres': [],
-                     'countries': '',
-                     'country_codes': [],
-                     'certificates': [],
-                     'rating': '',
-                     'votes': '',
-                     'last_update': ''}
-
-        i = imdbpie.Imdb()
+    def load_imdb_info(self):
         if not self.imdbid:
-            for x in i.search_for_title(self.name):
+            for x in IMDbAPI().search_by_imdb_title(self.name) or []:
                 try:
-                    if int(x.get('year'), 0) == self.startyear and x.get('title') in self.name:
-                        self.imdbid = x.get('imdb_id')
+                    if int(x.get('Year'), 0) == self.startyear and x.get('Title') in self.name:
+                        self.imdbid = x.get('imdbID')
                         break
                 except:
                     continue
@@ -1065,88 +1014,58 @@ class TVShow(object):
         if self.imdbid:
             sickrage.app.log.debug(str(self.indexerid) + ": Loading show info from IMDb")
 
-            imdbTv = i.get_title_by_id(self.imdbid)
-            for key in [x for x in imdb_info.keys() if hasattr(imdbTv, x.replace('_', ' '))]:
-                # Store only the first value for string type
-                if isinstance(imdb_info[key], basestring) and isinstance(getattr(imdbTv, key.replace('_', ' ')), list):
-                    imdb_info[key] = getattr(imdbTv, key.replace('_', ' '))[0]
-                else:
-                    imdb_info[key] = getattr(imdbTv, key.replace('_', ' '))
-
-            # Filter only the value
-            if imdb_info['runtime']:
-                imdb_info['runtime'] = int(imdb_info['runtime']) / 60
-            else:
-                imdb_info['runtime'] = self.runtime
-
-            if imdb_info['akas']:
-                imdb_info['akas'] = '|'.join(imdb_info['akas'])
-            else:
-                imdb_info['akas'] = ''
-
-            # Join all genres in a string
-            if imdb_info['genres']:
-                imdb_info['genres'] = '|'.join(imdb_info['genres'])
-            else:
-                imdb_info['genres'] = ''
-
-            # Get only the production country certificate if any
-            if imdb_info['certificates'] and imdb_info['countries']:
-                dct = {}
-                try:
-                    for item in imdb_info['certificates']:
-                        dct[item.split(':')[0]] = item.split(':')[1]
-
-                    imdb_info['certificates'] = dct[imdb_info['countries']]
-                except Exception:
-                    imdb_info['certificates'] = ''
-
-            else:
-                imdb_info['certificates'] = ''
-
-            if imdb_info['country_codes']:
-                imdb_info['country_codes'] = '|'.join(imdb_info['country_codes'])
-            else:
-                imdb_info['country_codes'] = ''
-
-            imdb_info['last_update'] = datetime.date.today().toordinal()
-
-            # Rename dict keys without spaces for DB upsert
-            self.imdb_info = dict(
-                (k.replace(' ', '_'), k(v) if hasattr(v, 'keys') else v) for k, v in imdb_info.items())
+            self.imdb_info = IMDbAPI().search_by_imdb_id(self.imdbid)
+            if not self.imdb_info:
+                sickrage.app.log.debug(str(self.indexerid) + ': Unable to obtain IMDb info')
+                return
 
             sickrage.app.log.debug(
                 str(self.indexerid) + ": Obtained IMDb info ->" + str(self.imdb_info))
 
-            # save show to database
-            self.saveToDB()
+            # save imdb info to database
+            imdb_info = {
+                '_t': 'imdb_info',
+                'indexer_id': self.indexerid,
+                'last_update': datetime.date.today().toordinal()
+            }
 
-    def nextEpisode(self):
-        if self.paused: return
-
-        curDate = datetime.date.today()
-
-        if not self.next_aired or self.next_aired and curDate.toordinal() > self.next_aired:
-            dbData = sorted(
-                [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True) if
-                 x['doc']['airdate'] >= curDate.toordinal() and
-                 x['doc']['status'] in (UNAIRED, WANTED)], key=lambda d: d['airdate'])
-
-            self.next_aired = dbData[0]['airdate'] if dbData else ''
+            try:
+                dbData = sickrage.app.main_db.get('imdb_info', self.indexerid)
+                dbData.update(self.imdb_info)
+                sickrage.app.main_db.update(dbData)
+            except RevConflict:
+                dbData = sickrage.app.main_db.get('imdb_info', self.indexerid)
+                sickrage.app.main_db.delete(dbData)
+                imdb_info.update(self.imdb_info)
+                sickrage.app.main_db.insert(imdb_info)
+            except RecordNotFound:
+                imdb_info.update(self.imdb_info)
+                sickrage.app.main_db.insert(imdb_info)
 
     def deleteShow(self, full=False):
-        [sickrage.app.main_db.db.delete(x['doc']) for x in
-         sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)]
-        [sickrage.app.main_db.db.delete(x['doc']) for x in
-         sickrage.app.main_db.db.get_many('tv_shows', self.indexerid, with_doc=True)]
-        [sickrage.app.main_db.db.delete(x['doc']) for x in
-         sickrage.app.main_db.db.get_many('imdb_info', self.indexerid, with_doc=True)]
-        [sickrage.app.main_db.db.delete(x['doc']) for x in
-         sickrage.app.main_db.db.get_many('xem_refresh', self.indexerid, with_doc=True)]
-        [sickrage.app.main_db.db.delete(x['doc']) for x in
-         sickrage.app.main_db.db.get_many('scene_numbering', self.indexerid, with_doc=True)]
+        # choose delete or trash action
         action = ('delete', 'trash')[sickrage.app.config.trash_remove_show]
 
+        # remove from tv episodes table
+        for x in sickrage.app.main_db.get_many('tv_episodes', self.indexerid):
+            sickrage.app.main_db.delete(x)
+
+        # remove from tv shows table
+        for x in sickrage.app.main_db.get_many('tv_shows', self.indexerid):
+            sickrage.app.main_db.delete(x)
+
+        # remove from imdb info table
+        for x in sickrage.app.main_db.get_many('imdb_info', self.indexerid):
+            sickrage.app.main_db.delete(x)
+
+        # remove from xem scene table
+        for x in sickrage.app.main_db.get_many('xem_refresh', self.indexerid):
+            sickrage.app.main_db.delete(x)
+
+        # remove from scene numbering table
+        for x in sickrage.app.main_db.get_many('scene_numbering', self.indexerid):
+            sickrage.app.main_db.delete(x)
+
         # remove self from show list
         sickrage.app.showlist = [x for x in sickrage.app.showlist if int(x.indexerid) != self.indexerid]
 
@@ -1159,7 +1078,6 @@ class TVShow(object):
                     send2trash.send2trash(cache_file)
                 else:
                     os.remove(cache_file)
-
             except OSError as e:
                 sickrage.app.log.warning('Unable to %s %s: %s / %s' % (action, cache_file, repr(e), str(e)))
 
@@ -1186,8 +1104,8 @@ class TVShow(object):
                         shutil.rmtree(self.location)
 
                     sickrage.app.log.info('%s show folder %s' %
-                                                  (('Deleted', 'Trashed')[sickrage.app.config.trash_remove_show],
-                                                   self.location))
+                                          (('Deleted', 'Trashed')[sickrage.app.config.trash_remove_show],
+                                           self.location))
             except OSError as e:
                 sickrage.app.log.warning('Unable to %s %s: %s / %s' % (action, self.location, repr(e), str(e)))
 
@@ -1209,14 +1127,15 @@ class TVShow(object):
         try:
             self.loadEpisodesFromDir()
         except Exception as e:
-            sickrage.app.log.debug("Error searching dir for episodes: {}".format(e.message))
+            sickrage.app.log.debug("Error searching dir for episodes: {}".format(e))
             sickrage.app.log.debug(traceback.format_exc())
 
         # run through all locations from DB, check that they exist
         sickrage.app.log.debug(str(self.indexerid) + ": Loading all episodes with a location from the database")
 
-        for ep in [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)
-                   if x['doc']['location'] != '']:
+        for ep in sickrage.app.main_db.get_many('tv_episodes', self.indexerid):
+            if ep['location'] == '':
+                continue
 
             curLoc = os.path.normpath(ep["location"])
             season = int(ep["season"])
@@ -1317,7 +1236,7 @@ class TVShow(object):
             "sports": self.sports,
             "subtitles": self.subtitles,
             "dvdorder": self.dvdorder,
-            "archive_firstmatch": self.archive_firstmatch,
+            "skip_downloaded": self.skip_downloaded,
             "startyear": self.startyear,
             "lang": self.lang,
             "imdb_id": self.imdbid,
@@ -1326,28 +1245,17 @@ class TVShow(object):
             "rls_ignore_words": self.rls_ignore_words,
             "rls_require_words": self.rls_require_words,
             "default_ep_status": self.default_ep_status,
-            "sub_use_sr_metadata": self.subtitles_sr_metadata
+            "sub_use_sr_metadata": self.subtitles_sr_metadata,
+            "notify_list": self.notify_list,
+            "search_delay": self.search_delay,
         }
 
         try:
-            dbData = sickrage.app.main_db.db.get('tv_shows', self.indexerid, with_doc=True)['doc']
+            dbData = sickrage.app.main_db.get('tv_shows', self.indexerid)
             dbData.update(tv_show)
-            sickrage.app.main_db.db.update(dbData)
+            sickrage.app.main_db.update(dbData)
         except RecordNotFound:
-            sickrage.app.main_db.db.insert(tv_show)
-
-        if self.imdbid and self.imdb_info:
-            try:
-                dbData = sickrage.app.main_db.db.get('imdb_info', self.indexerid, with_doc=True)['doc']
-                dbData.update(self.imdb_info)
-                sickrage.app.main_db.db.update(dbData)
-            except RecordNotFound:
-                imdb_info = {
-                    '_t': 'imdb_info',
-                    'indexer_id': self.indexerid
-                }
-                imdb_info.update(self.imdb_info)
-                sickrage.app.main_db.db.insert(imdb_info)
+            sickrage.app.main_db.insert(tv_show)
 
     def __str__(self):
         toReturn = ""
@@ -1406,8 +1314,8 @@ class TVShow(object):
             sickrage.app.log.debug("Don't want this quality, ignoring found episode")
             return False
 
-        dbData = [x['doc'] for x in sickrage.app.main_db.db.get_many('tv_episodes', self.indexerid, with_doc=True)
-                  if x['doc']['season'] == season and x['doc']['episode'] == episode]
+        dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', self.indexerid)
+                  if x['season'] == season and x['episode'] == episode]
 
         if not dbData or not len(dbData):
             sickrage.app.log.debug("Unable to find a matching episode in database, ignoring found episode")
@@ -1438,7 +1346,7 @@ class TVShow(object):
 
         # if we are re-downloading then we only want it if it's in our bestQualities list and better than what we have, or we only have one bestQuality and we do not have that quality yet
         if epStatus in Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER and quality in bestQualities and (
-                        quality > curQuality or curQuality not in bestQualities):
+                quality > curQuality or curQuality not in bestQualities):
             sickrage.app.log.debug(
                 "Episode already exists but the found episode quality is wanted more, getting found episode")
             return True
@@ -1453,6 +1361,7 @@ class TVShow(object):
         return False
 
     def getOverview(self, epStatus):
+        epStatus = try_int(epStatus) or UNKNOWN
 
         if epStatus == WANTED:
             return Overview.WANTED
@@ -1462,9 +1371,18 @@ class TVShow(object):
             return Overview.SKIPPED
         elif epStatus in Quality.ARCHIVED:
             return Overview.GOOD
-        elif epStatus in Quality.DOWNLOADED + Quality.SNATCHED + Quality.SNATCHED_PROPER + Quality.FAILED + Quality.SNATCHED_BEST:
+        elif epStatus in Quality.FAILED:
+            return Overview.WANTED
+        elif epStatus in Quality.SNATCHED:
+            return Overview.SNATCHED
+        elif epStatus in Quality.SNATCHED_PROPER:
+            return Overview.SNATCHED_PROPER
+        elif epStatus in Quality.SNATCHED_BEST:
+            return Overview.SNATCHED_BEST
+        elif epStatus in Quality.DOWNLOADED:
+            anyQualities, bestQualities = Quality.splitQuality(self.quality)
+            epStatus, curQuality = Quality.splitCompositeStatus(epStatus)
 
-            __, bestQualities = Quality.splitQuality(self.quality)
             if bestQualities:
                 maxBestQuality = max(bestQualities)
                 minBestQuality = min(bestQualities)
@@ -1472,22 +1390,16 @@ class TVShow(object):
                 maxBestQuality = None
                 minBestQuality = None
 
-            epStatus, curQuality = Quality.splitCompositeStatus(epStatus)
-
-            if epStatus == FAILED:
-                return Overview.WANTED
-            if epStatus == DOWNLOADED and curQuality == Quality.UNKNOWN:
-                return Overview.QUAL
-            elif epStatus in (SNATCHED, SNATCHED_PROPER, SNATCHED_BEST):
-                return Overview.SNATCHED
+            # elif epStatus == DOWNLOADED and curQuality == Quality.UNKNOWN:
+            #    return Overview.QUAL
             # if they don't want re-downloads then we call it good if they have anything
-            elif maxBestQuality is None:
+            if maxBestQuality is None:
                 return Overview.GOOD
             # if the want only first match and already have one call it good
-            elif self.archive_firstmatch and curQuality in bestQualities:
+            elif self.skip_downloaded and curQuality in bestQualities:
                 return Overview.GOOD
             # if they want only first match and current quality is higher than minimal best quality call it good
-            elif self.archive_firstmatch and minBestQuality is not None and curQuality > minBestQuality:
+            elif self.skip_downloaded and minBestQuality is not None and curQuality > minBestQuality:
                 return Overview.GOOD
             # if they have one but it's not the best they want then mark it as qual
             elif curQuality < maxBestQuality:
@@ -1495,6 +1407,8 @@ class TVShow(object):
             # if it's >= maxBestQuality then it's good
             else:
                 return Overview.GOOD
+        else:
+            sickrage.app.log.error('Could not parse episode status into a valid overview status: {}'.format(epStatus))
 
     def mapIndexers(self):
         mapped = {}
@@ -1504,9 +1418,8 @@ class TVShow(object):
             mapped[indexer] = self.indexerid if int(indexer) == int(self.indexer) else 0
 
         # for each mapped entry
-        for dbData in [x['doc'] for x in
-                       sickrage.app.main_db.db.get_many('indexer_mapping', self.indexerid, with_doc=True)
-                       if x['doc']['indexer'] == self.indexer]:
+        for dbData in (x for x in sickrage.app.main_db.get_many('indexer_mapping', self.indexerid)
+                       if x['indexer'] == self.indexer):
 
             # Check if its mapped with both tvdb and tvrage.
             if len([i for i in dbData if i is not None]) >= 4:
@@ -1540,13 +1453,11 @@ class TVShow(object):
 
                     sickrage.app.log.debug("Adding indexer mapping to DB for show: " + self.name)
 
-                    dbData = [x['doc'] for x in
-                              sickrage.app.main_db.db.get_many('indexer_mapping', self.indexerid, with_doc=True)
-                              if x['doc']['indexer'] == self.indexer
-                              and x['doc']['mindexer_id'] == int(mapped_show['id'])]
+                    dbData = [x for x in sickrage.app.main_db.get_many('indexer_mapping', self.indexerid)
+                              if x['indexer'] == self.indexer and x['mindexer_id'] == int(mapped_show['id'])]
 
                     if not len(dbData):
-                        sickrage.app.main_db.db.insert({
+                        sickrage.app.main_db.insert({
                             '_t': 'indexer_mapping',
                             'indexer_id': self.indexerid,
                             'indexer': self.indexer,
@@ -1576,4 +1487,4 @@ class TVShow(object):
 
     def __setstate__(self, d):
         d['lock'] = threading.Lock()
-        self.__dict__.update(d)
\ No newline at end of file
+        self.__dict__.update(d)
