@@ -35,7 +35,7 @@ class History:
         """
         Clear all the history
         """
-        [sickrage.app.main_db.db.delete(x['doc']) for x in sickrage.app.main_db.db.all('history', with_doc=True)]
+        [sickrage.app.main_db.delete(x) for x in sickrage.app.main_db.all('history')]
 
     def get(self, limit=100, action=None):
         """
@@ -57,24 +57,19 @@ class History:
         else:
             actions = []
 
-        for tv_show in [x['doc'] for x in sickrage.app.main_db.db.all('tv_shows', with_doc=True)]:
+        for show in sickrage.app.showlist:
             if limit == 0:
                 if len(actions) > 0:
-                    dbData = [x['doc'] for x in
-                              sickrage.app.main_db.db.get_many('history', tv_show['indexer_id'], with_doc=True)
-                              if x['doc']['action'] in actions]
+                    dbData = (x for x in sickrage.app.main_db.get_many('history', show.indexerid)
+                              if x['action'] in actions)
                 else:
-                    dbData = [x['doc'] for x in
-                              sickrage.app.main_db.db.get_many('history', tv_show['indexer_id'], with_doc=True)]
+                    dbData = (x for x in sickrage.app.main_db.get_many('history', show.indexerid))
             else:
                 if len(actions) > 0:
-                    dbData = [x['doc'] for x in
-                              sickrage.app.main_db.db.get_many('history', tv_show['indexer_id'], limit, with_doc=True)
-                              if x['doc']['action'] in actions]
+                    dbData = (x for x in sickrage.app.main_db.get_many('history', show.indexerid, limit)
+                              if x['action'] in actions)
                 else:
-                    dbData = [x['doc'] for x in
-                              sickrage.app.main_db.db.get_many('history', tv_show['indexer_id'], limit,
-                                                                 with_doc=True)]
+                    dbData = (x for x in sickrage.app.main_db.get_many('history', show.indexerid, limit))
 
             for result in dbData:
                 data.append({
@@ -86,7 +81,7 @@ class History:
                     'resource': result['resource'],
                     'season': result['season'],
                     'show_id': result['showid'],
-                    'show_name': tv_show['show_name']
+                    'show_name': show.name
                 })
 
         return sorted(data, key=lambda d: d['date'], reverse=True)
@@ -97,8 +92,8 @@ class History:
         """
 
         date = (datetime.today() - timedelta(days=30)).strftime(History.date_format)
-        for dbData in [x['doc'] for x in sickrage.app.main_db.db.all('history', with_doc=True)
-                       if x['doc']['date'] < date]: sickrage.app.main_db.db.delete(dbData)
+        for dbData in (x for x in sickrage.app.main_db.all('history') if x['date'] < date):
+            sickrage.app.main_db.delete(dbData)
 
     @staticmethod
     def _logHistoryItem(action, showid, season, episode, quality, resource, provider, version=-1):
@@ -117,7 +112,7 @@ class History:
         logDate = datetime.today().strftime(History.date_format)
         resource = resource
 
-        sickrage.app.main_db.db.insert({
+        sickrage.app.main_db.insert({
             '_t': 'history',
             'action': action,
             'date': logDate,
@@ -243,8 +238,7 @@ class FailedHistory(object):
 
         release = FailedHistory.prepareFailedName(release)
 
-        dbData = [x['doc'] for x in sickrage.app.failed_db.db.all('history', with_doc=True) if
-                  x['doc']['release'] == release]
+        dbData = [x for x in sickrage.app.main_db.all('failed_snatch_history') if x['release'] == release]
 
         if len(dbData) == 0:
             sickrage.app.log.warning("{}, Release not found in snatch history.".format(release))
@@ -269,8 +263,8 @@ class FailedHistory(object):
             provider = dbData[0]["provider"]
 
         if not FailedHistory.hasFailed(release, size, provider):
-            sickrage.app.failed_db.db.insert({
-                '_t': 'failed',
+            sickrage.app.main_db.insert({
+                '_t': 'failed_snatches',
                 'release': release,
                 'size': size,
                 'provider': provider
@@ -283,8 +277,8 @@ class FailedHistory(object):
     @staticmethod
     def logSuccess(release):
         release = FailedHistory.prepareFailedName(release)
-        for dbData in [x['doc'] for x in sickrage.app.failed_db.db.all('history', with_doc=True)
-                       if x['doc']['release'] == release]: sickrage.app.failed_db.db.delete(dbData)
+        for dbData in (x for x in sickrage.app.main_db.all('failed_snatch_history') if x['release'] == release):
+            sickrage.app.main_db.delete(dbData)
 
     @staticmethod
     def hasFailed(release, size, provider="%"):
@@ -302,19 +296,17 @@ class FailedHistory(object):
         """
 
         release = FailedHistory.prepareFailedName(release)
-        dbData = [x['doc'] for x in sickrage.app.failed_db.db.get_many('failed', release, with_doc=True)
-                  if all([x['doc']['size'] == size, x['doc']['provider'] == provider])]
+        dbData = [x for x in sickrage.app.main_db.get_many('failed_snatches', release)
+                  if all([x['size'] == size, x['provider'] == provider])]
 
         return len(dbData) > 0
 
     @staticmethod
     def revertFailedEpisode(epObj):
         """Restore the episodes of a failed download to their original state"""
-        dbData = [x['doc'] for x in sickrage.app.failed_db.db.all('history', with_doc=True)
-                  if x['doc']['showid'] == epObj.show.indexerid
-                  and x['doc']['season'] == epObj.season]
-
-        history_eps = dict([(res["episode"], res) for res in dbData])
+        history_eps = dict([(res["episode"], res) for res in (x for x in sickrage.app.main_db.all('failed_snatch_history')
+                                                              if x['showid'] == epObj.show.indexerid
+                                                              and x['season'] == epObj.season)])
 
         try:
             sickrage.app.log.info("Reverting episode (%s, %s): %s" % (epObj.season, epObj.episode, epObj.name))
@@ -323,13 +315,13 @@ class FailedHistory(object):
                     sickrage.app.log.info("Found in history")
                     epObj.status = history_eps[epObj.episode]['old_status']
                 else:
-                    sickrage.app.log.warning("WARNING: Episode not found in history. Setting it back to WANTED")
+                    sickrage.app.log.debug("WARNING: Episode not found in history. Setting it back to WANTED")
                     epObj.status = WANTED
                     epObj.saveToDB()
 
         except EpisodeNotFoundException as e:
             sickrage.app.log.warning(
-                "Unable to create episode, please set its status manually: {}".format(e.message))
+                "Unable to create episode, please set its status manually: {}".format(e))
 
     @staticmethod
     def markFailed(epObj):
@@ -349,7 +341,7 @@ class FailedHistory(object):
 
         except EpisodeNotFoundException as e:
             sickrage.app.log.warning(
-                "Unable to get episode, please set its status manually: {}".format(e.message))
+                "Unable to get episode, please set its status manually: {}".format(e))
 
         return log_str
 
@@ -372,8 +364,8 @@ class FailedHistory(object):
         show_obj = searchResult.episodes[0].show
 
         for episode in searchResult.episodes:
-            sickrage.app.failed_db.db.insert({
-                '_t': 'history',
+            sickrage.app.main_db.insert({
+                '_t': 'failed_snatch_history',
                 'date': logDate,
                 'size': searchResult.size,
                 'release': release,
@@ -394,18 +386,16 @@ class FailedHistory(object):
         :param provider: Provider to delete it from
         """
         release = FailedHistory.prepareFailedName(release)
-        for dbData in [x['doc'] for x in sickrage.app.failed_db.db.all('history', with_doc=True)
-                       if x['doc']['release'] == release
-                       and x['doc']['size'] == size
-                       and x['doc']['provider'] == provider]: sickrage.app.failed_db.db.delete(dbData)
+        for dbData in (x for x in sickrage.app.main_db.all('failed_snatch_history')
+                       if x['release'] == release and x['size'] == size and x['provider'] == provider):
+            sickrage.app.main_db.delete(dbData)
 
     @staticmethod
     def trimHistory():
         """Trims history table to 1 month of history from today"""
         date = str((datetime.today() - timedelta(days=30)).strftime(History.date_format))
-        for dbData in [x['doc'] for x in sickrage.app.failed_db.db.all('history', with_doc=True) if
-                       x['doc']['date'] < date]:
-            sickrage.app.failed_db.db.delete(dbData)
+        for dbData in (x for x in sickrage.app.main_db.all('failed_snatch_history') if x['date'] < date):
+            sickrage.app.main_db.delete(dbData)
 
     @staticmethod
     def findFailedRelease(epObj):
@@ -418,26 +408,22 @@ class FailedHistory(object):
         provider = None
 
         # Clear old snatches for this release if any exist
-        dbData = sorted(
-            [x['doc'] for x in sickrage.app.failed_db.db.get_many('history', epObj.show.indexerid, with_doc=True)
-             if x['doc']['season'] == epObj.season
-             and x['doc']['episode'] == epObj.episode], key=lambda d: d['date'])
-
-        [sickrage.app.failed_db.db.delete(x) for x in dbData[1::]]
+        [sickrage.app.main_db.delete(x) for x in
+         sorted((x for x in sickrage.app.main_db.get_many('failed_snatch_history', epObj.show.indexerid)
+                 if x['season'] == epObj.season and x['episode'] == epObj.episode), key=lambda d: d['date'])[1::]]
 
         # Search for release in snatch history
-        for dbData in [x['doc'] for x in
-                       sickrage.app.failed_db.db.get_many('history', epObj.show.indexerid, with_doc=True)
-                       if x['doc']['season'] == epObj.season
-                       and x['doc']['episode'] == epObj.episode]:
+        for dbData in (x for x in sickrage.app.main_db.get_many('failed_snatch_history', epObj.show.indexerid)
+                       if x['season'] == epObj.season and x['episode'] == epObj.episode):
 
             release = str(dbData["release"])
             provider = str(dbData["provider"])
             date = dbData["date"]
 
             # Clear any incomplete snatch records for this release if any exist
-            for x in [x['doc'] for x in sickrage.app.failed_db.db.all('history', with_doc=True)]:
-                if x['release'] == release and x['date'] != date: sickrage.app.failed_db.db.delete(x)
+            for x in (x for x in sickrage.app.main_db.all('failed_snatch_history')
+                      if x['release'] == release and x['date'] != date):
+                sickrage.app.main_db.delete(x)
 
             # Found a previously failed release
             sickrage.app.log.debug(
