@@ -48,11 +48,11 @@ class ShowUpdater(object):
         update_timestamp = int(time.mktime(datetime.datetime.now().timetuple()))
 
         try:
-            dbData = sickrage.app.cache_db.db.get('lastUpdate', 'theTVDB', with_doc=True)['doc']
+            dbData = sickrage.app.cache_db.get('lastUpdate', 'theTVDB')
             last_update = int(dbData['time'])
         except RecordNotFound:
             last_update = update_timestamp
-            dbData = sickrage.app.cache_db.db.insert({
+            dbData = sickrage.app.cache_db.insert({
                 '_t': 'lastUpdate',
                 'provider': 'theTVDB',
                 'time': 0
@@ -67,19 +67,29 @@ class ShowUpdater(object):
         for show in sickrage.app.showlist:
             if show.paused:
                 sickrage.app.log.info('Show update skipped, show: {} is paused.'.format(show.name))
+                continue
+
+            if show.status == 'Ended':
+                if not sickrage.app.config.showupdate_stale:
+                    sickrage.app.log.info('Show update skipped, show: {} status is ended.'.format(show.name))
+                    continue
+                elif not (datetime.datetime.now() - datetime.datetime.fromordinal(show.last_update)).days >= 90:
+                    sickrage.app.log.info(
+                        'Show update skipped, show: {} status is ended and recently updated.'.format(show.name))
+                    continue
+
             try:
-                show.nextEpisode()
-                stale = (datetime.datetime.now() - datetime.datetime.fromordinal(show.last_update)).days > 7
+                stale = (datetime.datetime.now() - datetime.datetime.fromordinal(show.last_update)).days >= 7
                 if show.indexerid in updated_shows or stale:
                     pi_list.append(sickrage.app.show_queue.updateShow(show, False))
                 else:
                     pi_list.append(sickrage.app.show_queue.refreshShow(show, False))
             except (CantUpdateShowException, CantRefreshShowException) as e:
-                sickrage.app.log.debug("Automatic update failed: {}".format(e.message))
+                sickrage.app.log.debug("Automatic update failed: {}".format(e))
 
         ProgressIndicators.setIndicator('dailyShowUpdates', QueueProgressIndicator("Daily Show Updates", pi_list))
 
         dbData['time'] = update_timestamp
-        sickrage.app.cache_db.db.update(dbData)
+        sickrage.app.cache_db.update(dbData)
 
-        self.amActive = False
\ No newline at end of file
+        self.amActive = False
