@@ -28,18 +28,14 @@ import subprocess
 import sys
 import tarfile
 import threading
-import traceback
 
 import sickrage
 from sickrage.core.helpers import backupSR
+from sickrage.core.websession import WebSession
 from sickrage.notifiers import Notifiers
 
 
 class VersionUpdater(object):
-    """
-    Version check class meant to run as a thread object with the sr scheduler.
-    """
-
     def __init__(self):
         self.name = "VERSIONUPDATER"
         self.amActive = False
@@ -58,20 +54,21 @@ class VersionUpdater(object):
         threading.currentThread().setName(self.name)
 
         try:
-            if self.check_for_new_version(force) and sickrage.app.config.auto_update:
-                if sickrage.app.show_updater.amActive:
-                    sickrage.app.log.debug("We can't proceed with auto-updating. Shows are being updated")
-                    return
+            if self.check_for_new_version(force):
+                if sickrage.app.config.auto_update:
+                    if sickrage.app.show_updater.amActive:
+                        sickrage.app.log.debug("We can't proceed with auto-updating. Shows are being updated")
+                        return
 
-                sickrage.app.log.info("New update found for SiCKRAGE, starting auto-updater ...")
-                sickrage.app.alerts.message(_('New update found for SiCKRAGE, starting auto-updater'))
-                if self.update():
-                    sickrage.app.log.info("Update was successful!")
-                    sickrage.app.alerts.message(_('Update was successful'))
-                    sickrage.app.shutdown(restart=True)
-                else:
-                    sickrage.app.log.info("Update failed!")
-                    sickrage.app.alerts.message(_('Update failed!'))
+                    sickrage.app.log.info("New update found for SiCKRAGE, starting auto-updater ...")
+                    sickrage.app.alerts.message(_('New update found for SiCKRAGE, starting auto-updater'))
+                    if self.update():
+                        sickrage.app.log.info("Update was successful!")
+                        sickrage.app.alerts.message(_('Update was successful'))
+                        sickrage.app.shutdown(restart=True)
+                    else:
+                        sickrage.app.log.info("Update failed!")
+                        sickrage.app.alerts.message(_('Update failed!'))
         finally:
             self.amActive = False
 
@@ -90,19 +87,16 @@ class VersionUpdater(object):
                     sickrage.app.alerts.message(_('Backup'), _('Config backup successful, updating...'))
                     return True
                 else:
-                    sickrage.app.log.error("Config backup failed, aborting update")
+                    sickrage.app.log.warning("Config backup failed, aborting update")
                     sickrage.app.alerts.message(_('Backup'), _('Config backup failed, aborting update'))
                     return False
             except Exception as e:
-                sickrage.app.log.error('Update: Config backup failed. Error: %s' % e)
+                sickrage.app.log.warning('Update: Config backup failed. Error: {}'.format(e))
                 sickrage.app.alerts.message(_('Backup'), _('Config backup failed, aborting update'))
                 return False
 
     @staticmethod
     def safe_to_update():
-        if sickrage.app.developer:
-            return False
-
         if not sickrage.app.started:
             return True
         if not sickrage.app.auto_postprocessor.amActive:
@@ -139,11 +133,15 @@ class VersionUpdater(object):
         Checks the internet for a newer version.
 
         returns: bool, True for new version or False for no new version.
-        :param force: if true the VERSION_NOTIFY setting will be ignored and a check will be forced
+        :param force: if true the version_notify setting will be ignored and a check will be forced
         """
 
-        if self.updater and self.updater.need_update():
-            if force: self.updater.set_newest_text()
+        if not self.updater or (not sickrage.app.config.version_notify or sickrage.app.developer) and not force:
+            return False
+
+        if self.updater.need_update():
+            if not sickrage.app.config.auto_update or force:
+                self.updater.set_newest_text()
             return True
 
     def update(self):
@@ -158,6 +156,8 @@ class VersionUpdater(object):
                         [os.remove(os.path.join(root, name)) for name in files]
                         [shutil.rmtree(os.path.join(root, name)) for name in dirs]
 
+                    sickrage.app.config.view_changelog = True
+
                     return True
 
     @property
@@ -171,6 +171,7 @@ class VersionUpdater(object):
             return self.updater.current_branch
         return "master"
 
+
 class UpdateManager(object):
     @property
     def _git_path(self):
@@ -445,7 +446,7 @@ class GitUpdateManager(UpdateManager):
                                                                                    self.current_branch))
         if exit_status == 0:
             sickrage.app.log.info("Updating SiCKRAGE from GIT servers")
-            Notifiers.notify_version_update(self.get_newest_version)
+            Notifiers.mass_notify_version_update(self.get_newest_version)
             self.install_requirements()
             return True
 
@@ -539,7 +540,7 @@ class SourceUpdateManager(UpdateManager):
         git_version_url = "https://git.sickrage.ca/SiCKRAGE/sickrage/raw/master/sickrage/version.txt"
 
         try:
-            return sickrage.app.wsession.get(git_version_url).text
+            return WebSession().get(git_version_url).text
         except Exception:
             return self._find_installed_version()
 
@@ -575,12 +576,16 @@ class SourceUpdateManager(UpdateManager):
                 shutil.rmtree(sr_update_dir)
 
             sickrage.app.log.info("Creating update folder " + sr_update_dir + " before extracting")
-            os.makedirs(sr_update_dir)
+            try:
+                os.makedirs(sr_update_dir)
+            except OSError as e:
+                sickrage.app.log.warning("Unable to create update folder " + sr_update_dir + ': ' + str(e))
+                return False
 
             # retrieve file
             sickrage.app.log.info("Downloading update from " + repr(tar_download_url))
             tar_download_path = os.path.join(sr_update_dir, 'sr-update.tar')
-            sickrage.app.wsession.download(tar_download_url, tar_download_path)
+            WebSession().download(tar_download_url, tar_download_path)
 
             if not os.path.isfile(tar_download_path):
                 sickrage.app.log.warning(
@@ -588,7 +593,7 @@ class SourceUpdateManager(UpdateManager):
                 return False
 
             if not tarfile.is_tarfile(tar_download_path):
-                sickrage.app.log.error(
+                sickrage.app.log.warning(
                     "Retrieved version from " + tar_download_url + " is corrupt, can't update")
                 return False
 
@@ -606,7 +611,7 @@ class SourceUpdateManager(UpdateManager):
             update_dir_contents = [x for x in os.listdir(sr_update_dir) if
                                    os.path.isdir(os.path.join(sr_update_dir, x))]
             if len(update_dir_contents) != 1:
-                sickrage.app.log.error("Invalid update data, update failed: " + str(update_dir_contents))
+                sickrage.app.log.warning("Invalid update data, update failed: " + str(update_dir_contents))
                 return False
             content_dir = os.path.join(sr_update_dir, update_dir_contents[0])
 
@@ -627,7 +632,7 @@ class SourceUpdateManager(UpdateManager):
                             os.remove(new_path)
                             os.renames(old_path, new_path)
                         except Exception as e:
-                            sickrage.app.log.debug("Unable to update " + new_path + ': ' + e.message)
+                            sickrage.app.log.debug("Unable to update " + new_path + ': ' + str(e))
                             os.remove(old_path)  # Trash the updated file without moving in new path
                         continue
 
@@ -636,12 +641,11 @@ class SourceUpdateManager(UpdateManager):
                     os.renames(old_path, new_path)
 
         except Exception as e:
-            sickrage.app.log.error("Error while trying to update: {}".format(e.message))
-            sickrage.app.log.debug("Traceback: " + traceback.format_exc())
+            sickrage.app.log.error("Error while trying to update: {}".format(e))
             return False
 
         # Notify update successful
-        Notifiers.notify_version_update(self.get_newest_version)
+        Notifiers.mass_notify_version_update(self.get_newest_version)
 
         # install requirements
         self.install_requirements()
@@ -684,11 +688,12 @@ class PipUpdateManager(UpdateManager):
             return False
 
     def _check_for_new_version(self):
-        from distutils.version import StrictVersion
-        url = "https://pypi.python.org/pypi/{}/json".format('sickrage')
-        resp = sickrage.app.wsession.get(url)
+        from distutils.version import LooseVersion
+        url = "https://pypi.org/pypi/{}/json".format('sickrage')
+        resp = WebSession().get(url)
         versions = resp.json()["releases"].keys()
-        versions.sort(key=StrictVersion, reverse=True)
+        versions = [x for x in versions if 'dev' not in x]
+        versions.sort(key=LooseVersion, reverse=True)
 
         try:
             return versions[0]
@@ -704,7 +709,7 @@ class PipUpdateManager(UpdateManager):
             sickrage.app.log.debug("Unknown current version number, don't know if we should update or not")
             return
         else:
-            newest_text = _("New SiCKRAGE update found on PyPy servers, version {} &mdash; "
+            newest_text = _("New SiCKRAGE update found on PyPi servers, version {} &mdash; "
                             "<a href=\"{}\">Update Now</a>").format(self.get_newest_version, self.get_update_url())
 
         sickrage.app.newest_version_string = newest_text
@@ -716,7 +721,7 @@ class PipUpdateManager(UpdateManager):
         __, __, exit_status = self._pip_cmd(self._pip_path, 'install -U --no-cache-dir sickrage')
         if exit_status == 0:
             sickrage.app.log.info("Updating SiCKRAGE from PyPi servers")
-            Notifiers.notify_version_update(self.get_newest_version)
+            Notifiers.mass_notify_version_update(self.get_newest_version)
             return True
 
         return False
