@@ -18,18 +18,25 @@
 
 from __future__ import print_function, unicode_literals
 
-import datetime
 import functools
 import io
+import json
 import os
 import pickle
 import re
 import time
 import urlparse
+from base64 import urlsafe_b64decode
 from collections import OrderedDict
+from datetime import datetime
 from operator import itemgetter
 
+from requests import RequestException
+from simplejson import JSONDecodeError
+from six import text_type
+
 import sickrage
+from sickrage.core.websession import WebSession
 
 try:
     import gzip
@@ -43,13 +50,13 @@ from sickrage.indexers.thetvdb.exceptions import (tvdb_error, tvdb_shownotfound,
 def login_required(f):
     @functools.wraps(f)
     def wrapper(obj, *args, **kwargs):
-        if not obj.logged_in:
-            obj.login()
+        if not obj.jwt_token:
+            obj.authenticate()
 
         try:
             return f(obj, *args, **kwargs)
         except tvdb_unauthorized:
-            obj.login(True)
+            obj.authenticate()
             return f(obj, *args, **kwargs)
 
     return wrapper
@@ -131,7 +138,7 @@ class Show(dict):
             return dict.__getitem__(self.data, key)
 
         # Data wasn't found, raise appropriate error
-        if isinstance(key, int) or key.isdigit():
+        if key and (isinstance(key, int) or key.isdigit()):
             # Season number x was not found
             raise tvdb_seasonnotfound("Could not find season {}".format(repr(key)))
         else:
@@ -203,7 +210,7 @@ class Season(dict):
             # Non-numeric request is for season-data
             return dict.__getitem__(self.data, key)
 
-        if isinstance(key, int) or key.isdigit():
+        if key and (isinstance(key, int) or key.isdigit()):
             raise tvdb_episodenotfound("Could not find episode {}".format(repr(key)))
         else:
             raise tvdb_attributenotfound("Cannot find attribute {}".format(repr(key)))
@@ -304,7 +311,8 @@ class Tvdb:
                  proxy=None,
                  headers=None):
 
-        if headers is None: headers = {}
+        if headers is None:
+            headers = {}
 
         self.shows = ShowCache()
         if os.path.isfile(os.path.join(sickrage.app.data_dir, 'thetvdb.db')):
@@ -315,7 +323,7 @@ class Tvdb:
                     pass
 
         self.config = dict(apikey=apikey, debug_enabled=debug, custom_ui=custom_ui, cache_enabled=cache,
-                           dvdorder=dvdorder, proxy=proxy, apitoken=None, api={}, headers=headers)
+                           dvdorder=dvdorder, proxy=proxy, api={}, headers=headers)
 
         # api base url
         self.config['api']['base'] = "https://api.thetvdb.com"
@@ -340,7 +348,7 @@ class Tvdb:
         self.config['api']['images']['series'] = "/series/{id}/images/query?keyType=series"
         self.config['api']['images']['season'] = "/series/{id}/images/query?keyType=season&subKey={season}"
         self.config['api']['images']['seasonwide'] = "/series/{id}/images/query?keyType=seasonwide&subKey={season}"
-        self.config['api']['images']['prefix'] = "http://thetvdb.com/banners/{id}"
+        self.config['api']['images']['prefix'] = "http://thetvdb.com/banners/{value}"
 
         # api-v2 language
         self.config['api']['lang'] = 'en'
@@ -350,50 +358,111 @@ class Tvdb:
         if language not in self.languages:
             self.config['language'] = None
 
-    def logout(self):
-        self.config['apitoken'] = None
+    @property
+    def jwt_token(self):
+        return getattr(self, '_jwt_token', None)
+
+    @jwt_token.setter
+    def jwt_token(self, value):
+        if self.jwt_token != value:
+            setattr(self, '_jwt_token', value)
 
     @property
-    def logged_in(self):
-        return self.config['apitoken'] is not None
+    def jwt_payload(self):
+        return getattr(self, '_jwt_payload', self.get_jwt_payload(self.token))
 
-    def login(self, refresh=False):
+    @property
+    def jwt_expiration(self):
+        return self.jwt_payload.get('exp', time.time())
+
+    @property
+    def jwt_time_remaining(self):
+        return max(self.jwt_expiration - time.time(), 0)
+
+    @property
+    def jwt_is_expired(self):
+        return self.jwt_expiration <= time.time()
+
+    def logout(self):
+        self.token = None
+
+    def _refresh(self):
+        self.jwt_token = self._request('get', self.config['api']['refresh'])['token']
+
+    def _login(self):
+        self.jwt_token = self._request('post', self.config['api']['login'], json={'apikey': self.config['apikey']})['token']
+
+    def authenticate(self):
         try:
-            if refresh and self.config['apitoken']:
-                self.config['apitoken'] = \
-                    self._request('post', self.config['api']['refresh'])['token']
-            else:
-                self.config['apitoken'] = \
-                    self._request('post', self.config['api']['login'], json={'apikey': self.config['apikey']})['token']
+            if not self.jwt_token or self.jwt_is_expired:
+                self._login()
+            elif self.jwt_time_remaining < 7200:
+                self._refresh()
         except Exception as e:
             self.logout()
 
+    def jwt_decode(self, data):
+        # make sure data is binary
+        if isinstance(data, text_type):
+            sickrage.app.log.debug('Encoding the JWT token as UTF-8')
+            data = data.encode('utf-8')
+
+        # pad the data to a multiple of 4 bytes
+        remainder = len(data) % 4
+        if remainder > 0:
+            length = 4 - remainder
+            sickrage.app.log.debug('Padding the JWT with {x} bytes'.format(x=length))
+            data += b'=' * length
+
+        # base64 decode the data
+        data = urlsafe_b64decode(data)
+
+        # convert the decoded json to a string
+        data = data.decode('utf-8')
+
+        # return the json string as a dict
+        result = json.loads(data)
+        sickrage.app.log.info('JWT Successfully decoded')
+        return result
+
+    def get_jwt_payload(self, token):
+        result = {}
+
+        try:
+            __, payload, __ = token.split('.')
+        except AttributeError:
+            sickrage.app.log.debug('Unable to extract payload from JWT: {}'.format(token))
+        else:
+            result = self.jwt_decode(payload)
+            sickrage.app.log.debug('Payload extracted from JWT: {}'.format(result))
+        finally:
+            return result
+
     def _request(self, method, url, lang=None, **kwargs):
         self.config['headers'].update({'Content-type': 'application/json'})
-
-        if self.config['apitoken']:
-            self.config['headers']['authorization'] = 'Bearer {}'.format(self.config['apitoken'])
-
+        self.config['headers']['Authorization'] = 'Bearer {}'.format(self.jwt_token)
         self.config['headers'].update({'Accept-Language': lang or self.config['language']})
 
         # get response from theTVDB
         try:
-            resp = sickrage.app.wsession.request(
-                method,
-                urlparse.urljoin(self.config['api']['base'], url),
-                cache=self.config['cache_enabled'],
-                headers=self.config['headers'],
-                timeout=sickrage.app.config.indexer_timeout,
-                **kwargs
+            resp = WebSession(cache=self.config['cache_enabled']).request(
+                method, urlparse.urljoin(self.config['api']['base'], url), headers=self.config['headers'],
+                timeout=sickrage.app.config.indexer_timeout, **kwargs
             )
         except Exception as e:
-            raise tvdb_error(e.message)
+            raise tvdb_error(str(e))
 
         # handle requests exceptions
-        if resp.status_code == 401:
-            raise tvdb_unauthorized(resp.json()['Error'])
-        elif resp.status_code >= 400:
-            raise tvdb_error(resp.json()['Error'])
+        try:
+            if resp.status_code == 401:
+                raise tvdb_unauthorized(resp.json()['Error'])
+            elif resp.status_code >= 400:
+                raise tvdb_error(resp.json()['Error'])
+        except JSONDecodeError:
+            try:
+                resp.raise_for_status()
+            except RequestException as e:
+                raise tvdb_error(str(e))
 
         return to_lowercase(resp.json())
 
@@ -506,7 +575,7 @@ class Tvdb:
         for k, v in series_info.items():
             if v is not None:
                 if k in ['banner', 'fanart', 'poster']:
-                    v = self.config['api']['images']['prefix'].format(id=v)
+                    v = self.config['api']['images']['prefix'].format(value=v)
                 elif isinstance(v, list):
                     v = '|'.join(v)
                 else:
@@ -569,19 +638,21 @@ class Tvdb:
 
             for k, v in cur_ep.items():
                 k = k.lower()
-
                 if v is not None:
-                    if k == 'filename':
-                        v = self.config['api']['images']['prefix'].format(id=v)
-                    elif isinstance(v, list):
+                    if isinstance(v, list):
                         v = '|'.join(v)
                     else:
                         v = self._cleanData(v)
 
                 self._setItem(sid, seas_no, ep_no, k, v)
 
+            # add episode image url
+            image_url = self.config['api']['images']['prefix'].format(
+                value='episodes/{}/{}.jpg'.format(sid, cur_ep['id']))
+            self._setItem(sid, seas_no, ep_no, 'filename', image_url)
+
         # set last updated
-        self._setShowData(sid, 'last_updated', int(time.mktime(datetime.datetime.now().timetuple())))
+        self._setShowData(sid, 'last_updated', int(time.mktime(datetime.now().timetuple())))
 
         return self.shows[int(sid)]
 
@@ -604,7 +675,7 @@ class Tvdb:
             image["score"] = image["ratingsinfo"]["average"] * image["ratingsinfo"]["count"]
             for k, v in image.items():
                 if not all([k, v]): continue
-                v = (v, self.config['api']['images']['prefix'].format(id=v))[k in ['filename', 'thumbnail']]
+                v = (v, self.config['api']['images']['prefix'].format(value=v))[k in ['filename', 'thumbnail']]
                 images[i][k] = v
 
         return [item for item in sorted(images, key=itemgetter("score"), reverse=True)]
@@ -620,7 +691,7 @@ class Tvdb:
                 curActor = Actor()
                 for k, v in cur_actor.items():
                     if not all([k, v]): continue
-                    v = (v, self.config['api']['images']['prefix'].format(id=v))[k == 'images']
+                    v = (v, self.config['api']['images']['prefix'].format(value=v))[k == 'image']
                     curActor[k] = v
 
                 cur_actors.append(curActor)
