@@ -97,10 +97,10 @@ class MediaBrowserMetadata(GenericMetadata):
         # while show metadata is generated, it is not supported for our lookup
         return None, None, None
 
-    def create_season_all_poster(self, show_obj):
+    def create_season_all_poster(self, show_obj, force=False):
         pass
 
-    def create_season_all_banner(self, show_obj):
+    def create_season_all_banner(self, show_obj, force=False):
         pass
 
     def get_episode_file_path(self, ep_obj):
@@ -416,10 +416,10 @@ class MediaBrowserMetadata(GenericMetadata):
 
             myShow = t[ep_obj.show.indexerid]
         except indexer_shownotfound as e:
-            raise ShowNotFoundException(e.message)
+            raise ShowNotFoundException(str(e))
         except indexer_error as e:
             sickrage.app.log.error("Unable to connect to " + IndexerApi(
-                ep_obj.show.indexer).name + " while creating meta files - skipping - {}".format(e.message))
+                ep_obj.show.indexer).name + " while creating meta files - skipping - {}".format(e))
             return False
 
         rootNode = Element("Item")
