@@ -303,7 +303,7 @@ class KODINotifier(Notifiers):
             try:
                 et = ElementTree.fromstring(encSqlXML)
             except SyntaxError as e:
-                sickrage.app.log.error("Unable to parse XML returned from KODI: {}".format(e.message))
+                sickrage.app.log.error("Unable to parse XML returned from KODI: {}".format(e))
                 return False
 
             paths = et.findall('.//field')
@@ -386,7 +386,7 @@ class KODINotifier(Notifiers):
             except (httplib.BadStatusLine, urllib2.URLError) as e:
                 if sickrage.app.config.kodi_always_on:
                     sickrage.app.log.warning(
-                        "Error while trying to retrieve KODI API version for " + host + ": {}".format(e.message))
+                        "Error while trying to retrieve KODI API version for " + host + ": {}".format(e))
                 return False
 
             # parse the json result
@@ -402,7 +402,7 @@ class KODINotifier(Notifiers):
         except IOError as e:
             if sickrage.app.config.kodi_always_on:
                 sickrage.app.log.warning(
-                    "Warning: Couldn't contact KODI JSON API at " + url + " {}".format(e.message))
+                    "Warning: Couldn't contact KODI JSON API at " + url + " {}".format(e))
             return False
 
     def _update_library_json(self, host=None, showName=None):
@@ -518,19 +518,19 @@ class KODINotifier(Notifiers):
     # Public functions which will call the JSON or Legacy HTTP API methods
     ##############################################################################
 
-    def _notify_snatch(self, ep_name):
+    def notify_snatch(self, ep_name):
         if sickrage.app.config.kodi_notify_onsnatch:
             self._notify_kodi(ep_name, self.notifyStrings[self.NOTIFY_SNATCH])
 
-    def _notify_download(self, ep_name):
+    def notify_download(self, ep_name):
         if sickrage.app.config.kodi_notify_ondownload:
             self._notify_kodi(ep_name, self.notifyStrings[self.NOTIFY_DOWNLOAD])
 
-    def _notify_subtitle_download(self, ep_name, lang):
+    def notify_subtitle_download(self, ep_name, lang):
         if sickrage.app.config.kodi_notify_onsubtitledownload:
             self._notify_kodi(ep_name + ": " + lang, self.notifyStrings[self.NOTIFY_SUBTITLE_DOWNLOAD])
 
-    def _notify_version_update(self, new_version="??"):
+    def notify_version_update(self, new_version="??"):
         if sickrage.app.config.use_kodi:
             update_text = self.notifyStrings[self.NOTIFY_GIT_UPDATE_TEXT]
             title = self.notifyStrings[self.NOTIFY_GIT_UPDATE]
