@@ -25,7 +25,7 @@ import itertools
 import os
 import random
 import re
-from base64 import b16encode, b32decode
+from base64 import b16encode, b32decode, b64decode
 from collections import OrderedDict, defaultdict
 from time import sleep
 from urlparse import urljoin
@@ -33,10 +33,10 @@ from xml.sax import SAXParseException
 
 import bencode
 from feedparser import FeedParserDict
-from pynzb import nzb_parser
 from requests.utils import add_dict_to_cookiejar, dict_from_cookiejar
 
 import sickrage
+from sickrage.core.api.cache import TorrentCacheAPI
 from sickrage.core.caches.tv_cache import TVCache
 from sickrage.core.classes import NZBSearchResult, SearchResult, TorrentSearchResult
 from sickrage.core.common import MULTI_EP_RESULT, Quality, SEASON_RESULT, cpu_presets
@@ -45,6 +45,7 @@ from sickrage.core.helpers import chmodAsParent, findCertainShow, sanitizeFileNa
 from sickrage.core.helpers.show_names import allPossibleShowNames
 from sickrage.core.nameparser import InvalidNameException, InvalidShowException, NameParser
 from sickrage.core.scene_exceptions import get_scene_exceptions
+from sickrage.core.websession import WebSession
 
 
 class GenericProvider(object):
@@ -66,10 +67,9 @@ class GenericProvider(object):
 
         # cookies
         self.enable_cookies = False
-        self.required_cookies = []
         self.cookies = ''
 
-        self.bt_cache_url = 'http://itorrents.org/torrent/{info_hash}.torrent'
+        self.session = WebSession()
 
     @property
     def id(self):
@@ -111,34 +111,22 @@ class GenericProvider(object):
         """
         return SearchResult(episodes)
 
-    def make_url(self, url):
-        urls = [url]
+    def get_content(self, url):
+        if self.login():
+            headers = {}
+            if url.startswith('http'):
+                headers = {'Referer': '/'.join(url.split('/')[:3]) + '/'}
 
-        if url.startswith('magnet'):
-            info_hash = str(re.findall(r'urn:btih:([\w]{32,40})', url)[0]).upper()
-
-            try:
-                torrent_name = re.findall('dn=([^&]+)', url)[0]
-            except Exception:
-                torrent_name = 'NO_DOWNLOAD_NAME'
-
-            if len(info_hash) == 32:
-                info_hash = b16encode(b32decode(info_hash)).upper()
-
-            if not info_hash:
-                sickrage.app.log.error("Unable to extract torrent hash from magnet: " + url)
-                return urls
-
-            urls.append(self.bt_cache_url.format(info_hash=info_hash, torrent_name=torrent_name))
-
-        random.shuffle(urls)
-
-        return urls
+            if not url.startswith('magnet'):
+                try:
+                    return self.session.get(url, verify=False, headers=headers).content
+                except Exception:
+                    pass
 
     def make_filename(self, name):
         return ""
 
-    def getQuality(self, item, anime=False):
+    def get_quality(self, item, anime=False):
         """
         Figures out the quality of the given RSS item node
 
@@ -150,7 +138,7 @@ class GenericProvider(object):
         quality = Quality.sceneQuality(title, anime)
         return quality
 
-    def search(self, search_params, age=0, ep_obj=None):
+    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
         return []
 
     def _get_season_search_strings(self, episode):
@@ -199,7 +187,7 @@ class GenericProvider(object):
             elif episode.show.anime:
                 # If the showname is a season scene exception, we want to use the indexer episode number.
                 if (episode.scene_season > 1 and
-                            show_name in get_scene_exceptions(episode.show.indexerid, episode.scene_season)):
+                        show_name in get_scene_exceptions(episode.show.indexerid, episode.scene_season)):
                     # This is apparently a season exception, let's use the scene_episode instead of absolute
                     ep = episode.scene_episode
                 else:
@@ -207,7 +195,7 @@ class GenericProvider(object):
                 episode_string_fallback = episode_string + '{episode:0>3}'.format(episode=ep)
                 episode_string += '{episode:0>2}'.format(episode=ep)
             else:
-                episode_string += sickrage.app.config.naming_ep_type[2] % {
+                episode_string += sickrage.app.naming_ep_type[2] % {
                     'seasonnumber': episode.scene_season,
                     'episodenumber': episode.scene_episode,
                 }
@@ -242,11 +230,6 @@ class GenericProvider(object):
         sickrage.app.log.debug("Provider type doesn't have ability to provide download size implemented yet")
         return -1
 
-    def _get_files(self, item):
-        """Gets dict of files with sizes from the item"""
-        sickrage.app.log.debug("Provider type doesn't have _get_files() implemented yet")
-        return {}
-
     def _get_result_stats(self, item):
         # Get seeders/leechers stats
         seeders = item.get('seeders', -1)
@@ -321,7 +304,7 @@ class GenericProvider(object):
             # categorize the items into lists by quality
             items = defaultdict(list)
             for item in itemList:
-                items[self.getQuality(item, anime=show.is_anime)].append(item)
+                items[self.get_quality(item, anime=show.is_anime)].append(item)
 
             # temporarily remove the list of items with unknown quality
             unknown_items = items.pop(Quality.UNKNOWN, [])
@@ -341,15 +324,14 @@ class GenericProvider(object):
 
             result.name, result.url = self._get_title_and_url(item)
 
-            # parse the file name
-            try:
-                myParser = NameParser(False)
-                parse_result = myParser.parse(result.name)
-            except InvalidNameException:
-                sickrage.app.log.debug("Unable to parse the filename " + result.name + " into a valid episode")
+            # ignore invalid urls
+            if not validate_url(result.url) and not result.url.startswith('magnet'):
                 continue
-            except InvalidShowException:
-                sickrage.app.log.debug("Unable to parse the filename " + result.name + " into a valid show")
+
+            try:
+                parse_result = NameParser().parse(result.name)
+            except (InvalidNameException, InvalidShowException) as e:
+                sickrage.app.log.debug("{}".format(e))
                 continue
 
             result.show = parse_result.show
@@ -357,73 +339,65 @@ class GenericProvider(object):
             result.release_group = parse_result.release_group
             result.version = parse_result.version
             result.size = self._get_size(item)
-            result.files = self._get_files(item)
-
             result.seeders, result.leechers = self._get_result_stats(item)
 
-            addCacheEntry = False
+            sickrage.app.log.debug("Adding item from search to cache: " + result.name)
+            self.cache.addCacheEntry(result.name, result.url, result.seeders, result.leechers, result.size)
+
+            if not result.show:
+                continue
+
             if not (result.show.air_by_date or result.show.sports):
                 if search_mode == 'sponly':
                     if len(parse_result.episode_numbers):
                         sickrage.app.log.debug(
                             "This is supposed to be a season pack search but the result " + result.name + " is not a valid season pack, skipping it")
-                        addCacheEntry = True
+                        continue
                     if len(parse_result.episode_numbers) and (
-                                    parse_result.season_number not in set([ep.season for ep in episodes])
+                            parse_result.season_number not in set([ep.season for ep in episodes])
                             or not [ep for ep in episodes if ep.scene_episode in parse_result.episode_numbers]):
                         sickrage.app.log.debug(
                             "The result " + result.name + " doesn't seem to be a valid episode that we are trying to snatch, ignoring")
-                        addCacheEntry = True
+                        continue
                 else:
                     if not len(parse_result.episode_numbers) and parse_result.season_number and not [ep for ep in
                                                                                                      episodes if
                                                                                                      ep.season == parse_result.season_number and ep.episode in parse_result.episode_numbers]:
                         sickrage.app.log.debug(
                             "The result " + result.name + " doesn't seem to be a valid season that we are trying to snatch, ignoring")
-                        addCacheEntry = True
+                        continue
                     elif len(parse_result.episode_numbers) and not [ep for ep in episodes if
                                                                     ep.season == parse_result.season_number and ep.episode in parse_result.episode_numbers]:
                         sickrage.app.log.debug(
                             "The result " + result.name + " doesn't seem to be a valid episode that we are trying to snatch, ignoring")
-                        addCacheEntry = True
+                        continue
 
-                if not addCacheEntry:
-                    # we just use the existing info for normal searches
-                    actual_season = parse_result.season_number
-                    actual_episodes = parse_result.episode_numbers
+                # we just use the existing info for normal searches
+                actual_season = parse_result.season_number
+                actual_episodes = parse_result.episode_numbers
             else:
                 if not parse_result.is_air_by_date:
                     sickrage.app.log.debug(
                         "This is supposed to be a date search but the result " + result.name + " didn't parse as one, skipping it")
-                    addCacheEntry = True
+                    continue
                 else:
                     airdate = parse_result.air_date.toordinal()
-                    dbData = [x['doc'] for x in
-                              sickrage.app.main_db.db.get_many('tv_episodes', result.show.indexerid, with_doc=True)
-                              if x['doc']['airdate'] == airdate]
+                    dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', result.show.indexerid)
+                              if x['airdate'] == airdate]
 
                     if len(dbData) != 1:
                         sickrage.app.log.warning(
                             "Tried to look up the date for the episode " + result.name + " but the database didn't give proper results, skipping it")
-                        addCacheEntry = True
+                        continue
 
-                if not addCacheEntry:
                     actual_season = int(dbData[0]["season"])
                     actual_episodes = [int(dbData[0]["episode"])]
 
-            # add parsed result to cache for usage later on
-            if addCacheEntry:
-                sickrage.app.log.debug("Adding item from search to cache: " + result.name)
-                self.cache.addCacheEntry(result.name, result.url, result.seeders, result.leechers, result.size,
-                                         result.files, parse_result)
-                continue
-
             # make sure we want the episode
-            wantEp = True
+            wantEp = False
             for epNo in actual_episodes:
-                if not result.show.wantEpisode(actual_season, epNo, result.quality, manualSearch, downCurQuality):
-                    wantEp = False
-                    break
+                if result.show.wantEpisode(actual_season, epNo, result.quality, manualSearch, downCurQuality):
+                    wantEp = True
 
             if not wantEp:
                 sickrage.app.log.info(
@@ -462,7 +436,7 @@ class GenericProvider(object):
         results = []
 
         for episode in episodes:
-            show = findCertainShow(sickrage.app.showlist, int(episode["showid"]))
+            show = findCertainShow(int(episode["showid"]))
             if not show:
                 continue
 
@@ -472,9 +446,11 @@ class GenericProvider(object):
                 for item in self.search(search_strngs[0], ep_obj=ep_obj):
                     result = self.getResult([ep_obj])
                     result.name, result.url = self._get_title_and_url(item)
+                    if not validate_url(result.url) and not result.url.startswith('magnet'):
+                        continue
+
                     result.seeders, result.leechers = self._get_result_stats(item)
                     result.size = self._get_size(item)
-                    result.files = self._get_files(item)
                     result.date = datetime.datetime.today()
                     result.show = show
                     results.append(result)
@@ -510,16 +486,16 @@ class GenericProvider(object):
             return {'result': False,
                     'message': 'Cookie is not correctly formatted: {}'.format(self.cookies)}
 
-        if not all(req_cookie in [x.rsplit('=', 1)[0] for x in self.cookies.split(';')] for req_cookie in
-                   self.required_cookies):
+        if hasattr(self, 'required_cookies') and not all(
+                req_cookie in [x.rsplit('=', 1)[0] for x in self.cookies.split(';')] for req_cookie in
+                self.required_cookies):
             return {'result': False,
                     'message': "You haven't configured the required cookies. Please login at {provider_url}, "
                                "and make sure you have copied the following cookies: {required_cookies!r}"
                         .format(provider_url=self.name, required_cookies=self.required_cookies)}
 
         # cookie_validator got at least one cookie key/value pair, let's return success
-        add_dict_to_cookiejar(sickrage.app.wsession.cookies,
-                              dict(x.rsplit('=', 1) for x in self.cookies.split(';')))
+        add_dict_to_cookiejar(self.session.cookies, dict(x.rsplit('=', 1) for x in self.cookies.split(';')))
 
         return {'result': True,
                 'message': ''}
@@ -531,13 +507,12 @@ class GenericProvider(object):
         Meaning that we've already successfully authenticated once, and we don't need to go through this again.
         Note! This doesn't mean the cookies are correct!
         """
-        if not hasattr(self, 'required_cookies'):
-            # A reminder for the developer, implementing cookie based authentication.
-            sickrage.app.log.error(
-                'You need to configure the required_cookies attribute, for the provider: {}'.format(self.name))
-            return False
-        return all(
-            dict_from_cookiejar(sickrage.app.wsession.cookies).get(cookie) for cookie in self.required_cookies)
+        if hasattr(self, 'required_cookies'):
+            return all(dict_from_cookiejar(self.session.cookies).get(cookie) for cookie in self.required_cookies)
+
+        # A reminder for the developer, implementing cookie based authentication.
+        sickrage.app.log.error(
+            'You need to configure the required_cookies attribute, for the provider: {}'.format(self.name))
 
     def cookie_login(self, check_login_text, check_url=None):
         """
@@ -558,29 +533,29 @@ class GenericProvider(object):
         if self.cookies:
             result = self.add_cookies_from_ui()
             if not result['result']:
-                sickrage.app.alerts.notifications.message(result['message'])
+                sickrage.app.alerts.message(result['message'])
                 sickrage.app.log.warning(result['message'])
                 return False
         else:
             sickrage.app.log.warning('Failed to login, you will need to add your cookies in the provider '
                                      'settings')
 
-            sickrage.app.alerts.notifications.error(
+            sickrage.app.alerts.error(
                 'Failed to auth with {provider}'.format(provider=self.name),
                 'You will need to add your cookies in the provider settings')
             return False
 
-        response = sickrage.app.wsession.get(check_url)
+        response = self.session.get(check_url)
         if any([not response, not (response.text and response.status_code == 200),
                 check_login_text.lower() in response.text.lower()]):
             sickrage.app.log.warning('Please configure the required cookies for this provider. Check your '
                                      'provider settings')
 
-            sickrage.app.alerts.notifications.error(
+            sickrage.app.alerts.error(
                 'Wrong cookies for {}'.format(self.name),
                 'Check your provider settings'
             )
-            sickrage.app.wsession.cookies.clear()
+            self.session.cookies.clear()
             return False
         else:
             return True
@@ -662,6 +637,38 @@ class TorrentProvider(GenericProvider):
         result.provider = self
         return result
 
+    def get_content(self, url):
+        result = None
+
+        def verify_torrent(content):
+            try:
+                if bencode.bdecode(content).get('info'):
+                    return content
+            except Exception:
+                pass
+
+        if url.startswith('magnet'):
+            # try iTorrents
+            info_hash = str(re.findall(r'urn:btih:([\w]{32,40})', url)[0]).upper()
+            if len(info_hash) == 32:
+                info_hash = b16encode(b32decode(info_hash)).upper()
+
+            if info_hash:
+                torrent_url = "https://itorrents.org/torrent/{info_hash}.torrent".format(info_hash=info_hash)
+                result = verify_torrent(super(TorrentProvider, self).get_content(torrent_url))
+
+                try:
+                    # add to external api database
+                    TorrentCacheAPI().add(url)
+                    result = verify_torrent(b64decode(TorrentCacheAPI().get(info_hash)['data']['content']).strip())
+                except Exception:
+                    pass
+
+        if not result:
+            result = verify_torrent(super(TorrentProvider, self).get_content(url))
+
+        return result
+
     def _get_title_and_url(self, item):
         title, download_url = '', ''
         if isinstance(item, (dict, FeedParserDict)):
@@ -683,52 +690,35 @@ class TorrentProvider(GenericProvider):
         return title, download_url
 
     def _get_size(self, item):
-        size = item.get('size', -1)
-        if size == -1 and item.get('url'):
-            for url in self.make_url(item.url):
-                try:
-                    resp = sickrage.app.wsession.get(url)
-                    torrent = bencode.bdecode(resp.content)
+        return item.get('size', -1)
 
-                    total_length = 0
-                    for file in torrent['info']['files']:
-                        total_length += int(file['length'])
+    def download_result(self, result):
+        """
+        Downloads a result to the appropriate black hole folder.
 
-                    if total_length > 0:
-                        size = total_length
-                        break
-                except Exception:
-                    pass
+        :param result: SearchResult instance to download.
+        :return: boolean, True on success
+        """
 
-        return size
+        if not result.content:
+            return False
 
-    def _get_files(self, item):
-        files = {}
+        filename = self.make_filename(result.name)
 
-        title, url = self._get_title_and_url(item)
-        if url:
-            for url in self.make_url(url):
-                try:
-                    resp = sickrage.app.wsession.get(url)
-                    torrent = bencode.bdecode(resp.content)
+        sickrage.app.log.info("Saving TORRENT to " + filename)
 
-                    for file in torrent['info']['files']:
-                        files[file['path'][0]] = int(file['length'])
-                except Exception:
-                    pass
+        # write content to torrent file
+        with io.open(filename, 'wb') as f:
+            f.write(result.content)
 
-        return files
+        return True
 
     @staticmethod
     def _clean_title_from_provider(title):
         return (title or '').replace(' ', '.')
 
-    def make_url(self, url):
-        return super(TorrentProvider, self).make_url(url)
-
     def make_filename(self, name):
-        return os.path.join(sickrage.app.config.torrent_dir,
-                            '{}.torrent'.format(sanitizeFileName(name)))
+        return os.path.join(sickrage.app.config.torrent_dir, '{}.torrent'.format(sanitizeFileName(name)))
 
     def add_trackers(self, result):
         """
@@ -738,7 +728,7 @@ class TorrentProvider(GenericProvider):
         """
 
         try:
-            trackers_list = sickrage.app.wsession.get('https://cdn.sickrage.ca/torrent_trackers/').text.split()
+            trackers_list = self.session.get('https://cdn.sickrage.ca/torrent_trackers/').text.split()
         except Exception:
             trackers_list = []
 
@@ -793,48 +783,51 @@ class NZBProvider(GenericProvider):
         return result
 
     def _get_size(self, item):
-        size = item.get('size', -1)
-        if size == -1 and item.get('url'):
+        return item.get('size', -1)
+
+    def download_result(self, result):
+        """
+        Downloads a result to the appropriate black hole folder.
+
+        :param result: SearchResult instance to download.
+        :return: boolean, True on success
+        """
+
+        if not result.content:
+            return False
+
+        filename = self.make_filename(result.name)
+
+        # Support for Jackett/TorzNab
+        if (result.url.endswith('torrent') or result.url.startswith('magnet')) and self.type in ['nzb', 'newznab']:
+            filename = filename.rsplit('.', 1)[0] + '.' + 'torrent'
+
+        if result.resultType == "nzb":
+            sickrage.app.log.info("Saving NZB to " + filename)
+
+            # write content to torrent file
+            with io.open(filename, 'wb') as f:
+                f.write(result.content)
+
+            return True
+        elif result.resultType == "nzbdata":
+            filename = os.path.join(sickrage.app.config.nzb_dir, result.name + ".nzb")
+
+            sickrage.app.log.info("Saving NZB to " + filename)
+
+            # save the data to disk
             try:
-                resp = sickrage.app.wsession.get(item.url)
+                with io.open(filename, 'w') as fileOut:
+                    fileOut.write(result.extraInfo[0])
 
-                total_length = 0
-                for file in nzb_parser.parse(resp.content):
-                    for segment in file.segments:
-                        total_length += int(segment.bytes)
+                chmodAsParent(filename)
 
-                if total_length > 0:
-                    size = total_length
-            except Exception:
-                pass
-
-        return size
-
-    def _get_files(self, item):
-        files = {}
-
-        title, url = self._get_title_and_url(item)
-        if url:
-            try:
-                resp = sickrage.app.wsession.get(url)
-
-                for file in nzb_parser.parse(resp.content):
-                    total_length = 0
-                    for segment in file.segments:
-                        total_length += int(segment.bytes)
-
-                    files[file.subject] = total_length
-            except Exception:
-                pass
-
-        return files
-
-    def make_url(self, url):
-        return super(NZBProvider, self).make_url(url)
+                return True
+            except EnvironmentError as e:
+                sickrage.app.log.error("Error trying to save NZB to black hole: {}".format(e))
 
     def make_filename(self, name):
-        return os.path.join(sickrage.app.config.nzb_dir,
-                            '{}.nzb'.format(sanitizeFileName(name)))
+        return os.path.join(sickrage.app.config.nzb_dir, '{}.nzb'.format(sanitizeFileName(name)))
 
     @classmethod
     def getProviders(cls):
@@ -865,6 +858,7 @@ class TorrentRssProvider(TorrentProvider):
         self.enable_backlog = enable_backlog
         self.enable_cookies = True
         self.cookies = cookies
+        self.required_cookies = ('uid', 'pass')
         self.titleTAG = titleTAG
         self.default = default
 
@@ -919,19 +913,20 @@ class TorrentRssProvider(TorrentProvider):
                         'message': 'RSS feed Parsed correctly'}
             else:
                 try:
-                    torrent_file = sickrage.app.wsession.get(url).content
+                    torrent_file = self.session.get(url).content
                     bencode.bdecode(torrent_file)
                 except Exception as e:
-                    if data: self.dumpHTML(torrent_file)
+                    if data:
+                        self.dumpHTML(torrent_file)
                     return {'result': False,
-                            'message': 'Torrent link is not a valid torrent file: {}'.format(e.message)}
+                            'message': 'Torrent link is not a valid torrent file: {}'.format(e)}
 
             return {'result': True,
                     'message': 'RSS feed Parsed correctly'}
 
         except Exception as e:
             return {'result': False,
-                    'message': 'Error when trying to load RSS: {}'.format(e.message)}
+                    'message': 'Error when trying to load RSS: {}'.format(e)}
 
     @staticmethod
     def dumpHTML(data):
@@ -1038,7 +1033,7 @@ class NewznabProvider(NZBProvider):
             url_params['apikey'] = self.key
 
         try:
-            response = sickrage.app.wsession.get(urljoin(self.urls['base_url'], 'api'), params=url_params).text
+            response = self.session.get(urljoin(self.urls['base_url'], 'api'), params=url_params).text
         except Exception:
             error_string = 'Error getting caps xml for [{}]'.format(self.name)
             sickrage.app.log.warning(error_string)
@@ -1093,7 +1088,7 @@ class NewznabProvider(NZBProvider):
 
         return False
 
-    def search(self, search_strings, age=0, ep_obj=None):
+    def search(self, search_strings, age=0, ep_obj=None, **kwargs):
         """
         Search indexer using the params in search_strings, either for latest releases, or a string/id search.
 
@@ -1156,75 +1151,12 @@ class NewznabProvider(NZBProvider):
                 sleep(cpu_presets[sickrage.app.config.cpu_preset])
 
                 try:
-                    response = sickrage.app.wsession.get(urljoin(self.urls['base_url'], 'api'),
-                                                         params=search_params).text
+                    data = self.session.get(urljoin(self.urls['base_url'], 'api'), params=search_params).text
+                    results += self.parse(data, mode)
                 except Exception:
                     sickrage.app.log.debug('No data returned from provider')
                     continue
 
-                with bs4_parser(response) as html:
-                    if not self._check_auth_from_data(html):
-                        return results
-
-                    try:
-                        self.torznab = 'xmlns:torznab' in html.rss.attrs
-                    except AttributeError:
-                        self.torznab = False
-
-                    if not html('item'):
-                        sickrage.app.log.debug('No results returned from provider. Check chosen Newznab '
-                                               'search categories in provider settings and/or usenet '
-                                               'retention')
-                        continue
-
-                    for item in html('item'):
-                        try:
-                            title = item.title.get_text(strip=True)
-                            download_url = None
-                            if item.link:
-                                if validate_url(item.link.get_text(strip=True)):
-                                    download_url = item.link.get_text(strip=True)
-                                elif validate_url(item.link.next.strip()):
-                                    download_url = item.link.next.strip()
-
-                            if not download_url and item.enclosure:
-                                if validate_url(item.enclosure.get('url', '').strip()):
-                                    download_url = item.enclosure.get('url', '').strip()
-
-                            if not (title and download_url):
-                                continue
-
-                            seeders = leechers = -1
-                            if 'gingadaddy' in self.urls['base_url']:
-                                size_regex = re.search(r'\d*.?\d* [KMGT]B', str(item.description))
-                                item_size = size_regex.group() if size_regex else -1
-                            else:
-                                item_size = item.size.get_text(strip=True) if item.size else -1
-                                for attr in item('newznab:attr') + item('torznab:attr'):
-                                    item_size = attr['value'] if attr['name'] == 'size' else item_size
-                                    seeders = try_int(attr['value']) if attr['name'] == 'seeders' else seeders
-                                    peers = try_int(attr['value']) if attr['name'] == 'peers' else None
-                                    leechers = peers - seeders if peers else leechers
-
-                            if not item_size or (self.torznab and (seeders is -1 or leechers is -1)):
-                                continue
-
-                            size = convert_size(item_size, -1)
-
-                            item = {
-                                'title': title,
-                                'link': download_url,
-                                'size': size,
-                                'seeders': seeders,
-                                'leechers': leechers,
-                            }
-                            if mode != 'RSS':
-                                sickrage.app.log.debug('Found result: {0}'.format(title))
-
-                            results.append(item)
-                        except (AttributeError, TypeError, KeyError, ValueError, IndexError):
-                            sickrage.app.log.error('Failed parsing provider')
-
                 # Since we arent using the search string,
                 # break out of the search string loop
                 if 'tvdbid' in search_params:
@@ -1237,6 +1169,74 @@ class NewznabProvider(NZBProvider):
 
         return results
 
+    def parse(self, data, mode, **kwargs):
+        results = []
+
+        with bs4_parser(data) as html:
+            if not self._check_auth_from_data(html):
+                return results
+
+            try:
+                self.torznab = 'xmlns:torznab' in html.rss.attrs
+            except AttributeError:
+                self.torznab = False
+
+            if not html('item'):
+                sickrage.app.log.debug('No results returned from provider. Check chosen Newznab '
+                                       'search categories in provider settings and/or usenet '
+                                       'retention')
+                return results
+
+            for item in html('item'):
+                try:
+                    title = item.title.get_text(strip=True)
+                    download_url = None
+                    if item.link:
+                        url = item.link.get_text(strip=True)
+                        if validate_url(url) or url.startswith('magnet'):
+                            download_url = url
+
+                        if not download_url:
+                            url = item.link.next.strip()
+                            if validate_url(url) or url.startswith('magnet'):
+                                download_url = url
+
+                    if not download_url and item.enclosure:
+                        url = item.enclosure.get('url', '').strip()
+                        if validate_url(url) or url.startswith('magnet'):
+                            download_url = url
+
+                    if not (title and download_url):
+                        continue
+
+                    seeders = leechers = -1
+                    if 'gingadaddy' in self.urls['base_url']:
+                        size_regex = re.search(r'\d*.?\d* [KMGT]B', str(item.description))
+                        item_size = size_regex.group() if size_regex else -1
+                    else:
+                        item_size = item.size.get_text(strip=True) if item.size else -1
+                        for attr in item('newznab:attr') + item('torznab:attr'):
+                            item_size = attr['value'] if attr['name'] == 'size' else item_size
+                            seeders = try_int(attr['value']) if attr['name'] == 'seeders' else seeders
+                            peers = try_int(attr['value']) if attr['name'] == 'peers' else None
+                            leechers = peers - seeders if peers else leechers
+
+                    if not item_size or (self.torznab and (seeders is -1 or leechers is -1)):
+                        continue
+
+                    size = convert_size(item_size, -1)
+
+                    results += [
+                        {'title': title, 'link': download_url, 'size': size, 'seeders': seeders, 'leechers': leechers}
+                    ]
+
+                    if mode != 'RSS':
+                        sickrage.app.log.debug('Found result: {}'.format(title))
+                except (AttributeError, TypeError, KeyError, ValueError, IndexError):
+                    sickrage.app.log.error('Failed parsing provider')
+
+        return results
+
     @classmethod
     def getProviders(cls):
         providers = cls.getDefaultProviders()
@@ -1272,10 +1272,11 @@ class NewznabProvider(NZBProvider):
     def getDefaultProviders(cls):
         return [
             cls('DOGnzb', 'https://api.dognzb.cr', '', '5030,5040,5060,5070', 'eponly', False, False, False, True),
-            cls('NZB.Cat', 'http://nzb.cat', '', '5030,5040,5010', 'eponly', True, True, True, True),
-            cls('NZBGeek', 'http://api.nzbgeek.info', '', '5030,5040', 'eponly', False, False, False, True),
-            cls('NZBs.org', 'http://nzbs.org', '', '5030,5040', 'eponly', False, False, False, True),
-            cls('Usenet-Crawler', 'http://usenet-crawler.com', '', '5030,5040', 'eponly', False, False, False, True)
+            cls('NZB.Cat', 'https://nzb.cat', '', '5030,5040,5010', 'eponly', True, True, True, True),
+            cls('NZBGeek', 'https://api.nzbgeek.info', '', '5030,5040', 'eponly', False, False, False, True),
+            cls('NZBs.org', 'https://nzbs.org', '', '5030,5040', 'eponly', False, False, False, True),
+            cls('Usenet-Crawler', 'https://api.usenet-crawler.com', '', '5030,5040', 'eponly', False, False, False,
+                True)
         ]
 
 
@@ -1288,7 +1289,8 @@ class TorrentRssCache(TVCache):
         sickrage.app.log.debug("Cache update URL: %s" % self.provider.urls['base_url'])
 
         if self.provider.cookies:
-            self.provider.headers.update({'Cookie': self.provider.cookies})
+            add_dict_to_cookiejar(self.provider.session.cookies,
+                                  dict(x.rsplit('=', 1) for x in self.provider.cookies.split(';')))
 
         return self.getRSSFeed(self.provider.urls['base_url'])
 
@@ -1299,6 +1301,12 @@ class SearchProviders(dict):
 
         self.provider_order = []
 
+        self[NZBProvider.type] = {}
+        self[TorrentProvider.type] = {}
+        self[NewznabProvider.type] = {}
+        self[TorrentRssProvider.type] = {}
+
+    def load(self):
         self[NZBProvider.type] = dict([(p.id, p) for p in NZBProvider.getProviders()])
         self[TorrentProvider.type] = dict([(p.id, p) for p in TorrentProvider.getProviders()])
         self[NewznabProvider.type] = dict([(p.id, p) for p in NewznabProvider.getProviders()])
